/* eslint-disable jsx-a11y/anchor-is-valid */
import {
  Button,
  Divider,
  List,
  ListItem,
  ListItemIcon,
  makeStyles,
} from '@material-ui/core';
import { Mail } from '@material-ui/icons';

import Image from 'next/image';
import { useRouter } from 'next/router';
import { menuData as listItems } from '@/config/menuData';
import logo from '@/images/logos/logo.png';
import ActiveLink from '@/components/ActiveLink';
import { useDispatch } from 'react-redux';
import { closeDrawer, openDrawer } from '@/redux/actions/drawer.actions';
import LoginComponent from '@/components/LoginComponent';
import ModalExample from './ModalExample';

const useStyles = makeStyles((theme) => ({
  wrapper: {
    width: 266,
    display: 'flex',
    justifyContent: 'center',
  },
  container: {
    width: 250,
    padding: theme.spacing(2),
    overflow: 'hidden',
  },
  logo: {
    width: 250,
    padding: theme.spacing(2),
  },
  list: {
    width: 250,
  },
  fullList: {
    width: 'auto',
  },
  buttons: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
  btn: {
    margin: theme.spacing(1),
  },
  imageLogo: {
    cursor: 'pointer',
  },
}));
const DrawerList = ({ setOpen }) => {
  const router = useRouter();
  const dispatch = useDispatch();
  const classes = useStyles();

  return (
    <>
      <div className={classes.wrapper}>
        <div className={classes.container}>
          <div className={classes.logo}>
            <Image
              src={logo}
              alt="Aaipay : Pay With Faith"
              width={160}
              height={50}
              className={classes.imageLogo}
              onClick={(e) => {
                e.preventDefault();
                router.push('/');
              }}
            />
          </div>
          <div className={classes.buttons}>
            <Button
              variant="outlined"
              color="primary"
              className={classes.btn}
              onClick={() => {
                dispatch(
                  closeDrawer({
                    modalProps: { open: false },
                  })
                );
                setTimeout(() => {
                  dispatch(
                    openDrawer({
                      modalType: ModalExample,
                      modalProps: {
                        component: <LoginComponent />,
                        open: true,
                        // setOpen: setOpen,
                        widthDrawer: 800,
                        title: 'Login',
                        closeDrawerAction: true,
                      },
                    })
                  );
                }, 300);
              }}
            >
              Log in
            </Button>
            <Button variant="contained" color="primary" className={classes.btn}>
              Sign Up
            </Button>
          </div>
        </div>
      </div>
      <Divider />
      <List className={classes.fullList}>
        {listItems.map((item) => (
          <ListItem button key={item.id} className={classes.list}>
            {' '}
            <style jsx>{`
              .nav-link {
                text-decoration: none;
              }

              .active {
                font-weight: 600;
              }
            `}</style>
            <ListItemIcon>
              <Mail />
            </ListItemIcon>
            <ActiveLink
              href={item.href}
              onClick={() =>
                dispatch(
                  closeDrawer({
                    modalType: ModalExample,
                    modalProps: {
                      open: false,
                    },
                  })
                )
              }
              activeclassname="active"
            >
              <span href={item.href}>{item.name}</span>
            </ActiveLink>
          </ListItem>
        ))}
      </List>
    </>
  );
};

export default DrawerList;
