import Container from '@material-ui/core/Container';
import Grid from '@material-ui/core/Grid';
import Box from '@material-ui/core/Box';
import Link from 'next/link';
import { useSelector } from 'react-redux';
import SocialIcons from '@/components/SocialIcons';
import FooterItems from './FooterItems';
import { mergeArrayObjects } from 'utils/customFunctions';
import sluggedNavData from '@/config/navData';

export default function Footer() {
  const { categories, loading } = useSelector((state) => state.category);
  const allData = categories.map((item) => {
    return {
      id: item.serviceId,
      serviceTypeName: item.serviceTypeName,
    };
  });
  const fullNavdata = mergeArrayObjects(allData, sluggedNavData);
  const cat1 = fullNavdata.slice(0, 4);
  const cat2 = fullNavdata.slice(4, 8);
  const cat3 = fullNavdata.slice(8, 12);
  const cat4 = fullNavdata.slice(12, 16);
  const cat5 = fullNavdata.slice(16, 20);
  const cat6 = fullNavdata.slice(20, 24);

  return (
    <>
      {loading && null}
      <footer className="top__footer">
        <Container maxWidth="sm">
          <Grid container>
            <Grid item xs={12}>
              <SocialIcons />
            </Grid>
            {/* <Grid item xs={6}></Grid> */}
          </Grid>
        </Container>
      </footer>
      <footer className="footer">
        <Box px={{ xs: 3, sm: 10 }} py={{ xs: 5, sm: 10 }}>
          <Container maxWidth="lg">
            <Grid container spacing={5} className="footer__text">
              <FooterItems listItems={cat1} listHead="Category 1" />
              <FooterItems listItems={cat2} listHead="Category 2" />
              <FooterItems listItems={cat3} listHead="Category 3" />
              <FooterItems listItems={cat4} listHead="Category 4" />
              <FooterItems listItems={cat5} listHead="Category 5" />
              <FooterItems listItems={cat6} listHead="Category 6" />
            </Grid>
            <Box
              textAlign="center"
              pt={{ xs: 5, sm: 5 }}
              pb={{ xs: 5, sm: 5 }}
              mt={{ xs: 5, sm: 5 }}
              className="bottom__footer"
            >
              Aaipay &reg; {new Date().getFullYear()}
            </Box>
          </Container>
        </Box>

        <svg
          xmlns="http://www.w3.org/2000/svg"
          viewBox="0 0 1440 319"
          preserveAspectRatio="xMidYMin slice"
          // preserveAspectRatio={width >= 800 ? 'none' : ''}
          className="curve"
        >
          <path
            fill="#3da3e3"
            fillOpacity="1"
            d="M0,192L26.7,202.7C53.3,213,107,235,160,224C213.3,213,267,171,320,176C373.3,181,427,235,480,229.3C533.3,224,587,160,640,122.7C693.3,85,747,75,800,85.3C853.3,96,907,128,960,128C1013.3,128,1067,96,1120,106.7C1173.3,117,1227,171,1280,165.3C1333.3,160,1387,96,1413,64L1440,32L1440,320L1413.3,320C1386.7,320,1333,320,1280,320C1226.7,320,1173,320,1120,320C1066.7,320,1013,320,960,320C906.7,320,853,320,800,320C746.7,320,693,320,640,320C586.7,320,533,320,480,320C426.7,320,373,320,320,320C266.7,320,213,320,160,320C106.7,320,53,320,27,320L0,320Z"
          ></path>
        </svg>
      </footer>
    </>
  );
}
