import {
  AppBar,
  IconButton,
  Toolbar,
  makeStyles,
  Button,
  Hidden,
  Container,
  CssBaseline,
} from '@material-ui/core';
import { Menu as MenuIcon } from '@material-ui/icons';
import { useRouter } from 'next/router';
import Image from 'next/image';

import logo from '@/images/logos/logo.png';
import { useDispatch } from 'react-redux';
import { openDrawer } from '@/redux/actions/drawer.actions';
import DrawerList from '../Drawer/DrawerList';
import MaterialDrawerRedux from '../Drawer/DrawerRedux';
import ModalExample from '../Drawer/ModalExample';
import LoginComponent from '@/components/LoginComponent';
const useStyles = makeStyles(() => ({
  imageLogo: {
    flexGrow: 1,
    cursor: 'pointer',
  },
  title: {
    flexGrow: 1,
  },
  logo: {
    width: '100px',
  },
}));
export default function Header({ setOpen }) {
  const dispatch = useDispatch();
  const classes = useStyles();
  const router = useRouter();
  return (
    <div className={classes.root}>
      <CssBaseline />
      <AppBar position="fixed" color="inherit">
        <Container maxWidth="lg">
          <Toolbar style={{ width: '100%' }}>
            <Image
              src={logo}
              alt="Aaipay"
              width={130}
              height={40}
              className={classes.imageLogo}
              onClick={(e) => {
                e.preventDefault();
                router.push('/');
              }}
            />
            <span style={{ position: 'absolute', right: 20 }}>
              <Hidden smDown>
                <Button
                  variant="outlined"
                  color="primary"
                  onClick={() =>
                    dispatch(
                      openDrawer({
                        modalType: ModalExample,
                        modalProps: {
                          component: <LoginComponent />,
                          open: true,
                          // setOpen: setOpen,
                          widthDrawer: 800,
                          title: 'Login',
                          closeDrawerAction: true,
                        },
                      })
                    )
                  }
                  style={{ marginRight: 10 }}
                >
                  Log in
                </Button>
                <Button
                  variant="contained"
                  color="primary"
                  style={{ marginRight: 20 }}
                >
                  Sign Up
                </Button>
              </Hidden>
              <IconButton
                edge="start"
                className={classes.menuButton}
                color="inherit"
                aria-label="menu"
                // onClick={() => setOpen(true)}
                onClick={() =>
                  dispatch(
                    openDrawer({
                      modalType: ModalExample,
                      modalProps: {
                        component: <DrawerList />,
                        open: true,
                        // setOpen: setOpen,
                        widthDrawer: 300,
                        closeDrawerAction: false,
                      },
                    })
                  )
                }
              >
                <MenuIcon />
              </IconButton>
            </span>
          </Toolbar>
        </Container>
      </AppBar>
    </div>
  );
}

// export const getStaticProps = async () => {
//   return {
//     props: {
//       open: open,
//       setOpen: setOpen,
//     },
//   };
// };
