import { useRouter } from 'next/router';
import PropTypes from 'prop-types';
import Link from 'next/link';
import React, { Children } from 'react';

const ActiveLink = ({ children, activeclassname, onClick, ...props }) => {
  const { asPath } = useRouter();
  const child = Children.only(children);
  const childClassName = child.props.className || '';
  // pages/index.js will be matched via props.href
  // pages/about.js will be matched via props.href
  // pages/[slug].js will be matched via props.as
  const className =
    asPath === props?.href || asPath === props.as
      ? `${childClassName} ${activeclassname}`.trim()
      : childClassName;

  return (
    <Link {...props}>
      {React.cloneElement(child, {
        className: className || null,
        onClick: onClick || null,
        as: asPath || null,
      })}
    </Link>
  );
};

ActiveLink.propTypes = {
  activeclassname: PropTypes.string.isRequired,
};
ActiveLink.defaultProps = {
  activeclassname: 'active',
};

export default ActiveLink;
