import { Field, Form, Formik, useFormikContext } from "formik";
import React, { useEffect, useState } from "react";

import Controls from "../Controls/Controls";

import { useDispatch, useSelector } from "react-redux";
import Overlay from "../Overlay";
import { useWindowSize } from "@/hooks/useWindowSize";
import { MoneyButtonWrapper } from "../Styled/MoneyButton";
import { Typography } from "@material-ui/core";

import { useRouter } from "next/router";

const LoadOperators = () => {
  const { values, setFieldValue } = useFormikContext();

  useEffect(() => {
    setFieldValue("amount", "0");
  }, [setFieldValue]);
  return null;
};
const AddMoneyToWallet = ({ walletBalance }) => {
  const router = useRouter();
  const dispatch = useDispatch();
  const { loading } = useSelector((state) => state.passbook);
  const { userInfo } = useSelector((state) => state.myProfile);
  const [loadingButton, setLoadingButton] = useState(false);

  const { width: windowWidth } = useWindowSize();
  const validate = (values) => {
    const errors = {};

    if (values.amount === 0 || values.amount === "0") {
      errors.amount = "Please enter amount greater than 0";
    }
    if (values.amount === "") {
      errors.amount = "Please enter amount ";
    }

    return errors;
  };
  return (
    <Formik
      initialValues={{
        amount: 0,
      }}
      validate={validate}
      onSubmit={(values, actions) => {
        const { amount } = values;
        typeof window !== "undefined" &&
          window.localStorage.setItem("amount", values.amount);
        setLoadingButton(true);
        router.push({
          pathname: "/passbook/transaction",
        });
        // setTimeout(() => {
        //   alert(JSON.stringify(values, null, 2));
        //   actions.setSubmitting(false);
        // }, 1000);
        // history.push()
        // dispatch(
        //   openModal({
        //     modalType: ModalExample,
        //     modalProps: {
        //       component: (
        //         <Razorpay
        //           amount={values.amount}
        //           userInfo={userInfo}
        //           windowWidth={windowWidth}
        //         />
        //       ),
        //       open: true,
        //       // setOpen: setOpen,
        //       // widthDrawer: 800,
        //       closeDrawerAction: true,
        //     },
        //   })
        // );
      }}
    >
      {({
        setFieldValue,
        values,
        handleSubmit,
        handleChange,
        touched,
        errors,
        setErrors,
      }) => {
        return (
          <>
            {loading && <Overlay />}
            {/* {alertOpen === true ? <AlertMessage /> : null} */}
            <div>
              <Typography variant="subtitle2" style={{ fontSize: "1.2rem" }}>
                Available Wallet Balance : ₹{walletBalance}
              </Typography>
            </div>
            <Form onSubmit={handleSubmit}>
              <div
                style={{
                  display: "flex",
                  justifyContent: "flex-start",
                  flexDirection: windowWidth > 768 ? "row" : "column",
                  alignItems: "center",
                }}
              >
                <div
                  style={{
                    display: "flex",
                    width: "100%",

                    flex: "2 1 170%",
                  }}
                >
                  <div
                    style={{
                      display: "flex",
                      flexDirection: "column",
                      flex: "2 1 190%",
                    }}
                  >
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="amount"
                      name="amount"
                      label="Amount"
                      value={values.amount}
                      onChange={handleChange}
                      error={touched.amount && Boolean(errors.amount)}
                      helperText={touched.amount && errors.amount}
                      variant="standard"
                      size="medium"
                      margin="normal"
                      placeholder={"Please Enter Amount"}
                      maxLength={6}
                    />
                    <div
                      style={{
                        flexDirection: windowWidth > 400 ? "row" : "column",
                        display: "inline-flex",
                        // justifyContent:
                        //   windowWidth > 768 ? "flex-start" : "center",
                        alignItems: windowWidth > 768 ? "flex-start" : "center",
                      }}
                    >
                      <MoneyButtonWrapper
                        amount={"+500"}
                        windowWidth={windowWidth}
                        onClick={() => setFieldValue("amount", 500)}
                      />

                      <MoneyButtonWrapper
                        amount={"+1000"}
                        windowWidth={windowWidth}
                        onClick={() => setFieldValue("amount", 1000)}
                      />
                      <MoneyButtonWrapper
                        amount={"+2000"}
                        windowWidth={windowWidth}
                        onClick={() => setFieldValue("amount", 2000)}
                      />
                      <MoneyButtonWrapper
                        amount={"+3000"}
                        windowWidth={windowWidth}
                        onClick={() => setFieldValue("amount", 3000)}
                      />
                      <MoneyButtonWrapper
                        amount={"+5000"}
                        windowWidth={windowWidth}
                        onClick={() => setFieldValue("amount", 5000)}
                      />
                    </div>
                  </div>
                </div>
                <div
                  style={{
                    width: windowWidth > 768 ? "100%" : "100%",
                    display: "flex",
                    justifyContent: windowWidth > 768 ? "flex-end" : "center",
                    marginTop: windowWidth < 768 && "1rem",
                    minWidth: windowWidth > 360 ? "14rem" : "13rem",
                  }}
                >
                  <Controls.Button
                    color="primary"
                    variant="contained"
                    type="submit"
                    text={
                      values?.amount > 0
                        ? `Add ₹ ${parseFloat(values?.amount)?.toFixed(
                            2
                          )} To Wallet`
                        : "Add Money To Wallet"
                    }
                    fullWidthButton={windowWidth >= 768 ? false : true}
                    loadingIndicator={true}
                    loadingButton={loadingButton}
                    style={{
                      // borderRadius: 32,
                      position: windowWidth > 768 ? "relative" : "static",
                      marginTop: windowWidth > 768 ? 0 : 16,
                      // top: -24,
                      paddingTop: 12,
                      paddingBottom: 12,
                      marginRight: windowWidth < 768 && -16,
                      marginLeft: windowWidth < 768 && -16,
                    }}
                    // onClick={() => {
                    //   // dispatch(
                    //   //   goToRazorPay({
                    //   //     windowWidth,
                    //   //     amount: values.amount,
                    //   //     userInfo,
                    //   //   })
                    //   // );
                    // }}
                  />
                </div>
              </div>
            </Form>

            <LoadOperators
            //   userInfo={userInfo}
            //   loading={loading}
            //   userInfoWithRegId={userInfoWithRegId}
            />
          </>
        );
      }}
    </Formik>
  );
};

export default AddMoneyToWallet;
