import { useState, useEffect, useRef } from "react";
import { makeStyles } from "@material-ui/core/styles";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import Button from "@material-ui/core/Button";
import Controls from "../../Controls/Controls";
import KeyboardArrowLeftIcon from "@material-ui/icons/KeyboardArrowLeft";
import KeyboardArrowRightIcon from "@material-ui/icons/KeyboardArrowRight";
import { useWindowSize } from "@/hooks/useWindowSize";

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
  },
  menuButton: {
    marginRight: theme.spacing(2),
  },
}));

const MuiAppBar = ({ menuItems, handleFilter }) => {
  const classes = useStyles();
  const menuRef = useRef(null);
  const buttonRef = useRef(null);
  const toolbarRef = useRef(null);
  const [active, setActive] = useState("active-0");
  const [show, setShow] = useState(true);
  const scroll = (scrollOffset, direction) => {
    if (direction === "right") {
      return (menuRef.current.scrollLeft -= scrollOffset);
    } else {
      return (menuRef.current.scrollLeft += scrollOffset);
    }
  };
  const handleActive = (e, index) => {
    e.preventDefault();
    const text = e.target.innerText;
    setActive(`${text}-${index}`);
  };
  const windowSize = useWindowSize();
  useEffect(() => {
    const menuWidth = menuRef.current !== null && menuRef.current.scrollWidth;
    const toolwidth =
      toolbarRef.current !== null && toolbarRef.current.scrollWidth;
    const buttonsWidth =
      buttonRef.current !== null &&
      buttonRef.current.scrollWidth * menuItems?.length +
        menuItems?.length * 10;
    if (menuItems?.length >= 10 || menuWidth > toolwidth) {
      setShow(true);
    } else {
      setShow(false);
    }
  }, [windowSize, menuItems]);
  return (
    <div className={classes.root}>
      <AppBar
        position="static"
        color="default"
        style={{
          marginBottom: 20,
        }}
      >
        <Toolbar variant="dense" ref={toolbarRef}>
          {show && (
            <Controls.ActionButton
              style={{
                position: "sticky",

                width: 40,
                height: 40,
              }}
              onClick={() => scroll(50, "right")}
            >
              <KeyboardArrowLeftIcon />
            </Controls.ActionButton>
          )}
          <div className="wrapper__tabs" ref={menuRef}>
            {menuItems?.map((item, index) => (
              <Button
                ref={buttonRef}
                onClick={(e) => {
                  handleActive(e, index);
                  return handleFilter(e);
                }}
                key={index}
                style={{
                  marginRight: 5,
                  marginLeft: 5,
                }}
                className={
                  index < 10
                    ? `${index}` === active.charAt(active.length - 1)
                      ? "activeClassNav"
                      : null
                    : `${index}` ===
                      `${active.charAt(active.length - 2)}${active.charAt(
                        active.length - 1
                      )}`
                    ? "activeClassNav"
                    : null
                }
              >
                {item}
              </Button>
            ))}
          </div>
          {show && (
            <Controls.ActionButton
              style={{
                position: "sticky",
                width: 40,
                height: 40,
              }}
              onClick={() => scroll(50, "left")}
            >
              <KeyboardArrowRightIcon />
            </Controls.ActionButton>
          )}
        </Toolbar>
      </AppBar>
    </div>
  );
};

export default MuiAppBar;
