import React, { useState } from "react";
import RichTooltip from "./RichToolTip";

const ClickableRichTooltip = ({
  placement,
  arrow,
  content,
  children,
  disabled = false,
  width,
}) => {
  const [open, setOpen] = useState(false);

  if (disabled) {
    return React.cloneElement(children, { ...children.props, disabled: true });
  }

  const existingOnClick = children.props.onClick;
  const newOnClick = (e) => {
    setOpen(!open);
    existingOnClick && existingOnClick(e);
  };

  const contentNode = typeof content === "function" ? content() : content;

  return (
    <RichTooltip
      open={open}
      onClose={() => setOpen(false)}
      arrow={arrow}
      placement={placement}
      content={contentNode}
      width={width}
    >
      {React.cloneElement(children, { ...children.props, onClick: newOnClick })}
    </RichTooltip>
  );
};

export default ClickableRichTooltip;
