// import React from 'react';
// import { Button as MuiButton, makeStyles } from '@material-ui/core';

// const useStyles = makeStyles((theme) => ({
//   root: {
//     margin: theme.spacing(1),
//     paddingTop: theme.spacing(1.5),
//     paddingBottom: theme.spacing(1.5),
//     paddingRight: theme.spacing(2.5),
//     paddingLeft: theme.spacing(2.5),
//   },
//   label: {
//     textTransform: 'none',
//   },
// }));

// const Button = (props) => {
//   const { text, size, color, variant, onClick, ...other } = props;
//   const classes = useStyles();
//   return (
//     <MuiButton
//       color={color || 'primary'}
//       variant={variant || 'contained'}
//       size={size || 'small'}
//       onClick={onClick}
//       {...other}
//       classes={{ root: classes.root, label: classes.label }}
//     >
//       {text}
//     </MuiButton>
//   );
// };

// export default Button;

import React from "react";
import {
  Button as MuiButton,
  CircularProgress,
  makeStyles,
} from "@material-ui/core";

const useStyles = makeStyles((theme) => ({
  root: {
    margin: (props) => (props && props.margin ? theme.spacing(1) : 0),

    paddingBottom: (props) =>
      props && props.padding ? theme.spacing(2) : theme.spacing(1),
    paddingTop: (props) =>
      props && props.padding ? theme.spacing(2) : theme.spacing(1),
    paddingRight: (props) =>
      props && props.padding ? theme.spacing(4) : theme.spacing(2),
    paddingLeft: (props) =>
      props && props.padding ? theme.spacing(4) : theme.spacing(2),
    borderRadius: (props) =>
      props.borderRadius === true ? theme.spacing(2) : theme.spacing(1),
    minWidth: (props) => (props.fullWidthButton === true ? "100%" : "auto"),
    // borderRadius: '80% 20% 70% 30% / 36% 57% 43% 64%'
  },

  circularProgress: {
    position: "absolute",
    left: 10,
  },
  label: {
    textTransform: "uppercase",
  },
  buttonLoading: {
    margin: (props) => (props.margin ? theme.spacing(1) : 0),
    paddingTop: theme.spacing(1.3),
    paddingBottom: theme.spacing(1.3),
    paddingRight: (props) =>
      props.fullWidthButton === true ? theme.spacing(5) : theme.spacing(4),
    paddingLeft: (props) =>
      props.fullWidthButton === true ? theme.spacing(5) : theme.spacing(4),
    // backgroundColor: "rgb(0 0 0 / 26%)",
    // backgroundColor: props.fullWidthButton === true ? "red" : "blue",
    width: (props) => (props.fullWidthButton === true ? "100%" : "auto"),
    // borderRadius: '36% 64% 36% 64% / 100% 0% 100% 0% ',
    minWidth: 120,
    borderRadius: (props) =>
      props.borderRadius === true ? theme.spacing(4) : theme.spacing(1),
    "&:disabled": {
      cursor: "not-allowed",
      pointerEvents: "all !important",
    },
  },
}));

const Button = (props) => {
  const {
    text,
    size,
    color,
    variant,
    onClick,
    loadingButton,
    loadingIndicator,
    fullWidthButton,
    margin,
    borderRadius,
    padding = true,
    ...other
  } = props;
  const classes = useStyles({
    fullWidthButton: fullWidthButton,
    margin: margin,
    borderRadius: borderRadius,
    padding: padding,
  });
  return loadingIndicator ? (
    !loadingButton ? (
      <MuiButton
        color={color || "primary"}
        variant={variant || "contained"}
        size={size || "small"}
        onClick={onClick}
        {...other}
        classes={{ root: classes.root, label: classes.label }}
        fullWidth={fullWidthButton ? true : false}
      >
        {text}
      </MuiButton>
    ) : (
      <MuiButton
        disabled
        fullWidth={fullWidthButton ? true : false}
        color={color || "primary"}
        size={size || "small"}
        classes={{ root: classes.buttonLoading, label: classes.label }}
        // style={}
      >
        <CircularProgress className={classes.circularProgress} size={15} />
        {text}
      </MuiButton>
    )
  ) : (
    <MuiButton
      color={color || "primary"}
      variant={variant || "contained"}
      size={size || "small"}
      onClick={onClick}
      {...other}
      classes={{ root: classes.root, label: classes.label }}
    >
      {text}
    </MuiButton>
  );
};

Button.defaultProps = {
  margin: true,
  borderRadius: false,
  padding: true,
};

export default Button;
