import React from "react";
import {
  LocalizationProvider,
  DateRangePicker,
  DateRangeDelimiter,
} from "@material-ui/pickers";
import DateFnsUtils from "@date-io/date-fns";
import { TextField } from "@material-ui/core";

const CDateRangePicker = (props) => {
  const {
    name,
    label,
    value,
    onChange,
    disableToolbar,
    maxDate,
    inputVariant,
    fullWidth,
  } = props;
  const convertToDefaultEventParameter = (name, value) => ({
    target: {
      name,
      value,
    },
  });
  return (
    <LocalizationProvider utils={DateFnsUtils}>
      <DateRangePicker
        startText="Check-in"
        endText="Check-out"
        disableToolbar={disableToolbar}
        variant="normal"
        fullWidth={fullWidth}
        inputVariant={inputVariant || "standard"}
        size="small"
        label={label}
        format="dd-MMM-yyyy"
        name={name}
        value={value}
        maxDate={maxDate}
        onChange={(date) =>
          onChange(convertToDefaultEventParameter(name, date))
        }
        renderInput={(startProps, endProps) => (
          <>
            <TextField {...startProps} />
            <DateRangeDelimiter> to </DateRangeDelimiter>
            <TextField {...endProps} />
          </>
        )}
        KeyboardButtonProps={{
          "aria-label": "change date",
        }}
      />
    </LocalizationProvider>
  );
};

export default CDateRangePicker;

// import {
//   KeyboardDatePicker,
//   MuiPickersUtilsProvider,
// } from "@material-ui/pickers";
// import React from "react";
// import DateFnsUtils from "@date-io/date-fns";

// const DatePicker = ({
//   name,
//   label,
//   value,
//   onChange,
//   disableToolbar,
//   maxDate,
//   placeholder,
// }) => {
//   return (
//     <div>
//       <MuiPickersUtilsProvider utils={DateFnsUtils}>
//         <KeyboardDatePicker
//           name={name}
//           disableToolbar={disableToolbar}
//           clearable
//           label={label}
//           maxDate={maxDate}
//           inputVariant="outlined"
//           value={value}
//           placeholder={placeholder}
//           // onChange={(date) => handleDateChange(date)}
//           onChange={onChange}
//           minDate={new Date()}
//           format="dd-MMM-yyyy"
//         />
//       </MuiPickersUtilsProvider>
//     </div>
//   );
// };

// export default DatePicker;
