/* eslint-disable jsx-a11y/no-autofocus */
import { useEffect } from "react";
import { Grid, Typography } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import { useFormikContext, Formik, Form, Field } from "formik";
import Cookies from "js-cookie";
import { useStyles } from "./utils";
import { validateCoupon } from "@/redux/actions/mobile.recharge.actions";
import Controls from "../Controls/Controls";
import {
  CLEAR_COUPON_ERROR,
  RESET_COUPON,
} from "@/redux/constants/mobile.recharge.constants";
import { useWindowSize } from "@/hooks/useWindowSize";
import { capitalize } from "utils/customFunctions";

const AutoSubmitToken = () => {
  // Grab values and submitForm from context
  const dispatch = useDispatch();
  const { values, submitForm } = useFormikContext();
  const { data: couponData } = useSelector((state) => state.couponCode);

  useEffect(() => {
    // Submit the form imperatively as an effect as soon as form values.token are 6 digits long
    if (couponData.status === false) {
      submitForm();
      Cookies.remove("cpn");
      dispatch({ type: CLEAR_COUPON_ERROR });
      dispatch({ type: RESET_COUPON });
    }
  }, [dispatch, couponData.status, submitForm]);
  return null;
};
export const couponCode = (state) => state.couponCode;
const CouponCode = () => {
  const classes = useStyles();
  const dispatch = useDispatch();
  const { width: windowWidth } = useWindowSize();
  const regId = Cookies.get("regId");
  const { plan } = useSelector((state) => state.mobilePlan);
  const { data: couponData } = useSelector((state) => state.couponCode);
  const { categories } = useSelector((state) => state.category);
  const operator_type = plan.operator_type;
  const capitalOperatorType = capitalize(operator_type);
  const getOperator = () => {
    if (capitalOperatorType?.indexOf("-") === -1) {
      return capitalize(capitalOperatorType);
    } else {
      return capitalize(capitalOperatorType?.replace("-", " "));
    }
  };
  const op = getOperator();
  const operator = categories.find((cat) => {
    return cat.serviceTypeName === op;
  })?.serviceId;

  return (
    <div>
      <Formik
        initialValues={{ couponCode: "" }}
        validate={(values) => {
          const errors = {};
          if (couponData.status === false) {
            errors.couponCode = couponData.message;
          }
          if (values.couponCode === "") {
            errors.couponCode = "Please Enter a coupon Code";
          }

          return errors;
        }}
        onSubmit={(values) => {
          const couponData = {
            amount: !plan.bbps
              ? plan?.recharge_amount
              : plan?.bill_details?.totalAmount * 0.01,
            // amount: !plan.bbps ? plan?.recharge_amount : 10000,
            userid: regId,
            cpn: values.couponCode,
            serviceType: !plan.bbps ? plan.recharge_type : "BBPS Services",
            operator: !plan.bbps ? plan.oprCode : `${operator}`,
          };
          dispatch(validateCoupon(couponData));
          Cookies.set("cpn", values.couponCode);
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          handleChange,
          touched,
          errors,
          setErrors,
        }) => {
          return (
            <Form onSubmit={handleSubmit}>
              <Grid container>
                <Grid item xs={12}>
                  <Typography variant="h5" className={classes.heading}>
                    Coupon Code
                  </Typography>
                </Grid>
                <Grid item sm={10} xs={12}>
                  <Field
                    component={Controls.Input}
                    fullWidth={true}
                    value={values.couponCode}
                    onChange={(e) =>
                      setFieldValue("couponCode", e.target.value)
                    }
                    error={touched.couponCode && Boolean(errors.couponCode)}
                    helperText={touched.couponCode && errors.couponCode}
                    name="couponCode"
                    label="Coupon Code"
                    placeholder="Enter Coupon Code"
                    autoFocus={true}
                  />
                </Grid>
                <Grid
                  item
                  sm={2}
                  xs={12}
                  style={
                    windowWidth <= 600
                      ? {
                          display: "flex",
                          justifyContent: "center",
                          width: "100%",
                          marginTop: 16,
                        }
                      : null
                  }
                >
                  <Controls.Button
                    fullWidth={windowWidth <= 600 ? true : false}
                    text="Apply"
                    type="submit"
                    padding={false}
                    // onClick={() => alert(mbl)}
                  />
                </Grid>
                {/* </div> */}
              </Grid>
              <AutoSubmitToken />
            </Form>
          );
        }}
      </Formik>
    </div>
  );
};

export default CouponCode;
