/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
import { useWindowSize } from "@/hooks/useWindowSize";
import { openModal } from "@/redux/actions/modal.actions";
import { Button, Divider, Grid, Typography } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import { capitalize } from "utils/customFunctions";
import ModalExample from "../Layout/Modal/ModalExample";
import CouponCode from "@/components/CouponCode";
import _ from "lodash";
import { FaTimes } from "react-icons/fa";
import { ArrowBack as ArrowBackIcon } from "@material-ui/icons";
import { useStyles } from "./utils";
import Controls from "../Controls/Controls";
import PageHeader from "../PageHeader";
import { RESET_COUPON } from "@/redux/constants/mobile.recharge.constants";
import Cookies from "js-cookie";
import axios from "axios";
import { getWalletBalance } from "@/redux/actions/passbook.action";
import Image from "next/image";
import api from "@/redux/config/api.main";

import { useWarnIfUnsavedChanges } from "@/hooks/useWarnIfUnsavedChanges";
import { useEffect, useState } from "react";
import GeneralBreadcrumbs from "../GeneralBreadcrumbs";
import { toast } from "react-toastify";
import { useRouter } from "next/router";
import { billPayment } from "@/redux/actions/bbps.actions";
import BillPaidComponent from "@/screens/BillPaidComponent";

const CouponConfirm = () => {
  const { width: windowWidth } = useWindowSize();
  const classes = useStyles({ windowWidth });
  const {
    plan: {
      recharge_type,
      recharge_amount,
      Operator: operator_name,
      Circle: circle,
      mbl: mobile,
      oprCode,
      bbps,
      billerInfo,
      bill_details,
      fields,
      operator_type,
    },
  } = useSelector((state) => state.mobilePlan);
  const { data: CouponData } = useSelector((state) => state.couponCode);
  const { loadingButton, warningOnRefresh } = useSelector(
    (state) => state.billPay
  );
  const { wallet_balance } = useSelector((state) => state.passbook);
  const { userInfo } = useSelector((state) => state.myProfile);
  const operator_name_capital = capitalize(operator_name);
  const recharge_type_capital = capitalize(recharge_type);
  const [changeWarning, setChangeWarning] = useState(true);
  const [loadingRecharge, setLoadingRecharge] = useState(false);
  const dispatch = useDispatch();
  const router = useRouter();
  const resetCoupon = () => {
    dispatch({ type: RESET_COUPON });
    Cookies.remove("cpn");
  };
  const amountToAdd = !bbps
    ? Math.abs(wallet_balance - recharge_amount)
    : Math.abs(wallet_balance - bill_details?.billAmount * 0.01);
  function loadScript(src) {
    return new Promise((resolve) => {
      const script = document.createElement("script");
      script.src = src;
      script.onload = () => {
        resolve(true);
      };
      script.onerror = () => {
        resolve(false);
      };
      document.body.appendChild(script);
    });
  }

  async function displayRazorpay() {
    try {
      const res = await loadScript(
        "https://checkout.razorpay.com/v1/checkout.js"
      );

      if (!res) {
        alert("Razorpay SDK failed to load. Are you online?");
        return;
      }

      // creating a new order
      const reg_id = Cookies.get("regId").trim();
      const mbl = Cookies.get("mobile").trim();

      const result = await axios.post(
        `https://aaipay.in:10002/api/apps/v1/create_order.jsp?mbl=${mbl}&amount=${amountToAdd}&regId=${reg_id}`,
        {
          headers: { "content-type": "application/json" },
        }
      );
      console.log("result", result);
      const order_id = await result.data.razorpayId.trim();
      console.log(order_id);
      // Getting the order details back
      console.log(`Order details`, result.data, recharge_amount);
      const options = {
        key: process.env.RAZORPAY_KEY_ID_PROD, // Enter the Key ID generated from the Dashboard
        amount: amountToAdd,
        currency: "INR",
        name: "Aaipay-Pay with Faith",
        description: "Add Money to Wallet",
        image: "/assets/images/logos/logo.png",
        order_id: order_id,
        handler: async function (response) {
          const data = {
            orderCreationId: order_id,
            razorpayPaymentId: response.razorpay_payment_id,
            razorpayOrderId: response.razorpay_order_id,
            razorpaySignature: response.razorpay_signature,
            amount: amountToAdd.toString(),
            currency: "INR",
          };
          const resultB = await axios.get(
            `https://aaipay.in:10002/api/apps/v1/create_order_payment_gateway.jsp?reg=${reg_id}&amount=${amountToAdd}&mbl=${mbl}&razorpayOrderId=${response.razorpay_order_id}`
          );
          console.log(resultB, "resultB");
          const { status, err_code } = resultB;
          const paymentGateWayEntry = async () => {
            const result = await axios.post(
              `https://aaipay.in:10002/api/apps/v1/payemntGatway_entry.jsp?reg=${reg_id}&amount=${amountToAdd}&mbl=${mbl}&razorpayOrderId=${response.razorpay_order_id}&paymentStatus=${status}&razorpay_payment_id=${response.razorpay_payment_id}&error=""`,
              data
            );
            return result;
          };
          const creditAmount = async (resultGateEntry) => {
            try {
              const entry = await resultGateEntry.data.entry_id;
              console.log(entry);
              const resultC = await axios.post(
                `https://aaipay.in:10002/api/apps/v1/credit_amount.jsp?cust_reg=${reg_id}&amount=${amountToAdd}&mobile=${mbl}&razorPay_orderID=${response.razorpay_order_id}&razorpay_payment_id=${response.razorpay_payment_id}&tid=${entry}`,
                {
                  headers: {
                    "content-type": "application/json",
                  },
                }
              );
              return resultC;
            } catch (error) {
              console.error(error);
            }
          };
          await paymentGateWayEntry();
          await creditAmount(resultB);
          err_code === 123 && paymentGateWayEntry();
          dispatch(getWalletBalance({ mbl, reg_id }));
          // dispatch(getPassBook({ mbl, reg_id }));
          // dispatch(
          //   setAlertMessage(
          //     true,
          //     "success",
          //     `₹ ${amountToAdd} added to the wallet successfully`
          //   )
          // );
          toast.success(`₹ ${amountToAdd} added to the wallet successfully`, {
            position: "top-center",
            autoClose: 5000,
            hideProgressBar: false,
            closeOnClick: true,
            pauseOnHover: true,
            draggable: true,
            progress: undefined,
          });
          // if (window.location.href !== `${window.location.origin}/mobile`) {
          //   // Redirect logic
          //   setTimeout(() => {
          //     window.location.replace("/mobile");
          //     localStorage.removeItem("amount");
          //   }, 3000);
          // }
        },

        prefill: {
          name: userInfo.Name,
          email: userInfo.Email,
          contact: mbl,
        },
        notes: {
          address: "Soumya Dey Corporate Office",
        },
        theme: {
          color: "#46A7E4",
        },
      };

      const paymentObject = new window.Razorpay(options);
      paymentObject.open();
    } catch (error) {
      console.log(error?.response?.data, "error random custom");
    }
  }
  const regId = Cookies.get("regId");
  const reg_mobile = Cookies.get("mobile");
  const proceedToRecharge = async () => {
    try {
      setLoadingRecharge(true);
      const { data } = await api.get(
        `utility_recharge.jsp?reg_mbl=${reg_mobile}&mobno=${mobile}&operator=${oprCode}&reg=${regId}&amount=${recharge_amount}`
      );

      if (data.status !== "FAILED") {
        await api.get(
          `cashBack_credit.jsp?transID=${data.transID}&username=${regId}&reg_mobile=${reg_mobile}&cashbackID=${CouponData?.cashBackID}`
        );
        dispatch(getWalletBalance({ mbl: reg_mobile, reg_id: regId }));
        toast.success(`Recharge of ₹${recharge_amount} is completed`, {
          position: "top-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
        });
        setLoadingRecharge(false);
        setChangeWarning(false);
        if (window.location.href !== `${window.location.origin}/mobile`) {
          // Redirect logic
          setTimeout(() => {
            window.location.href = "/mobile";
            Cookies.remove("plan");
            Cookies.remove("cpn");
          }, 3000);
        }
      } else {
        // dispatch(setAlertMessage(true, "error", `${data.res_msg}`));
        toast.error(`${capitalize(data.res_msg)}`, {
          position: "top-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
        });
        setChangeWarning(false);
        setLoadingRecharge(false);
      }

      console.log(data);
    } catch (error) {
      console.log(error?.response?.data.message, "error random custom");
    }
  };

  const proceedToPayBill = () => {
    const billerId = billerInfo.billerId;
    const customerMobile = Cookies.get("mobile");
    const userId = Cookies.get("regId");
    const billerResponse = bill_details.billerResponse;
    const addtionalInfo = bill_details.addtionalInfo;
    const requestId = bill_details.requestId;
    const pymtModeQuick =
      billerInfo.billFetchRequired === "MANDATORY" ? "N" : "Y";
    const amt = bill_details.totalAmount;
    const billerAdhoc = billerInfo.billerAdhoc;
    const marginAmount = bill_details.marginAmount;

    const billPayDetails = {
      billerId,
      customerMobile,
      userId,
      billerResponse,
      addtionalInfo,
      requestId,
      pymtModeQuick,
      amt,
      billerAdhoc,
      marginAmount,
    };
    dispatch(billPayment(billPayDetails));
  };
  const remainingWallet = () => {
    const billAmount = bill_details?.totalAmount * 0.01;
    if (bbps === true) {
      if (wallet_balance - billAmount > 0) {
        return wallet_balance - billAmount;
      } else {
        return 0;
      }
    } else {
      if (wallet_balance - recharge_amount > 0) {
        return wallet_balance - recharge_amount;
      } else {
        return 0;
      }
    }
  };
  const proceedToPayDummy = () => {
    setChangeWarning(false);
    dispatch(
      openModal({
        modalType: ModalExample,
        modalProps: {
          component: <BillPaidComponent />,
          open: true,
          // setOpen: setOpen,
          widthDrawer: 800,
          closeDrawerAction: false,
        },
      })
    );
  };
  useEffect(() => {
    if (typeof warningOnRefresh !== "undefined") {
      setChangeWarning(warningOnRefresh);
    }
  }, [setChangeWarning, warningOnRefresh]);
  useWarnIfUnsavedChanges(changeWarning);
  const billAmount = bill_details?.totalAmount * 0.01;
  return (
    <>
      <div className={classes.root}>
        <Button
          variant="outlined"
          color="primary"
          size="small"
          className={classes.button}
          startIcon={<ArrowBackIcon />}
          onClick={() => router.back()}
        >
          Back
        </Button>
        <GeneralBreadcrumbs />
        <PageHeader title="Payment Details" />
        <Grid container spacing={4}>
          <Grid item xs={12} md={4} sm={12}>
            {!bbps ? (
              <Typography
                variant="h2"
                className={classes.recharge_quote}
                component="div"
              >
                {`Recharge of ${operator_name_capital} ${recharge_type_capital} ${mobile} for`}
                <strong>{` Rs. ${recharge_amount}`}</strong>
              </Typography>
            ) : (
              <div className={classes.amountContainer}>
                <div className={classes.amount}>
                  <Typography
                    className={classes.amount_head}
                    component="div"
                    variant="subtitle2"
                    style={{ marginBottom: 16 }}
                  >
                    {`${capitalize(
                      operator_type?.replace("-", " ")
                    )} Bill Payment`}
                  </Typography>
                  <Typography
                    variant="body2"
                    className={classes.biller_placeholder}
                    component="span"
                  >
                    <Image
                      src="/assets/images/Bharat-BillPay-Final-Logo.jpg"
                      alt="Bharat BillPay"
                      width="65"
                      height="22"
                    />
                  </Typography>
                </div>
                <div className={classes.amount}>
                  <Typography
                    variant="body2"
                    className={classes.amount_head}
                    component="span"
                  >
                    Biller Name
                  </Typography>
                  <Typography
                    variant="body2"
                    className={classes.biller_placeholder}
                    component="span"
                  >
                    {billerInfo?.billerName}
                  </Typography>
                </div>
                <Divider className={classes.divider} />

                {bill_details?.customerName !== "NA" && (
                  <>
                    <div className={classes.amount}>
                      <Typography
                        variant="body2"
                        className={classes.amount_head}
                        component="span"
                      >
                        Customer Name
                      </Typography>
                      <Typography
                        variant="body2"
                        className={classes.biller_placeholder}
                        component="span"
                      >
                        {bill_details?.customerName}
                      </Typography>
                    </div>
                    <Divider className={classes.divider} />
                  </>
                )}
                {fields?.length > 0 &&
                  fields?.map(
                    (field, index) =>
                      bill_details[`${field?.paramName}`] && (
                        <div key={index}>
                          <div className={classes.amount}>
                            <Typography
                              variant="body2"
                              className={classes.amount_head}
                              component="span"
                            >
                              {field?.paramName}
                            </Typography>
                            <Typography
                              variant="body2"
                              className={classes.biller_placeholder}
                              component="span"
                            >
                              {bill_details[`${field?.paramName}`]}
                            </Typography>
                          </div>
                          <Divider className={classes.divider} />
                        </div>
                      )
                  )}
              </div>
            )}
          </Grid>
          <Grid item xs={12} md={4} sm={12}>
            {_.isEmpty(CouponData) || CouponData.status === false ? (
              <Typography
                variant="body1"
                className={classes.promo_link}
                component="p"
                onClick={() =>
                  dispatch(
                    openModal({
                      modalType: ModalExample,
                      modalProps: {
                        component: <CouponCode />,
                        open: true,
                        noFullScreen: true,
                        maxWidth: "sm",
                        widthDrawer: 800,
                        closeDrawerAction: true,
                        titleBackground: "#EFF3FB",
                        fullScreenAt: "sm",
                      },
                    })
                  )
                }
              >
                Have a Coupon Code ?
              </Typography>
            ) : (
              <div className={classes.promoLinkContained}>
                <div className={classes.couponDetails}>
                  <div>
                    <span
                      style={{ textTransform: "uppercase", fontWeight: "bold" }}
                    >
                      {CouponData.cpn}{" "}
                    </span>
                  </div>
                  <div>
                    <Typography
                      variant="body2"
                      className={classes.coupon_quote}
                      component="div"
                    >
                      Cashback: Rs. {parseFloat(CouponData.cashback).toFixed(2)}
                    </Typography>
                    <Typography
                      variant="body2"
                      className={classes.coupon_quote}
                      component="div"
                    >
                      <span
                        style={{
                          textTransform: "uppercase",
                          fontWeight: "bold",
                        }}
                      >
                        {CouponData.cpn}{" "}
                      </span>
                      Promocode Applied!
                    </Typography>
                  </div>
                </div>
                <div className={classes.cross} onClick={resetCoupon}>
                  <FaTimes />
                </div>
              </div>
            )}
          </Grid>
          <Grid item xs={12} md={4} sm={12}>
            <div className={classes.amountContainer}>
              <div className={classes.amount}>
                <Typography
                  variant="body2"
                  className={classes.amount_head}
                  component="span"
                >
                  Wallet Money
                </Typography>
                <Typography
                  variant="body2"
                  className={classes.amount_placeholder}
                  component="span"
                >
                  Rs. {wallet_balance}
                </Typography>
              </div>
              <Divider className={classes.divider} />
              <div className={classes.amount}>
                <Typography
                  variant="body2"
                  className={classes.amount_head}
                  component="span"
                >
                  To be Paid
                </Typography>
                <Typography
                  variant="body2"
                  className={classes.amount_placeholder}
                  component="span"
                >
                  Rs. {bbps === true ? billAmount : recharge_amount}
                </Typography>
              </div>
              <Divider className={classes.divider} />
              <div className={classes.amount}>
                <Typography
                  variant="body2"
                  className={classes.amount_head}
                  component="span"
                >
                  Remaining Amount in Wallet
                </Typography>
                <Typography
                  variant="body2"
                  className={classes.amount_placeholder}
                  component="span"
                >
                  Rs. {remainingWallet()}
                </Typography>
              </div>
              <Divider className={classes.divider} />
              {/* {toAddInWallet()} */}
              {wallet_balance - billAmount <= 0 ||
              wallet_balance - recharge_amount <= 0 ? (
                <>
                  <div className={classes.amount}>
                    <Typography
                      variant="body2"
                      className={classes.amount_head}
                      component="span"
                    >
                      Amount to put into the Wallet
                    </Typography>
                    <Typography
                      variant="body2"
                      className={classes.amount_placeholder}
                      component="span"
                    >
                      Rs. {parseFloat(amountToAdd).toFixed(2)}
                    </Typography>
                  </div>
                  <Divider className={classes.divider} />
                </>
              ) : null}
            </div>
          </Grid>

          {bbps === true ? (
            <Grid item xs={12} md={4} sm={12}>
              <Controls.Button
                text={
                  wallet_balance - bill_details.totalAmount * 0.01 >= 0
                    ? `Proceed To Pay`
                    : `Pay  ₹${parseFloat(amountToAdd).toFixed(2)}`
                }
                fullWidthButton={true}
                loadingIndicator={true}
                loadingButton={loadingButton}
                margin={false}
                borderRadius={true}
                onClick={
                  wallet_balance - bill_details.totalAmount * 0.01 >= 0
                    ? proceedToPayBill
                    : displayRazorpay
                }
              />
            </Grid>
          ) : (
            <Grid item xs={12} md={4} sm={12}>
              <Controls.Button
                text={
                  wallet_balance - recharge_amount >= 0
                    ? `Proceed To Recharge`
                    : `Pay  ₹${parseFloat(amountToAdd).toFixed(2)}`
                }
                fullWidthButton={true}
                loadingIndicator={true}
                loadingButton={loadingRecharge}
                margin={false}
                borderRadius={true}
                onClick={
                  wallet_balance - recharge_amount >= 0
                    ? proceedToRecharge
                    : displayRazorpay
                }
              />
            </Grid>
          )}
         
        </Grid>
      </div>
    </>
  );
};

export default CouponConfirm;
