import React from "react";
import PropTypes from "prop-types";
import _ from "lodash";
import {
  Breadcrumbs as MUIBreadcrumbs,
  colors,
  Link,
  makeStyles,
  Typography,
} from "@material-ui/core";
import { useRouter } from "next/router";

const useStyles = makeStyles((theme) => ({
  root: {
    padding: theme.spacing(2, 0, 2, 0),
  },
  link: {
    color: colors.blue[600],
    cursor: "pointer",
    fontSize: 14,
    textTransform: "capitalize",
  },
  disabledItem: {
    color: colors.grey[500],
    textTransform: "capitalize",
    fontSize: 14,
  },
  linkLast: {
    color: colors.grey[500],
    textTransform: "capitalize",
    fontSize: 14,
  },
}));
const GeneralBreadcrumbs = ({ disabledItems }) => {
  const router = useRouter();
  const classes = useStyles();
  const { asPath, query } = router;
  const pathnames = router.pathname.split("/").filter((x) => x);

  return (
    <div className={classes.root}>
      <MUIBreadcrumbs separator="›" aria-label="breadcrumb">
        {pathnames.length > 0 ? (
          <Link className={classes.link} onClick={() => router.push("/mobile")}>
            Home
          </Link>
        ) : (
          <Typography variant="body2"> Home </Typography>
        )}
        {pathnames.map((name, index) => {
          let routeTo = `/${pathnames.slice(0, index + 1).join("/")}`;

          const isLast = index === pathnames.length - 1;
          return isLast ? (
            <Typography className={classes.linkLast} variant="body2" key={name}>
              {name.replace("-", " ")}
            </Typography>
          ) : (
            <Link
              className={classes.link}
              key={name}
              onClick={() => router.push(routeTo)}
            >
              {name.replace("-", " ")}
            </Link>
          );
        })}
      </MUIBreadcrumbs>
    </div>
  );
};

// Breadcrumbs.propTypes = {
//   disabledItems: PropTypes.array.isRequired,
// };

export default GeneralBreadcrumbs;
