/* eslint-disable jsx-a11y/anchor-is-valid */
import {
  Avatar,
  Button,
  Divider,
  Grid,
  List,
  ListItem,
  ListItemIcon,
  ListItemText,
  makeStyles,
  Typography,
} from "@material-ui/core";
import {
  Folder,
  Mail,
  PersonOutline as PersonOutlineIcon,
  PowerSettingsNew as PowerSettingsNewIcon,
} from "@material-ui/icons";

import _ from "lodash";
import Image from "next/image";
import { useRouter } from "next/router";
import { menuData as listItems } from "@/config/menuData";
// import logo from "@/images/logos/logo.png";
import ActiveLink from "@/components/ActiveLink";
import { useDispatch, useSelector } from "react-redux";

import { closeDrawer, openDrawer } from "@/redux/actions/drawer.actions";

import {
  RESET_OTP_STATUS,
  RESET_REGISTER_STATUS,
} from "@/redux/constants/auth.constants";
import { logout } from "@/redux/actions/auth.actions";

import MyProfileComponent from "@/screens/MyProfile/MyProfileComponent";
import LoginComponent from "@/screens/LoginComponent";
import ModalExample from "./ModalExample";

const useStyles = makeStyles((theme) => ({
  wrapper: {
    width: 266,
    display: "flex",
    justifyContent: "center",
  },
  container: {
    width: 266,
    padding: theme.spacing(2, 0, 0, 2),
    overflow: "hidden",
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
  },
  logo: {
    width: 266,
    padding: theme.spacing(2, 0, 0, 4),
  },
  list: {
    width: 250,
  },
  fullList: {
    width: "auto",
  },
  buttons: {
    display: "flex",
    justifyContent: "space-between",
    alignItems: "center",
    width: 250,
    flexDirection: "column",
    flexWrap: "wrap",
  },
  btn: {
    margin: theme.spacing(1),
  },
  imageLogo: {
    cursor: "pointer",
  },
  loginButtonContainer: {
    paddingTop: 16,
    paddingBottom: 16,
    paddingLeft: 16,
    // paddingRight: 16,
    marginRight: -16,
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    width: "266px",
    // backgroundColor: theme.palette.secondary.main,
  },
  loginButtonContainerLoggedIn: {
    paddingTop: 16,
    paddingBottom: 16,
    paddingLeft: 0,
    paddingRight: 16,
    // marginRight: -16,
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    width: "266px",
    flexDirection: "row",
    // backgroundColor: theme.palette.secondary.main,
  },
  profileButton: {
    paddingTop: 8,
    paddingBottom: 16,
    paddingLeft: 16,
    paddingRight: 16,
    // marginRight: -16,
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    width: "266px",
    flexDirection: "column",
    // backgroundColor: theme.palette.secondary.main,
  },
}));
const DrawerList = ({ setOpen }) => {
  const router = useRouter();

  const dispatch = useDispatch();
  const classes = useStyles();
  const { userInfo } = useSelector((state) => state.myProfile);
  return (
    <>
      <div className={classes.wrapper}>
        <div className={classes.container}>
          <div className={classes.logo}>
            <Image
              src="/assets/images/logos/logo.png"
              alt="Aaipay : Pay With Faith"
              width={160}
              height={50}
              className={classes.imageLogo}
              onClick={(e) => {
                e.preventDefault();
                router.push("/mobile");
              }}
            />
          </div>
        </div>
      </div>

      <div className={classes.buttons}>
        {userInfo && !_.isEmpty(userInfo) ? (
          <>
            <div
              // style={{
              //   display: "flex",
              //   justifyContent: "flex-start",
              //   alignItems: "center",
              //   width: 250,
              //   paddingRight: theme.spacing(2),
              //   paddingLeft: theme.spacing(2),
              //   marginTop: 20,
              // }}
              className={classes.loginButtonContainerLoggedIn}
            >
              <Avatar style={{ marginRight: 10, height: 32, width: 32 }}>
                <PersonOutlineIcon color="primary" style={{ fontSize: 20 }} />
              </Avatar>
              <div onClick={() => console.log(userInfo)} aria-hidden="true">
                <Typography
                  style={{
                    fontSize: 14,
                    textTransform: "capitalize",
                    fontWeight: 500,
                  }}
                >
                  {userInfo.Name}
                </Typography>
              </div>
            </div>
            <div className={classes.profileButton}>
              <Button
                variant="contained"
                color="primary"
                fullWidth={true}
                style={{ width: "80%" }}
                // onClick={() => {
                //   dispatch(closeDrawer({ modalProps: { open: false } }));
                //   dispatch(
                //     openDrawer({
                //       modalType: ModalExample,
                //       modalProps: {
                //         component: <MyProfileComponent userInfo={userInfo} />,
                //         open: true,
                //         widthDrawer: 800,
                //         title: "My Profile",
                //         closeDrawerAction: true,
                //       },
                //     })
                //   );
                // }}
              >
                Complete KYC
              </Button>
            </div>
          </>
        ) : (
          <div className={classes.loginButtonContainer}>
            <Button
              variant="contained"
              color="primary"
              onClick={() => {
                dispatch(
                  openDrawer({
                    modalType: ModalExample,
                    modalProps: {
                      component: <LoginComponent />,
                      open: true,

                      widthDrawer: 800,
                      title: "Login",
                      closeDrawerAction: true,
                    },
                  })
                );
                dispatch({ type: RESET_OTP_STATUS });
                dispatch({ type: RESET_REGISTER_STATUS });
              }}
            >
              Log in | Sign Up
            </Button>
          </div>
        )}
      </div>
      <Divider />
      <List className={classes.fullList}>
        {/* {_.isEmpty(userInfo) &&
          listItems.map((item) => (
            <ListItem button key={item.id} className={classes.list}>
              {" "}
              <style jsx>{`
                .nav-link {
                  text-decoration: none;
                }

                .active {
                  font-weight: 600;
                }
              `}</style>
              <ListItemIcon>
                <Mail />
              </ListItemIcon>
              <ActiveLink
                href={item.href}
                onClick={() =>
                  dispatch(
                    closeDrawer({
                      modalProps: {
                        open: false,
                      },
                    })
                  )
                }
                activeclassname="active"
              >
                <span href={item.href}>{item.name}</span>
              </ActiveLink>
            </ListItem>
          )
          )} */}
        {_.isEmpty(userInfo)
          ? listItems
              .filter((item) => {
                return item.authenticatedRoute === false;
              })
              .map((selList) => (
                <ListItem button key={selList.id} className={classes.list}>
                  {" "}
                  <style jsx>{`
                    .nav-link {
                      text-decoration: none;
                    }

                    .active {
                      font-weight: 600;
                    }
                  `}</style>
                  <ListItemIcon>{selList?.icon}</ListItemIcon>
                  <ActiveLink
                    href={selList.href}
                    onClick={() =>
                      dispatch(
                        closeDrawer({
                          modalProps: {
                            open: false,
                          },
                        })
                      )
                    }
                    activeclassname="active"
                  >
                    <span href={selList.href}>{selList.name}</span>
                  </ActiveLink>
                </ListItem>
              ))
          : listItems.map((selList) => (
              <ListItem button key={selList.id} className={classes.list}>
                <style jsx>{`
                  .nav-link {
                    text-decoration: none;
                  }

                  .active {
                    font-weight: 600;
                  }
                `}</style>
                <ListItemIcon>{selList?.icon}</ListItemIcon>
                <ActiveLink
                  href={selList.href}
                  onClick={() =>
                    dispatch(
                      closeDrawer({
                        modalProps: {
                          open: false,
                        },
                      })
                    )
                  }
                  activeclassname="active"
                >
                  <span href={selList.href}>{selList.name}</span>
                </ActiveLink>
              </ListItem>
            ))}
        {!_.isEmpty(userInfo) ? (
          <ListItem
            button
            style={{ cursor: "pointer" }}
            className={classes.list}
            onClick={() => {
              dispatch(logout());
              dispatch(closeDrawer({ modalProps: { open: false } }));
              setTimeout(() => {
                if (
                  window.location.href !== `${window.location.origin}/mobile`
                ) {
                  // Redirect logic
                  setTimeout(() => {
                    window.location.href = "/mobile";
                  }, 3000);
                }
              }, 1000);
            }}
          >
            <ListItemIcon>
              <PowerSettingsNewIcon />
            </ListItemIcon>
            <ListItemText primary="Log Out" />
          </ListItem>
        ) : null}
      </List>
    </>
  );
};

export default DrawerList;
