import Drawer from "@material-ui/core/Drawer";
import { useSelector, useDispatch } from "react-redux";
import { closeDrawer } from "@/redux/actions/drawer.actions";
import {
  CSSTransition,
  SwitchTransition,
  TransitionGroup,
} from "react-transition-group";
import { makeStyles, Typography } from "@material-ui/core";

import { useWindowSize } from "@/hooks/useWindowSize";
import { useEffect, useState } from "react";
import Controls from "@/components/Controls/Controls";
import { Close as CloseIcon } from "@material-ui/icons";
import ModalExample from "./ModalExample";
import { useTheme } from "@material-ui/styles";
// Styels

const useStyles = makeStyles((theme) => ({
  listTransitionEnter: {
    transform: (props) =>
      props && props.windowWidth < 768
        ? `-${100}vw`
        : `translateX(-${props.drawerWidth}px)`,
    transitionTimingFunction: "linear",
    transition: `transform 300ms`,
  },
  listTransitionEnterActive: {
    transform: `translateX(${0}px)`,
    transition: `transform 300ms`,
  },
  listTransitionExit: {
    transform: `translateX(${0}px)`,
    transitionTimingFunction: "linear",
  },
  listTransitionExitActive: {
    // transform: (props) =>
    //   props && props.drawerWidth > props.windowWidth
    //     ? `translateX(${props.drawerWidth}px)`
    //     : `translateX(${100}vw)`,
    transform: (props) =>
      props && props.windowWidth < 768
        ? `${100}vw`
        : `translateX(${props.drawerWidth}px)`,
    transitionTimingFunction: "linear",
    transition: `transform 300ms`,
  },
  /*   -webkit-transition: transform 200ms;
    -webkit-transition: -webkit-transform 200ms */
  // mainContent: {
  //   width: width > 600 ? `70vw` : `100vw`,
  //   padding: 16,
  // },
  drawerTitle: {
    paddingRight: "0px",
    paddingLeft: "10px",
    display: "flex",
    backgroundColor: "#FFFFFF",
  },
  paper: {
    backgroundColor: "#EFF3FB",
  },
  titleBar: {
    backgroundColor: theme.palette.primary.main,
    padding: "5px 5px 5px 16px",
  },
  drawerTitleTypography: {
    flexGrow: 1,
    lineHeight: 3,
    fontSize: "1.2rem",
    fontWeight: 500,
    textTransform: "capitalize",
  },
  actionButton: {
    zIndex: theme.zIndex.drawer - 1,
    // position: 'relative',
    // right: '10px',
  },
}));

// Styles End
const MaterialDrawerRedux = () => {
  const windowWidth = useWindowSize();
  const theme = useTheme();

  const drawerState = useSelector((state) => state.drawer);
  let { modalType, modalProps } = drawerState;
  const { widthDrawer, open, title, btnText, btnFunction, closeDrawerAction } =
    modalProps;
  const classes = useStyles({
    drawerWidth: widthDrawer,
    windowWidth: windowWidth.width,
  });
  const [openDrawer, setOpenDrawer] = useState(open);
  useEffect(() => {
    setOpenDrawer(open);
  }, [open, setOpenDrawer]);
  const toggleDrawer = (anchor, open) => (event) => {
    if (
      event &&
      event.type === "keydown" &&
      (event.key === "Tab" || event.key === "Shift")
    ) {
      return;
    }

    setOpenDrawer({ ...openDrawer, open });
  };
  const dispatch = useDispatch();
  const handleDrawerClose = () => {
    // dispatch(
    //   closeDrawer({
    //     modalProps: { open: false },
    //   })
    // );
    setOpenDrawer(false);
    setTimeout(() => {
      dispatch(
        closeDrawer({
          modalProps: { open: false },
        })
      );
    }, 500);

    // toggleDrawer('right', modalProps.open);
  };

  const SpecificModal = modalType;
  return (
    <>
      {
        <Drawer
          classes={{ paper: classes.paper }}
          anchor={"right"}
          open={openDrawer}
          onClose={handleDrawerClose}
          // BackdropProps={{ invisible: true }}
          // transitionDuration={{ enter: 500, exit: 500 }}
        >
          {closeDrawerAction ? (
            <div className={classes.titleBar}>
              <div className={classes.drawerTitle}>
                <Controls.ActionButton
                  style={{
                    position: "absolute",
                    right: "0px",
                    top: "5px",
                    width: 40,
                    height: 40,
                  }}
                  // color="primary"
                  onClick={() => {
                    setOpenDrawer(false);
                    setTimeout(() => {
                      dispatch(
                        closeDrawer({
                          modalProps: { open: false },
                        })
                      );
                    }, 500);

                    // removeValue && setValues({ removeValue: null });
                  }}
                >
                  <CloseIcon />
                </Controls.ActionButton>
                {/* 
                <Typography
                  variant="h6"
                  component="div"
                  className={classes.drawerTitleTypography}
                >
                  {title}
                </Typography>
                {btnText && (
                  <Controls.Button
                    onClick={btnFunction}
                    text={btnText}
                    style={{
                      height: 40,
                    }}
                  />
                )} */}
              </div>
            </div>
          ) : null}

          {modalType && <SpecificModal {...drawerState} />}
        </Drawer>
      }
    </>
  );
};
export default MaterialDrawerRedux;

/*  <Drawer
      classes={{ paper: classes.paper }}
      anchor="right"
      open={openSlider}
      // onClose={onClose}
      disableBackdropClick={true}
    >
      <div className={classes.titleBar}>
        <div className={classes.drawerTitle}>
          <Controls.ActionButton
            style={{
              position: 'relative',
              left: '-10px',
              top: '5px',
              width: 40,
              height: 40
            }}
            color="secondary"
            onClick={() => {
              setOpenSlider(false);
              // removeValue && setValues({ removeValue: null });
            }}
          >
            <CloseIcon />
          </Controls.ActionButton>
          <Typography
            variant="h6"
            component="div"
            className={classes.drawerTitleTypography}
          >
            {title}
          </Typography>
          {btnText && (
            <Controls.Button
              onClick={btnFunction}
              text={btnText}
              style={{
                height: 40
              }}
            />
          )}
        </div>
      </div>
      <Grid container className={classes.mainContent}>
        <Grid item xs={12}>
          {children}
        </Grid>
      </Grid>
    </Drawer> */
