import {
  AppBar,
  IconButton,
  Toolbar,
  makeStyles,
  Button,
  Hidden,
  Container,
  CssBaseline,
  Typography,
  Grid,
} from "@material-ui/core";
import AccountBalanceWalletOutlinedIcon from "@material-ui/icons/AccountBalanceWalletOutlined";
// import { CgUserList } from "react-icons/cg";
import _ from "lodash";
import { useRouter } from "next/router";
import Image from "next/image";

import logo from "@/images/logos/logo.png";
import { useDispatch, useSelector } from "react-redux";
import { openDrawer } from "@/redux/actions/drawer.actions";
import DrawerList from "../Drawer/DrawerList";
// import MaterialDrawerRedux from "../Drawer/DrawerRedux";
import ModalExample from "../Drawer/ModalExample";
import LoginComponent from "@/screens/LoginComponent";
// import SignUpComponent from "@/components/SignUpComponent";
import {
  RESET_OTP_STATUS,
  RESET_REGISTER_STATUS,
} from "@/redux/constants/auth.constants";
const useStyles = makeStyles(() => ({
  imageLogo: {
    flexGrow: 1,
    cursor: "pointer",
  },
  title: {
    flexGrow: 1,
  },
  logo: {
    width: "100px",
  },
}));
export default function Header({ setOpen }) {
  const dispatch = useDispatch();
  const classes = useStyles();
  const router = useRouter();
  const { userInfo, isAuthenticated, loading } = useSelector(
    (state) => state.myProfile
  );
  const { wallet_balance } = useSelector((state) => state.passbook);

  return (
    <div className={classes.root}>
      <CssBaseline />
      <AppBar position="fixed" color="inherit">
        <Container maxWidth="lg">
          <Toolbar style={{ width: "100%" }}>
            <Grid item xs={4}>
              <Image
                src={logo}
                alt="Aaipay"
                width={130}
                height={40}
                className={classes.imageLogo}
                onClick={(e) => {
                  e.preventDefault();
                  router.push("/mobile");
                }}
              />
            </Grid>
            <Grid item xs={8}>
              <span
                style={{
                  // position: "absolute",
                  // right: 20,

                  display: "flex",
                  alignItems: "center",
                  justifyContent: "flex-end",
                }}
              >
                {isAuthenticated ? (
                  <span
                    style={{
                      // position: "absolute",
                      // right: 20,

                      display: "flex",
                      alignItems: "center",
                      justifyContent: "center",
                      marginRight: "1.5rem",
                    }}
                  >
                    <AccountBalanceWalletOutlinedIcon
                      color="primary"
                      style={{ marginRight: "0.4rem" }}
                    />
                    <Typography variant="subtitle2" color="primary">
                      ₹{wallet_balance}
                    </Typography>
                  </span>
                ) : null}

                <Hidden smDown>
                  {userInfo && !_.isEmpty(userInfo) ? (
                    <Typography
                      variant="subtitle2"
                      component="div"
                      // color="primary"
                      // variant="contained"
                      color="primary"
                      style={{ marginRight: 20, textTransform: "capitalize" }}

                      // style={{ marginRight: 10 }}
                    >
                      Hi , {userInfo.Name.split(" ")[0]}
                    </Typography>
                  ) : (
                    <Button
                      // variant="outlined"
                      // color="primary"
                      variant="contained"
                      color="primary"
                      style={{ marginRight: 20 }}
                      className={
                        _.isEmpty(userInfo) && loading ? `loading` : `loaded`
                      }
                      onClick={() => {
                        dispatch(
                          openDrawer({
                            modalType: ModalExample,
                            modalProps: {
                              component: <LoginComponent />,
                              open: true,
                              // setOpen: setOpen,
                              widthDrawer: 800,
                              title: "Login",
                              closeDrawerAction: true,
                            },
                          })
                        );
                        dispatch({ type: RESET_OTP_STATUS });
                        dispatch({ type: RESET_REGISTER_STATUS });
                      }}
                      // style={{ marginRight: 10 }}
                    >
                      Log in | Sign Up
                    </Button>
                  )}
                </Hidden>

                <IconButton
                  edge="start"
                  className={classes.menuButton}
                  color="inherit"
                  aria-label="menu"
                  // onClick={() => setOpen(true)}
                  onClick={() =>
                    dispatch(
                      openDrawer({
                        modalType: ModalExample,
                        modalProps: {
                          component: <DrawerList />,
                          open: true,
                          // setOpen: setOpen,
                          widthDrawer: 300,
                          closeDrawerAction: false,
                        },
                      })
                    )
                  }
                >
                  {/* <MenuIcon /> */}
                  <Image
                    src="https://res.cloudinary.com/dsklvul34/image/upload/v1636443843/userIcon3_hnwbzz.png"
                    alt=""
                    width="30"
                    height="30"
                  />
                </IconButton>
              </span>
            </Grid>
          </Toolbar>
        </Container>
      </AppBar>
    </div>
  );
}
