import { useSelector, useDispatch } from "react-redux";

import { Dialog, makeStyles, useMediaQuery } from "@material-ui/core";

import { useWindowSize } from "@/hooks/useWindowSize";
import React, { useEffect, useState } from "react";
import Controls from "@/components/Controls/Controls";
import { Close as CloseIcon } from "@material-ui/icons";

import { useTheme } from "@material-ui/styles";

import { closeModal } from "@/redux/actions/modal.actions";

// Styels

const useStyles = makeStyles((theme) => ({
  root: {
    overflowY: "auto",
    overflowX: "hidden",
  },
  listTransitionEnter: {
    opacity: 1,
    transitionTimingFunction: "ease-in-out",
    transition: `opacity 3000ms`,
  },
  listTransitionEnterActive: {
    opacity: 1,
    transition: `opacity 300ms`,
  },
  listTransitionExit: {
    opacity: 0,
    transitionTimingFunction: "ease-in-out",
  },
  listTransitionExitActive: {
    // transform: (props) =>
    //   props && props.drawerWidth > props.windowWidth
    //     ? `translateX(${props.drawerWidth}px)`
    //     : `translateX(${100}vw)`,
    opacity: 1,
    transitionTimingFunction: "ease-in-out",
    transition: `opacity 500ms`,
  },
  /*   -webkit-transition: transform 200ms;
    -webkit-transition: -webkit-transform 200ms */
  // mainContent: {
  //   width: width > 600 ? `70vw` : `100vw`,
  //   padding: 16,
  // },
  drawerTitle: {
    paddingRight: "0px",
    paddingLeft: "10px",
    display: "flex",
    backgroundColor: "#FFFFFF",
  },
  paper: {
    backgroundColor: "#EFF3FB",
  },
  titleBar: {
    backgroundColor: theme.palette.primary.main,
    padding: "5px 5px 5px 16px",
  },
  drawerTitleTypography: {
    flexGrow: 1,
    lineHeight: 3,
    fontSize: "1.2rem",
    fontWeight: 500,
    textTransform: "capitalize",
  },
  actionButton: {
    zIndex: theme.zIndex.drawer - 1,
    // position: "fixed",
    position: "relative",
    right: "10px",
  },
}));

// Styles End
export const modalData = (state) => state.modal;
const MaterialModalRedux = ({ children }) => {
  const windowWidth = useWindowSize();
  const theme = useTheme();

  const modalState = useSelector((state) => state.modal);
  let { modalType, modalProps } = modalState;
  const {
    widthDrawer,
    open,
    title,
    btnText,
    btnFunction,
    closeDrawerAction,
    noFullScreen,
    maxWidth,
    titleBackground,
    fullScreenAt,
  } = modalProps;

  const classes = useStyles({
    drawerWidth: widthDrawer,
    windowWidth: windowWidth.width,
    titleBackground: titleBackground,
  });
  const [openModal, setOpenModal] = useState(open);
  useEffect(() => {
    setOpenModal(open);
  }, [open, setOpenModal]);
  const toggleDrawer = (anchor, open) => (event) => {
    if (
      event &&
      event.type === "keydown" &&
      (event.key === "Tab" || event.key === "Shift")
    ) {
      return;
    }

    setOpenModal({ ...openModal, open });
  };
  const dispatch = useDispatch();
  const handleClose = (event, reason) => {
    setOpenModal(false);

    setTimeout(() => {
      dispatch(
        closeModal({
          modalProps: { open: false },
        })
      );
    }, 250);
  };
  const SpecificModal = modalType;
  // const theme = useTheme();
  const fullScreen = useMediaQuery(
    theme.breakpoints.down(fullScreenAt || "md")
  );
  return (
    <Dialog
      fullScreen={!noFullScreen && fullScreen}
      open={open ?? false}
      fullWidth={true}
      maxWidth={maxWidth || "md"}
      onClose={(event, reason) => {
        if (reason !== "backdropClick" && reason !== "escapeKeyDown") {
          handleClose(event, reason);
        }
      }}
      aria-labelledby="alert-dialog-slide-title"
      aria-describedby="alert-dialog-slide-description"
      // BackdropProps={{ invisible: true }}
      transitionDuration={{ enter: 300, exit: 550 }}
      className={classes.root}
    >
      {closeDrawerAction ? (
        <div className={classes.titleBar}>
          <div className={classes.drawerTitle}>
            <Controls.ActionButton
              style={{
                position: "absolute",
                right: "0px",
                top: "5px",
                width: 40,
                height: 40,
              }}
              // color="primary"
              onClick={() => {
                setOpenModal(false);
                setTimeout(() => {
                  dispatch(
                    closeModal({
                      modalProps: { open: false },
                    })
                  );
                }, 250);
              }}
            >
              <CloseIcon />
            </Controls.ActionButton>
          </div>
        </div>
      ) : null}

      {modalType && <SpecificModal {...modalState} />}
    </Dialog>
  );
};
export default MaterialModalRedux;
