/* eslint-disable jsx-a11y/anchor-is-valid */
import { useRef, useState, useEffect } from "react";
import { AppBar, Toolbar, Container, Grid } from "@material-ui/core";

import ActiveLink from "@/components/ActiveLink";
import Image from "next/image";
import MoreHorizIcon from "@material-ui/icons/MoreHoriz";
import { useSelector } from "react-redux";
import sluggedNavData from "@/config/navData";
import { mergeArrayObjects } from "utils/customFunctions";
import ClickableRichTooltip from "@/components/Container/RichToolTip/ClickableRichTooltip";
import { useRouter } from "next/router";
import { useWindowSize } from "@/hooks/useWindowSize";
// import rechargeLogo from '@/images/services/smartphone.png';
// import dthLogo from '@/images/services/satellite-dish.png';

const DeskNav = () => {
  const [boxWidth, setBoxWidth] = useState(null);
  const router = useRouter();
  const CategoryState = useSelector((state) => state.category);
  const { categories } = CategoryState;
  const allData = categories.map((item) => {
    return {
      id: item.serviceId,
      icon: item.icon,
      serviceTypeName: item.serviceTypeName,
    };
  });
  const fullNavdata = mergeArrayObjects(allData, sluggedNavData);

  const navItems = fullNavdata.slice(0, 9);
  const secondaryItems = fullNavdata.slice(9, fullNavdata.length);
  const boxRef = useRef(null);
  const { width: windowWidth } = useWindowSize();
  // useEffect(() => {
  //   const boxWidth = boxRef.current.clientWidth;
  //   // if (boxRef.current.clientWidth < 300) {
  //   //   setBoxWidth(boxWidth);
  //   // } else {
  //   //   // windowWidth > 1140 ? setBoxWidth(90) : setBoxWidth(100);
  //   //   if (windowWidth < 1140) {
  //   //     setBoxWidth(90);
  //   //   }
  //   //   if (windowWidth > 1140 && windowWidth < 1250) {
  //   //     setBoxWidth(100);
  //   //   }
  //   //   if (windowWidth > 1250 && windowWidth < 1600) {
  //   //     setBoxWidth(90);
  //   //   }
  //   //   if (windowWidth > 1600 && windowWidth < 1921) {
  //   //     setBoxWidth(120);
  //   //   }
  //   // }
  //   // console.log(boxWidth);
  // }, [setBoxWidth, windowWidth, boxRef]);
  useEffect(() => {
    const boxWidth = boxRef.current.clientWidth;
    if (boxRef.current.clientWidth < 300) {
      setBoxWidth(boxWidth);
    } else {
      setBoxWidth(120);
    }
    console.log(boxWidth);
  }, [setBoxWidth, windowWidth]);
  return (
    <AppBar position="static" className="tab">
      <Container>
        <style jsx>{`
          .nav-link {
            text-decoration: none;
          }
          .active {
            background-color: #f46703;
            color: white;
          }
        `}</style>
        <Toolbar className="cards">
          <ActiveLink href="/mobile" activeclassname="active">
            <span className="card" ref={boxRef}>
              <div className="card-icon">
                <Image
                  src="/assets/images/services/smartphone.png"
                  alt="Aaipay"
                  width="22"
                  height="22"
                  className="imageColor"
                />
              </div>
              <div className="card-primary">Mobile</div>
            </span>
          </ActiveLink>
          <ActiveLink href="/dth" activeclassname="active">
            <span className="card">
              <div className="card-icon">
                <Image
                  src="/assets/images/services/satellitedish.png"
                  alt="Aaipay"
                  width="22"
                  height="22"
                  className="imageColor"
                />
              </div>
              <div className="card-primary">DTH</div>
            </span>
          </ActiveLink>
          {navItems.length === 0 &&
            [1, 2, 3, 4, 5, 6, 7, 8, 9].map((item) => (
              <ActiveLink href="" activeclassname="active" key={item}>
                <span className="card">
                  <div className="card-icon"></div>
                  <div className="card-primary"></div>
                </span>
              </ActiveLink>
            ))}
          {navItems.map((item) => {
            return (
              <ActiveLink
                href={{
                  pathname: item.href,
                  // query: { id: item.id, name: item.serviceTypeName },
                }}
                activeclassname="active"
                key={item.id}
                as={`${item.href}`}
              >
                <span className="card">
                  <div className="card-icon">
                    <Image
                      src={item.icon}
                      alt="Aaipay"
                      width="22"
                      height="22"
                      className="imageColor"
                    />
                  </div>
                  <div className="card-primary"> {item.serviceTypeName}</div>
                </span>
              </ActiveLink>
            );
          })}
          <ClickableRichTooltip
            width={boxWidth || 100}
            content={() => {
              return (
                <Grid container spacing={2} style={{ width: 600 }}>
                  {secondaryItems.map((item) => {
                    return (
                      <Grid item xs={12} sm={4} key={item.id}>
                        <ActiveLink
                          // href={{
                          //   pathname: '/' + item.href,
                          //   // query: { id: item.id, name: item.serviceTypeName },
                          // }}
                          href={`${item.href}`}
                          activeclassname="active"
                          key={item.id}
                        >
                          <span className="card2">
                            <div className="card-icon">
                              <Image
                                src={item.icon}
                                alt="Aaipay"
                                width="22"
                                height="22"
                                className="imageColor"
                              />
                            </div>
                            <div className="card-primary">
                              {item.serviceTypeName}
                            </div>
                          </span>
                        </ActiveLink>
                      </Grid>
                    );
                  })}
                </Grid>
              );
            }}
            placement="left-start"
          >
            <span
              className="card blackText"
              style={{ display: "inline-flex", width: "100%" }}
            >
              <div className="card-icon">
                <MoreHorizIcon />
              </div>
              <div className="card-primary">More</div>
            </span>
          </ClickableRichTooltip>
        </Toolbar>
      </Container>
    </AppBar>
  );
};

export default DeskNav;
