/* eslint-disable jsx-a11y/anchor-is-valid */
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import ActiveLink from "@/components/ActiveLink";
import { Container, Grid } from "@material-ui/core";
import { useSelector } from "react-redux";
import { mergeArrayObjects } from "utils/customFunctions";
import sluggedNavData from "@/config/navData";
import MoreHorizIcon from "@material-ui/icons/MoreHoriz";
import Image from "next/image";
import ClickableRichTooltip from "@/components/Container/RichToolTip/ClickableRichTooltip";
import { useRef, useEffect, useState } from "react";
import { useWindowSize } from "@/hooks/useWindowSize";
// import rechargeLogo from '@/images/services/smartphone.png';
// import dthLogo from '@/images/services/satellitedish.png';
const TabNav = () => {
  const [boxWidth, setBoxWidth] = useState(null);
  const { loading, categories } = useSelector((state) => state.category);
  const allData = categories.map((item) => {
    return {
      id: item.serviceId,
      icon: item.icon,
      serviceTypeName: item.serviceTypeName,
    };
  });
  const fullNavdata = mergeArrayObjects(allData, sluggedNavData);
  const navItems = fullNavdata.slice(0, 4);
  const secondaryItems = fullNavdata.slice(4, fullNavdata.length);
  const boxRef = useRef(null);
  const { width: windowWidth } = useWindowSize();
  useEffect(() => {
    const boxWidth = boxRef.current.clientWidth;
    if (boxRef.current.clientWidth < 300) {
      setBoxWidth(boxWidth);
    } else {
      setBoxWidth(120);
    }
    console.log(boxWidth);
  }, [setBoxWidth, windowWidth]);
  return (
    <AppBar position="static" className="tab">
      <Container maxWidth="lg">
        <style jsx>{`
          .nav-link {
            text-decoration: none;
          }

          .active {
            background-color: #f46703;
            color: white;
          }
          .card:nth-child(8):parent {
            display: none;
          }
        `}</style>
        <Toolbar className="cards">
          <ActiveLink href="/mobile" activeclassname="active">
            <span className="card" ref={boxRef}>
              <div className="card-icon">
                <Image
                  src="/assets/images/services/smartphone.png"
                  alt="Aaipay"
                  width="22"
                  height="22"
                  className="imageColor"
                />
              </div>
              <div className="card-primary">Mobile</div>
            </span>
          </ActiveLink>
          <ActiveLink href="/dth" activeclassname="active">
            <span className="card">
              <div className="card-icon">
                <Image
                  src="/assets/images/services/satellitedish.png"
                  alt="Aaipay"
                  width="22"
                  height="22"
                  className="imageColor"
                />
              </div>
              <div className="card-primary">DTH</div>
            </span>
          </ActiveLink>
          {navItems.length === 0 &&
            [1, 2, 3, 4].map((item) => (
              <ActiveLink href="" activeclassname="active" key={item}>
                <span className="card">
                  <div className="card-icon"></div>
                  <div className="card-primary"></div>
                </span>
              </ActiveLink>
            ))}
          {navItems.map((item) => {
            return (
              <ActiveLink
                href={`${item.href}`}
                activeclassname="active"
                key={item.id}
              >
                <span className="card">
                  <div className="card-icon">
                    <Image
                      src={item.icon}
                      alt="Aaipay"
                      width="22"
                      height="22"
                      className="imageColor"
                    />
                  </div>
                  <div className="card-primary"> {item.serviceTypeName}</div>
                </span>
              </ActiveLink>
            );
          })}
          <ClickableRichTooltip
            width={boxWidth || 100}
            content={() => {
              return (
                <Grid container spacing={2} style={{ width: 600 }}>
                  {secondaryItems.map((item) => {
                    return (
                      <Grid item xs={12} sm={4} key={item.id}>
                        <ActiveLink
                          href={`${item.href}`}
                          activeclassname="active"
                          key={item.id}
                        >
                          <span className="card3">
                            <div className="card-icon">
                              <Image
                                src={item.icon}
                                alt="Aaipay"
                                width="22"
                                height="22"
                                className="imageColor"
                              />
                            </div>
                            <div className="card-primary">
                              {item.serviceTypeName}
                            </div>
                          </span>
                        </ActiveLink>
                      </Grid>
                    );
                  })}
                </Grid>
              );
            }}
            placement="left-start"
          >
            <span
              className="card blackText"
              style={{ display: "inline-flex", width: "100%" }}
            >
              <div className="card-icon">
                <MoreHorizIcon />
              </div>
              <div className="card-primary">More</div>
            </span>
          </ClickableRichTooltip>
        </Toolbar>
      </Container>
    </AppBar>
  );
};

export default TabNav;
