import PropTypes from "prop-types";
import Head from "next/head";
import ContainerComponent from "./ContainerComponent";
import { makeStyles, Paper } from "@material-ui/core";
import { useWindowSize } from "@/hooks/useWindowSize";
import Overlay from "./Overlay";
import { useSelector } from "react-redux";
const useStyles = makeStyles((theme) => ({
  root: {},
  mainComponent: {},
  paper: {
    borderRadius: theme.spacing(4),
    width: (props) => {
      if (props) {
        if (props.windowWidth < 768 && props.customPage === true) {
          return "100%";
        }

        if (props.customPage === false) {
          return "100%";
        }

        if (props.customPage === true && props.windowWidth > 768) {
          return 600;
        }
      }
    },
  },
}));
function PageSecondary({
  customPage,

  title,
  paper,
  loading: loadingSec,
  children,
}) {
  const { width: windowWidth } = useWindowSize();
  const classes = useStyles({
    windowWidth: windowWidth,
    customPage: customPage,
  });
  // const { loading: loadPass } = useSelector((state) => state.passbook);
  // if (loadPass) {
  //   return <Overlay />;
  // }
  return (
    <div>
      {/*====================================
               HEAD Section 
        ====================================*/}
      <Head>
        <title>Aaipay || {title}</title>
        <meta name="description" content="Aaipay Pay with Faith" />
        <link rel="icon" href="/assets/images/logos/favicon.ico" />
      </Head>
      {/*====================================
              Form Component and Preview 
        ====================================*/}
      {loadingSec && <Overlay />}

      <section className={classes.mainComponent}>
        <ContainerComponent
          maxWidth="md"
          style={{
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
          }}
        >
          {paper ? (
            <Paper elevation={3} className={classes.paper}>
              {children}
            </Paper>
          ) : (
            children
          )}
        </ContainerComponent>
      </section>
    </div>
  );
}
PageSecondary.defaultProps = {
  paper: false,
  title: "Pay with Faith",
  customPage: false,
};
PageSecondary.propTypes = {
  children: PropTypes.element.isRequired,
  paper: PropTypes.bool.isRequired,
  title: PropTypes.string.isRequired,
};
export { PageSecondary };
