import React, { useEffect, useState } from "react";
import { AppBar, Divider, Grid, Typography } from "@material-ui/core";
import ImageGalleryProducts from "../ImageGalleryProducts";
import { useStyles } from "./utils";
import _ from "lodash";
import {
  Replay as ReplayIcon,
  Security as SecurityIcon,
  LocalShippingOutlined as LocalShippingOutlinedIcon,
  ShoppingCartSharp as BuyNowIcon,
} from "@material-ui/icons";

import Controls from "../Controls/Controls";
import MuiBreadcrumbs from "@/components/Breadcrumbs";
import axios from "axios";
const ProductDetails = ({ productData }) => {
  const { data } = productData;
  const {
    selling_price,
    mrp,
    name,
    description,
    impt_note,
    in_the_box,
    generalDetails,
    additional_info,
    warrentyDetails,
  } = data;
  const {
    brand,
    offer,
    aspect_ratio,
    memory,
    model_name,
    connectivity,
    rmt_features,
    recording,
    weight,
    disp_res,
    technology,
  } = generalDetails;
  const { summary, service_type, not_covered, covered_in_warrenty } =
    warrentyDetails;

  const offPercentage = (((mrp - selling_price) / mrp) * 100).toFixed(2);
  const imageCollection = [];
  imageCollection.push(data.image);
  for (const item of [1, 2, 3, 4, 5]) {
    if (data[`img${item}`].indexOf(".") !== -1) {
      imageCollection.push(data[`img${item}`]);
    }
  }
  const disabledItems = ["category", "products"];
  const classes = useStyles();
  const [breadcrumbs, setBreadcrumbs] = useState([]);
  useEffect(() => {
    async function getCategory() {
      const category = await axios.get(
        "https://aaipay.in:10002/api/apps/v1/aai-system/connection/getProductCategories.jsp",
        {
          headers: { "content-type": "application/json" },
        }
      );
      const data = await category.data.data;
      setBreadcrumbs(data);
      console.log(data, "data");
    }
    getCategory();
  }, []);
  const latestBreadcrumbs = breadcrumbs.map((item) => {
    return {
      category_id: item.id,
      name: item.name,
    };
  });
  return (
    <div className={classes.root}>
      <Grid container spacing={4}>
        <Grid item xs={12} md={4} sm={12}>
          <ImageGalleryProducts imageCollection={imageCollection} />
          <Controls.Button
            text="Buy Now"
            startIcon={<BuyNowIcon />}
            fullWidth={true}
            style={{ marginTop: 30 }}
            type="button"
            onClick={() => console.log("Buy Now")}
          />
        </Grid>
        <Grid item xs={12} md={8} sm={12}>
          <MuiBreadcrumbs
            disabledItems={disabledItems}
            latestBreadcrumbs={latestBreadcrumbs}
            itemName={name.substring(0, 20).concat(" ...")}
          />
          <div className={classes.productDesc}>
            <Typography variant="subtitle2" className={classes.name}>
              {name}
            </Typography>
          </div>
          <div className={classes.price}>
            <Typography variant="subtitle2" className={classes.sellingPrice}>
              ₹ {selling_price}
            </Typography>
            <Typography variant="subtitle2" className={classes.mrp}>
              ₹ {mrp}
            </Typography>
            <Typography variant="subtitle2" className={classes.offPercentage}>
              {offPercentage + "% Off"}
            </Typography>
          </div>

          {/* <div className={classes.smallDetails}>
            <Typography
              variant="subtitle2"
              className={classes.smallDetailsContentHead}
            >
              Services
            </Typography>
            <div className={classes.descriptionSmall}>
              <Typography
                variant="body2"
                className={classes.smallDetailsContent}
              >
                <SecurityIcon className={classes.icon} />
                {warrentyDetails.summary}
              </Typography>
              <Typography
                variant="body2"
                className={classes.smallDetailsContent}
              >
                <ReplayIcon className={classes.icon} />
                No returns Applicable
              </Typography>
            </div>
          </div> */}
          <div className={classes.smallDetails}>
            <Typography
              variant="subtitle2"
              className={classes.smallDetailsContentHead}
            >
              Delivery
            </Typography>
            <div className={classes.descriptionSmall}>
              <Typography
                variant="body2"
                className={classes.smallDetailsContent}
              >
                <LocalShippingOutlinedIcon className={classes.icon} />
                Free Shipping Available
              </Typography>
            </div>
          </div>
          <div className={classes.smallDetails}>
            <Typography
              variant="subtitle2"
              className={classes.smallDetailsContentHead}
            >
              Description
            </Typography>
            <div className={classes.descriptionSmall}>
              <Typography
                variant="body2"
                className={classes.smallDetailsContent}
              >
                {description}
              </Typography>
            </div>
          </div>
          <div className={classes.specification}>
            <Typography variant="h6">Specification</Typography>
            <Divider className={classes.divider} />
            {impt_note && (
              <div className={classes.specificationContent}>
                <Typography
                  variant="h6"
                  className={classes.specificationHeading}
                >
                  Important Note
                </Typography>
                <Typography variant="body2">{impt_note}</Typography>
              </div>
            )}
            <Divider className={classes.divider2} />
            {in_the_box && (
              <div className={classes.specificationContent}>
                <Typography
                  variant="h6"
                  className={classes.specificationHeading}
                >
                  In The Box
                </Typography>
                <Typography variant="body2">{in_the_box}</Typography>
              </div>
            )}
            <Divider className={classes.divider2} />
            {!_.isEmpty(generalDetails) && (
              <div className={classes.specificationContent}>
                <Typography
                  variant="h6"
                  className={classes.specificationHeading}
                >
                  General Details
                </Typography>
                {brand ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Brand
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {brand}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {model_name ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Model Name
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {model_name}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {offer ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Offer
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {offer}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {aspect_ratio ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Aspect Ratio
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {aspect_ratio}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {connectivity ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Connectivity
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {connectivity}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {disp_res ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Display Resolution
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {disp_res}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {rmt_features ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Remote Features
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {rmt_features}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {technology ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Technology
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {technology}
                      </Typography>
                    </div>
                  </div>
                ) : null}

                {weight ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Weight
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {weight}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {memory ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Memory
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {memory}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {recording ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Recording
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {recording}
                      </Typography>
                    </div>
                  </div>
                ) : null}
              </div>
            )}
            <Divider className={classes.divider2} />
            {additional_info && (
              <div className={classes.specificationContent}>
                <Typography
                  variant="h6"
                  className={classes.specificationHeading}
                >
                  Additional Information
                </Typography>
                <Typography variant="body2">{additional_info}</Typography>
              </div>
            )}
            <Divider className={classes.divider2} />
            {!_.isEmpty(warrentyDetails) && (
              <div className={classes.specificationContent}>
                <Typography
                  variant="h6"
                  className={classes.specificationHeading}
                >
                  Warranty Details
                </Typography>
                {summary ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Summary
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {summary}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {service_type ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Service Type
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {service_type}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {not_covered ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Not Covered in Warranty
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {not_covered}
                      </Typography>
                    </div>
                  </div>
                ) : null}
                {covered_in_warrenty ? (
                  <div className={classes.smallDetailsGen}>
                    <Typography
                      variant="subtitle2"
                      className={classes.smallDetailsContentHead}
                    >
                      Covered in Warranty
                    </Typography>
                    <div className={classes.descriptionSmall}>
                      <Typography
                        variant="body2"
                        className={classes.smallDetailsContent}
                      >
                        {covered_in_warrenty}
                      </Typography>
                    </div>
                  </div>
                ) : null}
              </div>
            )}
          </div>
        </Grid>
      </Grid>
    </div>
  );
};

export default ProductDetails;
