import { useCallback, useEffect, useState } from "react";
import QRCode from "react-qr-code";
import PageHeader from "../PageHeader";
import { useStyles } from "./utils";
import MyTimer from "../Timer";
import { Button, Typography } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import { closeModal } from "@/redux/actions/modal.actions";
import api from "@/redux/config/api.main";
import Cookies from "js-cookie";
import { checkStatusOfPayment } from "@/redux/actions/upi.payment.action";
import { ArrowBack } from "@material-ui/icons";

const QrCodeComponent = (props) => {
  const { upi } = useSelector((state) => state.upiPayment);
  const dispatch = useDispatch();
  const time = new Date();
  time.setSeconds(time.getSeconds() + 300);
  const classes = useStyles();
  const [qrString, setQrString] = useState("");
  const [tid, setTid] = useState("");
  const generateTid = useCallback((n) => {
    var add = 1,
      max = 12 - add; // 12 is the min safe number Math.random() can generate without it starting to pad the end with zeros.

    if (n > max) {
      return generateTid(max) + generateTid(n - max);
    }

    max = Math.pow(10, n + add);
    var min = max / 10; // Math.pow(10, n) basically
    var number = Math.floor(Math.random() * (max - min + 1)) + min;

    return ("" + number).substring(add);
  }, []);
  const onExpireTimer = useCallback(() => {
    dispatch(closeModal({ modalProps: { open: false } }));
  }, [dispatch]);
  // 320442049308
  useEffect(() => {
    const tidNumber = generateTid(9);
    const tidString = `MNO${tidNumber}`;
    setTid(tidString);
    const str = `upi://pay?pa=aaipaystore@icici&pn=AAIPAY STORE&tr=${tidString}&am=${props.amount}&cu=INR&mc=5499`;
    setQrString(str);
  }, [setQrString, props.amount, generateTid, setTid]);
  useEffect(() => {
    const fetchProducts = async () => {
      if (qrString) {
        await api.get(
          `UPI/qrPaymentApiLogs.jsp?tid=${tid}&amount=${
            props.amount
          }&userId=${Cookies.get("regId")}`
        );
      }
    };
    fetchProducts();
  }, [props.amount, qrString, tid]);
  useEffect(() => {
    if (tid) {
      const transactionData = {
        merchantTranId: tid,
        transactionType: "Q",
        amount: props.amount,
      };
      dispatch(checkStatusOfPayment(transactionData));
    }
  }, [dispatch, tid, props.amount]);
  return (
    <div className={classes.root}>
      <Button
        variant="outlined"
        color="primary"
        size="small"
        className={classes.button}
        startIcon={<ArrowBack />}
        onClick={() =>
          dispatch(
            closeModal({
              modalProps: { open: false, payment: true, close: true },
            })
          )
        }
      >
        Back
      </Button>
      <PageHeader
        title="My Qr Code"
        subTitle={`Scan Qr Code and pay ₹${props.amount} using apps enabled with UPI QR`}
      />
      <div className={classes.qrcode}>
        <QRCode value={qrString} size={200} />
      </div>
      <div className={classes.timer}>
        <MyTimer
          expiryTimestamp={time}
          text="Complete Payment within:"
          onExpire={onExpireTimer}
        />
      </div>
      <div className={classes.textCenter}>
        <Typography
          variant="body1"
          style={{ marginTop: 20, fontSize: 16 }}
          component="p"
        >
          {`Can't`} Pay with Qr Code ?
        </Typography>
      </div>
      <div className={classes.textCenter}>
        <Typography
          variant="body1"
          className={classes.donotRefreshWarning}
          component="p"
        >
          Do not refresh or close this page until you get a transaction here
        </Typography>
      </div>
      <div className={classes.textCenter}>
        <Typography>
          You can send this QR Code and add money to your wallet
        </Typography>
      </div>
    </div>
  );
};

export default QrCodeComponent;
