/* eslint-disable jsx-a11y/click-events-have-key-events */
import { useWindowSize } from "@/hooks/useWindowSize";
import { setAlertMessage } from "@/redux/actions/alert.action";
import { getPassBook, getWalletBalance } from "@/redux/actions/passbook.action";
import { makeStyles, Grid, Typography, Button } from "@material-ui/core";
import axios from "axios";
import Cookies from "js-cookie";
import { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import AlertMessage from "../AlertMessage";
import Image from "next/image";
import { useRouter } from "next/router";
import GeneralBreadcrumbs from "../GeneralBreadcrumbs";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 96}px` : "100%",
    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    marginBottom: (props) =>
      props && props.windowWidth < 768 ? `0rem` : "16.7rem",
  },
  typography: {
    marginTop: theme.spacing(0),
    padding: theme.spacing(2, 1),
    fontSize: theme.spacing(2.5),
    display: "flex",
    justifyContent: "flex-start",
  },
  rate: {
    marginTop: theme.spacing(0),
    padding: theme.spacing(2, 2),
    fontSize: theme.spacing(2.5),
    display: "flex",
    justifyContent: "flex-end",
  },
  buttonFlex: {
    display: "flex",
    flexDirection: (props) =>
      props && props.windowWidth < 768 ? `column` : "row",
    justifyContent: "flex-start",
  },

  buttonPayment: {
    borderRadius: 32,
    paddingTop: 12,
    maxWidth: (props) =>
      props && props.windowWidth < 768
        ? "calc(100% - 20px)"
        : `calc(100% - 80px)`,
    paddingBottom: 12,
    marginRight: (props) =>
      props && props.windowWidth < 768 ? "0px" : theme.spacing(2),
    marginBottom: (props) =>
      props && props.windowWidth > 768 ? "0px" : theme.spacing(2),
  },
}));
function Razorpay({ amount }) {
  const dispatch = useDispatch();
  const moneyString = parseFloat(amount?.toString())?.toFixed(2);
  const { alertOpen } = useSelector((state) => state.alert);
  const { width: windowWidth } = useWindowSize();
  const reg_id = Cookies.get("regId");
  const mbl = Cookies.get("mobile");
  useEffect(() => {
    // dispatch(getMyProfile(reg_id, mbl));
    dispatch(getWalletBalance({ reg_id, mbl }));
  }, [dispatch, reg_id, mbl]);
  const classes = useStyles({
    windowWidth,
  });

  useEffect(() => {
    if (typeof amount === "undefined" || amount === null) {
      if (window.location.href !== `${window.location.origin}/mobile`) {
        // Redirect logic
        setTimeout(() => {
          window.location.replace("/mobile");
        }, 3000);
      }
    }
  }, [amount]);
  const { userInfo } = useSelector((state) => state.myProfile);
  // const amount_in_paisa = `${amount * 100}`;
  function loadScript(src) {
    return new Promise((resolve) => {
      const script = document.createElement("script");
      script.src = src;
      script.onload = () => {
        resolve(true);
      };
      script.onerror = () => {
        resolve(false);
      };
      document.body.appendChild(script);
    });
  }

  async function displayRazorpay() {
    try {
      const res = await loadScript(
        "https://checkout.razorpay.com/v1/checkout.js"
      );

      if (!res) {
        alert("Razorpay SDK failed to load. Are you online?");
        return;
      }

      // creating a new order
      const reg_id = Cookies.get("regId").trim();
      const mbl = Cookies.get("mobile").trim();

      const result = await axios.post(
        `https://aaipay.in:10002/api/apps/v1/create_order.jsp?mbl=${mbl}&amount=${amount}&regId=${reg_id}`,
        {
          headers: { "content-type": "application/json" },
        }
      );
      console.log("result", result);
      const order_id = await result.data.razorpayId.trim();
      console.log(order_id);
      // Getting the order details back
      console.log(`Order details`, result.data, amount);
      const options = {
        key: process.env.RAZORPAY_KEY_ID_PROD, // Enter the Key ID generated from the Dashboard
        amount: amount,
        currency: "INR",
        name: "Aaipay-Pay with Faith",
        description: "Add Money to Wallet",
        image: "/assets/images/logos/logo.png",
        order_id: order_id,
        handler: async function (response) {
          const data = {
            orderCreationId: order_id,
            razorpayPaymentId: response.razorpay_payment_id,
            razorpayOrderId: response.razorpay_order_id,
            razorpaySignature: response.razorpay_signature,
            amount: amount.toString(),
            currency: "INR",
          };
          const resultB = await axios.get(
            `https://aaipay.in:10002/api/apps/v1/create_order_payment_gateway.jsp?reg=${reg_id}&amount=${amount}&mbl=${mbl}&razorpayOrderId=${response.razorpay_order_id}`
          );
          console.log(resultB, "resultB");
          const { status, err_code } = resultB;
          const paymentGateWayEntry = async () => {
            const result = await axios.post(
              `https://aaipay.in:10002/api/apps/v1/payemntGatway_entry.jsp?reg=${reg_id}&amount=${amount}&mbl=${mbl}&razorpayOrderId=${response.razorpay_order_id}&paymentStatus=${status}&razorpay_payment_id=${response.razorpay_payment_id}&error=""`,
              data
            );
            return result;
          };
          const creditAmount = async (resultGateEntry) => {
            try {
              const entry = await resultGateEntry.data.entry_id;
              console.log(entry);
              const resultC = await axios.post(
                `https://aaipay.in:10002/api/apps/v1/credit_amount.jsp?cust_reg=${reg_id}&amount=${amount}&mobile=${mbl}&razorPay_orderID=${response.razorpay_order_id}&razorpay_payment_id=${response.razorpay_payment_id}&tid=${entry}`,
                {
                  headers: {
                    "content-type": "application/json",
                  },
                }
              );
              return resultC;
            } catch (error) {
              console.error(error);
            }
          };
          await paymentGateWayEntry();
          await creditAmount(resultB);
          err_code === 123 && paymentGateWayEntry();
          dispatch(getWalletBalance({ mbl, reg_id }));
          dispatch(getPassBook({ mbl, reg_id }));
          dispatch(
            setAlertMessage(
              true,
              "success",
              `₹ ${localStorage.getItem(
                "amount"
              )} added to the wallet successfully`
            )
          );
          if (window.location.href !== `${window.location.origin}/mobile`) {
            // Redirect logic
            setTimeout(() => {
              window.location.replace("/mobile");
              localStorage.removeItem("amount");
            }, 3000);
          }
        },

        prefill: {
          name: userInfo.Name,
          email: userInfo.Email,
          contact: mbl,
        },
        notes: {
          address: "Soumya Dey Corporate Office",
        },
        theme: {
          color: "#46A7E4",
        },
      };

      const paymentObject = new window.Razorpay(options);
      paymentObject.open();
    } catch (error) {
      console.log(error?.response?.data, "error random custom");
    }
  }
  const router = useRouter();
  return (
    <div className={classes.root}>
      <Grid container spacing={2}>
        <Grid item xs={12}>
          <GeneralBreadcrumbs />
          {alertOpen === true && <AlertMessage />}
        </Grid>
        <Grid item xs={8}>
          <Typography variant="subtitle2" className={classes.typography}>
            Add Money To Wallet
          </Typography>
        </Grid>
        <Grid item xs={4}>
          <Typography variant="subtitle2" className={classes.rate}>
            ₹ {moneyString}
          </Typography>
        </Grid>
        <Grid item xs={12}>
          <Typography variant="subtitle2">
            Select Preferred Payment Method
          </Typography>
        </Grid>
        <Grid item xs={12}>
          <div className={classes.buttonFlex}>
            <Button
              className={classes.buttonPayment}
              onClick={displayRazorpay}
              color="default"
              variant="contained"
              type="button"
              fullWidth={windowWidth > 768 ? false : true}
            >
              <Image
                src="/assets/images/razorpay.png"
                width="100"
                height="20"
                alt="razorpay"
              />
            </Button>
            <Button
              className={classes.buttonPayment}
              onClick={() => router.push("/passbook/transaction/upi")}
              color="default"
              variant="contained"
              type="button"
              style={{ alignItems: "center", justifyContent: "center" }}
              fullWidth={windowWidth > 768 ? false : true}
            >
              <Image
                src="/assets/images/upi.svg"
                width="25"
                height="25"
                alt="UPI"
              />
              <Typography variant="subtitle2" style={{ marginLeft: 8 }}>
                UPI ID
              </Typography>
            </Button>
          </div>
        </Grid>
      </Grid>
    </div>
  );
}

export default Razorpay;
