import { useEffect, useState } from "react";
import { useWindowSize } from "@/hooks/useWindowSize";
import { Grid, Button, Typography } from "@material-ui/core";
import Controls from "@/components/Controls/Controls";
import { useDispatch, useSelector } from "react-redux";
import { useFormik } from "formik";
import * as yup from "yup";
import { useRouter } from "next/router";
import PageHeader from "../PageHeader";
import { ArrowBack as ArrowBackIcon } from "@material-ui/icons";
// import { registerUser } from "@/redux/actions/auth.actions";
import { useStyles } from "./utils";
import { openModal } from "@/redux/actions/modal.actions";
import ModalExample from "../Layout/Modal/ModalExample";
import QrCodeComponent from "../QrCodeComponent";
import { sendUpiPaymentRequest } from "@/redux/actions/upi.payment.action";
const upiRegExp = /[a-zA-Z0-9.\-_]{2,256}@[a-zA-Z]{2,64}/;
const validationSchema = yup.object({
  payerVa: yup
    .string()
    .required("UPI ID is required.")
    .matches(upiRegExp, "UPI Id is not valid"),
});
const UPIComponent = (props) => {
  const windowWidth = useWindowSize();
  const dispatch = useDispatch();
  const router = useRouter();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
    customPage: props.customPage,
  });
  const { loadingButton } = useSelector((state) => state.upiPayment);
  const openQrCode = () => {
    dispatch(
      openModal({
        modalType: ModalExample,
        modalProps: {
          component: <QrCodeComponent amount={props.amount} />,
          open: true,
          closeDrawerAction: false,
          qrCode: true,
          fullScreenAt: "sm",
        },
      })
    );
  };

  const formik = useFormik({
    initialValues: {
      amount: props.amount,
      payerVa: "",
    },
    validationSchema: validationSchema,
    onSubmit: (values) => {
      dispatch(sendUpiPaymentRequest(values));
    },
  });

  return (
    <div className={classes.root}>
      <form onSubmit={formik.handleSubmit}>
        <Grid container spacing={2}>
          <Grid item xs={12}>
            {/* <GeneralBreadcrumbs /> */}
            <Button
              variant="outlined"
              color="primary"
              size="small"
              className={classes.button}
              startIcon={<ArrowBackIcon />}
              onClick={() => router.back()}
            >
              Back
            </Button>
            <PageHeader
              title="UPI Payment"
              subTitle="Pay using any UPI enabled application"
            />
          </Grid>
          <Grid item xs={12}>
            <Controls.Input
              fullWidth={true}
              label="Amount"
              name="amount"
              value={formik.values.amount ?? props?.mbl ?? ""}
              error={formik.touched.amount && Boolean(formik.errors.amount)}
              helperText={formik.touched.amount && formik.errors.amount}
              disabled
            />
          </Grid>
          <Grid item xs={12}>
            <Controls.Input
              fullWidth={true}
              label="UPI ID"
              name="payerVa"
              placeholder="Please Enter your UPI ID"
              value={formik.values.payerVa}
              onChange={formik.handleChange}
              error={formik.touched.payerVa && Boolean(formik.errors.payerVa)}
              helperText={formik.touched.payerVa && formik.errors.payerVa}
            />
          </Grid>
          <Grid item xs={12} className={classes.displayFlexEnd}>
            <Typography
              className={classes.link}
              variant="subtitle2"
              onClick={openQrCode}
            >
              Generate QR Code?
            </Typography>
          </Grid>
          <Controls.Button
            fullWidthButton={true}
            text="Proceed To Pay"
            type="submit"
            loadingButton={loadingButton}
            loadingIndicator={true}
          />
        </Grid>
      </form>
    </div>
  );
};

export default UPIComponent;
