import { useCallback, useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import Image from "next/image";
import { Button, Typography } from "@material-ui/core";
import MyTimer from "../Timer";
import { closeModal } from "@/redux/actions/modal.actions";
import { useStyles } from "./utils";
import { checkStatusOfPayment } from "@/redux/actions/upi.payment.action";
import { ArrowBack } from "@material-ui/icons";

export const upiPaymentData = (state) => state.upiPayment;
const UPIPaymentComponent = (props) => {
  const { upi } = useSelector((state) => state.upiPayment);
  const dispatch = useDispatch();
  const time = new Date();
  time.setSeconds(time.getSeconds() + 300);
  const classes = useStyles();

  const onExpireTimer = useCallback(() => {
    dispatch(closeModal({ modalProps: { open: false } }));
  }, [dispatch]);
  // 320442049308

  useEffect(() => {
    if (upi.success === "true") {
      const transactionData = {
        merchantTranId: upi.merchantTranId,
        transactionType: "C",
        amount: props.amount,
      };
      dispatch(checkStatusOfPayment(transactionData));
    }
  }, [upi.success, dispatch, upi.merchantTranId, props.amount]);
  return (
    <div className={classes.root}>
      <Button
        variant="outlined"
        color="primary"
        size="small"
        className={classes.button}
        startIcon={<ArrowBack />}
        onClick={() =>
          dispatch(
            closeModal({
              modalProps: { open: false, payment: true, close: true },
            })
          )
        }
      >
        Back
      </Button>
      <div className={classes.textCenter}>
        <Typography variant="h6" component="div">
          {`Open UPI mobile app and approve payment of ₹${parseFloat(
            props.amount
          ).toFixed(2)}`}
        </Typography>
      </div>

      <div className={classes.timer}>
        <MyTimer
          expiryTimestamp={time}
          text="Complete Payment within:"
          onExpire={onExpireTimer}
        />
      </div>
      <div className={classes.textCenter}>
        <Typography
          variant="body1"
          className={classes.donotRefreshWarning}
          component="p"
        >
          Do not refresh or close this page until you get a transaction here
        </Typography>
      </div>
      <div className={classes.poweredByContainer}>
        <Typography variant="h6" component="p">
          Powered by
        </Typography>
        <div className={classes.imagesContainer}>
          <div className={classes.image1}>
            <Image
              src="/assets/images/upi.webp"
              alt="Aaipay BHIM UPI Logo"
              width="90"
              height="30"
            />
          </div>
          <div className={classes.image2}>
            <Image
              src="/assets/images/ICICI_Bank.svg"
              alt="Aaipay ICICI Logo"
              width="150"
              height="50"
            />
          </div>
        </div>
      </div>
    </div>
  );
};

export default UPIPaymentComponent;
