import { wrapper } from "@/redux/store";
import Layout from "@/components/Layout";
import "@/styles/globals.css";
import { createTheme, ThemeProvider } from "@material-ui/core/styles";
import MaterialDrawerRedux from "@/components/Layout/Drawer/DrawerRedux";
import { useDispatch, useSelector } from "react-redux";
import { useEffect } from "react";
import { loginValidate, userValidate } from "@/redux/actions/auth.actions";
import Cookies from "js-cookie";
import { useRouter } from "next/router";
import { getWalletBalance } from "@/redux/actions/passbook.action";
import MaterialModalRedux from "@/components/Layout/Modal/ModalRedux";
import BackToTop from "@/components/BackToTop";
import { ToastContainer } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";

const theme = createTheme({
  palette: {
    primary: {
      main: "#3da3e3",
      contrastText: "#fff",
    },
    secondary: {
      main: "#f46703",
    },
  },
});

function MyApp({ Component, pageProps }) {
  const dispatch = useDispatch();
  const router = useRouter();
  const { isAuthenticated, loading } = useSelector((state) => state.myProfile);
  const { isAuthenticated: auth } = useSelector((state) => state.setOtp);
  const { status, isAuthenticated: authValidate } = useSelector(
    (state) => state.validateLogin
  );

  const mbl = Cookies.get("mobile");
  const reg_id = Cookies.get("regId");
  useEffect(() => {
    if (!isAuthenticated && !auth) {
      dispatch(
        loginValidate({
          mobile: Cookies.get("mobile"),
          password: Cookies.get("password"),
          loginKey: Cookies.get("loginKey"),
          ip: Cookies.get("ip"),
        })
      );
      dispatch(getWalletBalance({ mbl, reg_id }));
    }
  }, [dispatch, isAuthenticated, auth, mbl, reg_id]);

  const mobile = Cookies.get("mobile");
  useEffect(() => {
    dispatch(userValidate({ mobile }));
  }, [dispatch, mobile]);

  useEffect(() => {
    dispatch(getWalletBalance({ mbl, reg_id }));
  }, [dispatch, mbl, reg_id]);

  useEffect(() => {
    if (router.pathname !== "/payment-details") {
      Cookies.remove("cpn");
    }
  }, [router]);

  return (
    <ThemeProvider theme={theme}>
      <Layout>
        <Component {...pageProps} />
        <MaterialDrawerRedux />
        <MaterialModalRedux />
        <ToastContainer autoClose={2000} />
        <BackToTop />
      </Layout>
    </ThemeProvider>
  );
}

export default wrapper.withRedux(MyApp);
