import {
  GET_PROFILE_FAILED,
  GET_PROFILE_REQUEST,
  GET_PROFILE_SUCCESS,
  LOGIN_OTP_FAILED,
  LOGIN_OTP_REQUEST,
  LOGIN_OTP_SUCCESS,
  LOGIN_VALIDATE_FAILED,
  LOGIN_VALIDATE_REQUEST,
  LOGIN_VALIDATE_SUCCESS,
  NEW_LOGIN_REQUEST,
  NEW_LOGIN_SUCCESS,
  NEW_LOGIN_FAILED,
  REGISTER_USER_FAILED,
  REGISTER_USER_REQUEST,
  REGISTER_USER_SUCCESS,
  RESET_OTP_STATUS,
  RESET_REGISTER_STATUS,
  SET_OTP_FAILED,
  SET_OTP_REQUEST,
  SET_OTP_SUCCESS,
  UPDATE_PROFILE_FAILED,
  UPDATE_PROFILE_REQUEST,
  UPDATE_PROFILE_SUCCESS,
  USER_LOGOUT,
  USER_VALIDATE_FAILED,
  USER_VALIDATE_REQUEST,
  USER_VALIDATE_SUCCESS,
} from "../constants/auth.constants";

/*----------------------------------
          LOGIN REDUCER         
==================================*/
export const otpReducer = (
  state = {
    loading: true,
    error: false,
    status: "",
    err_msg: "",
    err_code: "",
    isAuthenticated: false,
    loadingButton: false,
  },
  action
) => {
  switch (action.type) {
    case LOGIN_OTP_REQUEST:
      return {
        ...state,
        isAuthenticated: false,
        loadingButton: true,
      };
    case LOGIN_OTP_SUCCESS:
      console.log(action.payload, "payload");
      return {
        loading: false,
        status: action.payload.Status ?? action.payload.status,
        err_msg: action.payload.err_msg ?? action.payload.message,
        err_code: action.payload.err_code ?? action.payload.err,
        error: false,
        isAuthenticated: false,
        loadingButton: false,
      };
    case LOGIN_OTP_FAILED:
      return {
        loading: false,
        error: action.payload,
        isAuthenticated: false,
      };
    case RESET_OTP_STATUS:
      return {
        status: null,
        isAuthenticated: false,
        loading: false,
      };
    case USER_LOGOUT:
      return {
        userInfo: {},
        isAuthenticated: false,
      };

    default:
      return state;
  }
};

/*----------------------------------
          USER REGISTER REDUCER         
==================================*/
export const registerUserReducer = (
  state = {
    loading: true,
    error: false,
    status: "",
    msg: "",
    err: "",
    isAuthenticated: false,
    loadingButton: false,
  },
  action
) => {
  switch (action.type) {
    case REGISTER_USER_REQUEST:
      return {
        ...state,
        isAuthenticated: false,
        loadingButton: true,
      };
    case REGISTER_USER_SUCCESS:
      return {
        loading: false,
        status: action.payload.status,
        msg: action.payload.msg,
        err: action.payload.err,
        error: false,
        isAuthenticated: false,
        loadingButton: false,
      };
    case REGISTER_USER_FAILED:
      return { loading: false, error: action.payload, isAuthenticated: false };
    case RESET_REGISTER_STATUS:
      return {
        status: null,
        isAuthenticated: false,
        loading: false,
      };
    default:
      return state;
  }
};

/*----------------------------------
          SET OTP REDUCER         
==================================*/
export const setOtpReducer = (
  state = {
    loading: true,
    error: false,
    status: "",
    msg: "",
    err: "",
    isAuthenticated: false,
    loadingButton: false,
    userInfo: {},
  },
  action
) => {
  switch (action.type) {
    case SET_OTP_REQUEST:
    case NEW_LOGIN_REQUEST:
      return {
        ...state,
        isAuthenticated: false,
        loadingButton: true,
      };
    case SET_OTP_SUCCESS:
    case NEW_LOGIN_SUCCESS:
      console.log(action.payload, "payload reduxer");
      return {
        loading: false,
        status: action.payload.status || action.payload.Status,
        msg: action.payload.msg || action.payload.err_msg,
        err: action.payload.err || action.payload.err_code,
        error: false,
        isAuthenticated: true,
        loadingButton: false,
        userInfo: { ...action.payload.data.data },
      };
    case SET_OTP_FAILED:
    case NEW_LOGIN_FAILED:
      return {
        loading: false,
        error: action.payload,
        isAuthenticated: false,
        userInfo: {},
      };

    default:
      return state;
  }
};

/*----------------------------------
          my profile REDUCER         
==================================*/
export const myProfileReducer = (
  state = {
    loading: false,
    error: false,
    status: "",
    msg: "",
    err: "",
    isAuthenticated: false,
    loadingButton: false,
    userInfo: {},
  },
  action
) => {
  switch (action.type) {
    case GET_PROFILE_REQUEST:
      console.log(action, "action.payload.request");
      return {
        ...state,
        isAuthenticated: false,
        loadingButton: true,
      };
    case GET_PROFILE_SUCCESS:
      console.log(action, "action.payload");
      return {
        loading: false,
        status: action.payload.status || action.payload.Status,
        msg: action.payload.msg || action.payload.err_msg,
        err: action.payload.err || action.payload.err_code,
        error: false,
        isAuthenticated: true,
        loadingButton: false,
        userInfo: action.payload,
      };
    case USER_LOGOUT: {
      return {
        userInfo: {},
        loading: false,
        error: false,
        isAuthenticated: false,
        status: null,
      };
    }
    case GET_PROFILE_FAILED:
      return { loading: false, error: action.payload, isAuthenticated: false };
    case UPDATE_PROFILE_REQUEST:
      return {
        ...state,
        loading: false,
        loadingButton: true,
      };
    case UPDATE_PROFILE_SUCCESS:
      return {
        ...state,
        loading: false,
        loadingButton: false,
      };
    case UPDATE_PROFILE_FAILED:
      return {
        ...state,
        profile: { ...state.profile },
        error: action.payload,
        loading: false,
      };
    default:
      return state;
  }
};

/*----------------------------------
          my profile REDUCER         
==================================*/
export const validateLoginReducer = (
  state = {
    loading: true,
    error: false,
    status: "",
    msg: "",
    err: "",
    isAuthenticated: false,
    loadingButton: false,
    userInfo: {},
  },
  action
) => {
  switch (action.type) {
    case LOGIN_VALIDATE_REQUEST:
      console.log(action, "action.payload.request");
      return {
        ...state,
        isAuthenticated: false,
        loadingButton: true,
      };
    case LOGIN_VALIDATE_SUCCESS:
      console.log(action, "action.payload");
      return {
        loading: false,
        status: action.payload.status || action.payload.Status,
        msg:
          action.payload.msg ||
          action.payload.err_msg ||
          action.payload.message,
        err: action.payload.err || action.payload.err_code,
        error: false,
        isAuthenticated: true,
        loadingButton: false,
        userInfo: action.payload.data,
      };
    case USER_LOGOUT: {
      return {
        userInfo: {},
        loading: false,
        error: false,
        isAuthenticated: false,
        status: null,
      };
    }
    case LOGIN_VALIDATE_FAILED:
      return { loading: false, error: action.payload, isAuthenticated: false };

    default:
      return state;
  }
};

/*------------------------------
        USER VALIDATE   
==============================*/

export const userValidateReducer = (
  state = { isValid: false, status: null, loading: true },
  action
) => {
  switch (action.type) {
    case USER_VALIDATE_REQUEST:
      console.log(action, "action.payload.request");
      return {
        isValid: false,
        loading: true,
      };
    case USER_VALIDATE_SUCCESS:
      console.log(action, "action.payload");
      return {
        isValid: true,
        status: action.payload.status,
        loading: false,
      };
    case USER_LOGOUT: {
      return {
        isValid: false,
        status: null,
        loading: false,
      };
    }
    case USER_VALIDATE_FAILED:
      return { error: action.payload, isValid: false, loading: false };

    default:
      return state;
  }
};
