import { HYDRATE } from "next-redux-wrapper";
import {
  LOAD_BILLERS_FAILURE,
  LOAD_BILLERS_REQUEST,
  LOAD_BILLERS_SUCCESS,
  LOAD_INPUT_FIELDS_FAILURE,
  LOAD_INPUT_FIELDS_REQUEST,
  LOAD_INPUT_FIELDS_SUCCESS,
  LOAD_BILL_FETCH_FAILURE,
  LOAD_BILL_FETCH_REQUEST,
  LOAD_BILL_FETCH_SUCCESS,
  RESET_INPUT_FIELDS,
  LOADING_BUTTON_RESET,
  RESET_BILLERS,
  LOAD_EDUC_BILLERS_REQUEST,
  LOAD_EDUC_BILLERS_SUCCESS,
  LOAD_EDUC_BILLERS_FAILURE,
  BILL_PAY_REQUEST,
  BILL_PAY_SUCCESS,
  BILL_PAY_FAILURE,
} from "@/redux/constants/bbps.constants";

const billlersReducer = (
  state = {
    error: false,
    billers: [],
    loading: true,
    loadingButton: false,
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case LOAD_BILLERS_REQUEST:
    case LOAD_EDUC_BILLERS_REQUEST:
      return {
        ...state,
        billers: [],
        loading: true,
      };
    case LOAD_BILLERS_SUCCESS:
    case LOAD_EDUC_BILLERS_SUCCESS:
      console.log(action.payload);
      return {
        ...state,
        billers: [...action.payload],
        loading: false,
      };
    case LOAD_BILLERS_FAILURE:
    case LOAD_EDUC_BILLERS_FAILURE:
      return {
        ...state,
        error: action.payload,
        billers: [...state.billers],
        loading: false,
      };

    case RESET_BILLERS:
      return {
        loading: false,
        billers: [],
      };

    default:
      return state;
  }
};

const inputFieldsReducer = (
  state = {
    error: false,
    fields: [],
    loading: true,
    billerInfo: {},
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case LOAD_INPUT_FIELDS_REQUEST:
      return {
        ...state,
        fields: [],
        billerInfo: {},
        loading: true,
      };
    case LOAD_INPUT_FIELDS_SUCCESS:
      return {
        ...state,
        fields: [...action.payload.paramInfo],
        billerInfo: { ...action.payload.billerInfo },
        loading: false,
      };
    case LOAD_INPUT_FIELDS_FAILURE:
      return {
        ...state,
        error: action.payload,
        fields: [...state.fields],
        billerInfo: { ...state.billerInfo },
        loading: false,
      };
    case RESET_INPUT_FIELDS:
      return {
        ...state,
        error: action.payload,
        fields: [],
        billerInfo: {},
        loading: false,
      };

    default:
      return state;
  }
};

const billFetchReducer = (
  state = {
    error: false,
    bill_details: {},
    loading: true,
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case LOAD_BILL_FETCH_REQUEST:
      return {
        ...state,
        bill_details: {},
        loading: true,
        loadingButton: true,
      };
    case LOAD_BILL_FETCH_SUCCESS:
      return {
        ...state,
        bill_details: { ...action.payload },
        loading: false,
        loadingButton: false,
      };
    case LOAD_BILL_FETCH_FAILURE:
      return {
        ...state,
        error: action.payload,
        bill_details: { ...state.bill_details },
        loading: false,
        loadingButton: false,
      };
    case LOADING_BUTTON_RESET:
      return {
        ...state,
        loadingButton: false,
      };

    default:
      return state;
  }
};

const billPayReducer = (
  state = {
    error: false,
    bill_paid_details: {
      transactionStatus: "Successful",
      dueDate: "2022-01-10",
      approvalRefNumber: "AB123456",
      transactionRefId: "CC012017BAAA07654297",
      billDate: "2022-01-10",
      responseStatus: true,
      billNumber: "32044202218519",
      customerName: "PRAKASH",
      billPeriod: "202201",
      billAmount: "24400",
      convCharge: "0",
    },
    loading: true,
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case BILL_PAY_REQUEST:
      return {
        ...state,
        bill_paid_details: {},
        loading: true,
        loadingButton: true,
      };
    case BILL_PAY_SUCCESS:
      return {
        ...state,
        bill_paid_details: { ...action.payload },
        loading: false,
        loadingButton: false,
        warningOnRefresh: false,
      };
    case BILL_PAY_FAILURE:
      return {
        ...state,
        error: action.payload,
        bill_paid_details: { ...state.bill_details },
        loading: false,
        loadingButton: false,
        warningOnRefresh: false,
      };
    case LOADING_BUTTON_RESET:
      return {
        ...state,
        loadingButton: false,
      };

    default:
      return state;
  }
};

export {
  billlersReducer,
  inputFieldsReducer,
  billFetchReducer,
  billPayReducer,
};
