import { HYDRATE } from "next-redux-wrapper";
import {
  SEND_COMPLAINT_FAILURE,
  SEND_COMPLAINT_REQUEST,
  SEND_COMPLAINT_SUCCESS,
  GET_COMPLAINT_STATUS_FAILURE,
  GET_COMPLAINT_STATUS_REQUEST,
  GET_COMPLAINT_STATUS_SUCCESS,
  GET_COMPLAINT_TRANSACTION_HISTORY_FAILURE,
  GET_COMPLAINT_TRANSACTION_HISTORY_REQUEST,
  GET_COMPLAINT_TRANSACTION_HISTORY_SUCCESS,
} from "../constants/complaints.constants";

const complaintsReducer = (
  state = {
    error: false,
    complaint: {},

    loading: true,
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case SEND_COMPLAINT_REQUEST:
      return {
        ...state,
        complaint: {},
        loading: true,
      };
    case SEND_COMPLAINT_SUCCESS:
      console.log(action.payload);
      return {
        ...state,
        complaint: { ...action.payload },
        loading: false,
      };
    case SEND_COMPLAINT_FAILURE:
      return {
        ...state,
        error: action.payload,
        complaint: { ...state.complaint },
        loading: false,
      };

    default:
      return state;
  }
};
const complaintStatusReducer = (
  state = {
    error: false,
    complaint_status: [],
    loading: true,
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case GET_COMPLAINT_STATUS_REQUEST:
      return {
        ...state,
        complaint_status: [],
        loading: true,
      };
    case GET_COMPLAINT_STATUS_SUCCESS:
      action.payload.data instanceof Array ? console.log("yes") : "no";
      return {
        ...state,
        complaint_status:
          action.payload.data instanceof Array
            ? [...action.payload.data]
            : { ...action.payload },
        loading: false,
      };
    case GET_COMPLAINT_STATUS_FAILURE:
      return {
        ...state,
        error: action.payload,
        complaint_status:
          state.complaint_status instanceof Array
            ? [...state.complaint_status]
            : { ...state.complaint_status[0] },
        loading: false,
      };

    default:
      return state;
  }
};

const complaintstTransactionReducer = (
  state = {
    error: false,
    transaction_history: [],
    loading: true,
  },
  action
) => {
  switch (action.type) {
    case HYDRATE: {
      return { ...state, ...action.payload };
    }
    case GET_COMPLAINT_TRANSACTION_HISTORY_REQUEST:
      return {
        ...state,
        transaction_history: [],
        loading: true,
      };
    case GET_COMPLAINT_TRANSACTION_HISTORY_SUCCESS:
      console.log(action.payload);
      return {
        ...state,
        transaction_history: [...action.payload],
        loading: false,
      };
    case GET_COMPLAINT_TRANSACTION_HISTORY_FAILURE:
      return {
        ...state,
        error: action.payload,
        transaction_history: [...state.transaction_history],
        loading: false,
      };

    default:
      return state;
  }
};

export {
  complaintsReducer,
  complaintStatusReducer,
  complaintstTransactionReducer,
};
