import {
  call,
  delay,
  put,
  takeEvery,
  takeLatest,
} from "@redux-saga/core/effects";
import axios from "axios";
import { setAlertMessage } from "../actions/alert.action";
import Cookies from "js-cookie";
import ModalExample from "@/components/Layout/Drawer/ModalExample";
import {
  LOGIN_OTP_FAILED,
  LOGIN_OTP_REQUEST,
  LOGIN_OTP_SUCCESS,
  REGISTER_USER_REQUEST,
  REGISTER_USER_SUCCESS,
  SET_OTP_FAILED,
  SET_OTP_REQUEST,
  SET_OTP_SUCCESS,
  GET_PROFILE_REQUEST,
  LOGIN_VALIDATE_SUCCESS,
  LOGIN_VALIDATE_FAILED,
  LOGIN_VALIDATE_REQUEST,
  USER_VALIDATE_SUCCESS,
  USER_VALIDATE_FAILED,
  USER_VALIDATE_REQUEST,
  UPDATE_PROFILE_SUCCESS,
  UPDATE_PROFILE_REQUEST,
  NEW_LOGIN_REQUEST,
  NEW_LOGIN_SUCCESS,
  NEW_LOGIN_FAILED,
} from "../constants/auth.constants";
import { closeDrawer, openDrawer } from "../actions/drawer.actions";
import LoginComponent from "@/screens/LoginComponent";
import SignUpComponent from "@/screens/SignUpComponent";
import {
  getMyProfile,
  populateProfile,
  populateProfileFailed,
} from "../actions/auth.actions";
import { toast } from "react-toastify";

/*----------------------------------
        LOGIN OTP          
==================================*/
function* loginSendOtp({ payload }) {
  try {
    yield put(setAlertMessage(false, "", ""));
    const result = yield call(sendOtpUser, payload);
    yield delay(400);
    yield put({
      type: LOGIN_OTP_SUCCESS,
      payload: result,
    });
    if (result.err === "01") {
      // yield put(setAlertMessage(true, "error", result.message));
      toast.success(result.message, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
    } else if (
      result.err_code === 0 &&
      result.Status.toUpperCase() === "SUCCESS"
    ) {
      // yield put(setAlertMessage(true, "success", result.err_msg));
      toast.success(result.err_msg, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
    } else {
      // yield put(setAlertMessage(true, "error", result.message));
      toast.error(result.message || "Logged in Successfully", {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
      yield delay(1000);
      yield put(closeDrawer({ modalProps: { open: false } }));
      yield put(
        openDrawer({
          modalType: ModalExample,
          modalProps: {
            component: <SignUpComponent mbl={payload.mbl} />,
            open: true,
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
    }
    // yield put(push("/dashboard"));
  } catch (error) {
    yield delay(400);
    yield put({ type: LOGIN_OTP_FAILED, payload: error });
    // yield put(setSnackbar(true, "error", "Invalid Email or Password"));
  }
}
export function* sendOtpUserSaga() {
  yield takeLatest(LOGIN_OTP_REQUEST, loginSendOtp);
}

async function sendOtpUser(payload) {
  const { mbl } = payload;
  const response = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: mbl,
      device: "12345",
    },
  });

  const getLogin = async () => {
    const resposne = await axios.post(
      `https://aaipay.in:10002/api/apps/v1/loginOTP.jsp?mbl=${mbl}`,
      {
        "content-type": "application/json",
      }
    );
    return resposne.data;
  };

  const data = response.data.err === "01" ? getLogin() : response.data;
  return data;
}

/*----------------------------------
          REGISTER USER          
==================================*/
/* https://aaipay.in:10002/api/apps/v1/new_userRegister.jsp?mbl=8595730637&mail=atul@gmail.com&pass=Abc@12345&mac=e4:b5:3:6e:95:ef&name=atul */

function* registerUser({ payload }) {
  try {
    yield put(setAlertMessage(false, "", ""));
    const result = yield call(registerUserTask, payload);
    yield delay(1000);
    yield put({
      type: REGISTER_USER_SUCCESS,
      payload: result,
    });
    if (result.status.toUpperCase() === "Success".toUpperCase()) {
      // yield put(setAlertMessage(true, "success", result.msg));
      toast.success(result.msg, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
      yield delay(1000);
      // yield put(closeDrawer({ modalProps: { open: false } }));
      // yield put(
      //   openDrawer({
      //     modalType: ModalExample,
      //     modalProps: {
      //       component: <LoginComponent mbl={payload.mbl} setOtpSent={true} />,
      //       open: true,
      //       // setOpen: setOpen,
      //       widthDrawer: 800,
      //       closeDrawerAction: true,
      //     },
      //   })
      // );
    } else {
      // yield put(setAlertMessage(true, "error", result.msg));
      toast.error(result.msg || "Logged in Successfully", {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
    }
    // yield put(push("/dashboard"));
  } catch (error) {
    yield delay(400);
    yield put({ type: LOGIN_OTP_FAILED, payload: error });
    // yield put(setSnackbar(true, "error", "Invalid Email or Password"));
  }
}
export function* registerUserSaga() {
  yield takeLatest(REGISTER_USER_REQUEST, registerUser);
}

async function registerUserTask(payload) {
  const { mbl, fullName, email, owId } = payload;

  const { data } = await axios.post(
    `https://aaipay.in:10002/api/apps/v1/new_userRegister.jsp?mbl=${mbl}&mail=${email}&pass=Abc@12345&mac=e4:b5:3:6e:95:ef&name=${fullName}&owId=${owId}`,
    {
      "content-type": "application/json",
    }
  );

  return data;
}

/*----------------------------------
         SET OTP          
==================================*/
/* https://aaipay.in:10002/api/apps/v1/otp_validation.jsp?mbl=8595730637&otp=233759&mac=e4:b5:3:6e:95:ef*/

function* setOtp({ payload }) {
  console.log(payload);
  const { history } = payload;
  try {
    yield put(setAlertMessage(false, "", ""));
    const result = yield call(setOtpUserTask, payload);
    yield delay(400);
    yield put({
      type: SET_OTP_SUCCESS,
      payload: result,
    });
    if (result.data.status.toUpperCase() === "Success".toUpperCase()) {
      // yield put(
      //   setAlertMessage(
      //     true,
      //     "success",
      //     result.data.msg || "Logged in Successfully"
      //   )
      // );
      toast.success(result.data.msg || "Logged in Successfully", {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });

      yield delay(1000);
      const { regId, mobile } = result.data.data;
      Cookies.set("regId", regId);
      Cookies.set("mobile", mobile);

      yield put(getMyProfile(regId, mobile));

      yield put(closeDrawer({ modalProps: { open: false } }));
      if (history.pathname === "/register/[owId]") {
        history.push("/mobile");
      }
      // const currentHref = window.location.pathname;

      // if (window.location.href !== `${window.location.origin}/${currentHref}`) {
      //   // Redirect logic
      //   window.location.href = `/${currentHref}`;
      // }
    } else {
      // yield put(
      //   setAlertMessage(
      //     true,
      //     "error",
      //     result.data.message ?? result.data.data.msg
      //   )
      // );
      toast.error(result.data.message ?? result.data.data.msg, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
    }
    // yield put(push("/dashboard"));
  } catch (error) {
    yield delay(400);
    yield put({ type: SET_OTP_FAILED, payload: error });
    // yield put(setSnackbar(true, "error", "Invalid Email or Password"));
  }
}
export function* setOtpUserSaga() {
  yield takeLatest(SET_OTP_REQUEST, setOtp);
}

async function setOtpUserTask(payload) {
  const { mbl, otp } = payload;
  Cookies.set("password", otp);
  const responseUserValidation = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: mbl,
      device: "12345",
    },
  });

  Cookies.set("loginKey", responseUserValidation.data.loginKey);
  const ipAddressResult = await axios.get("https://geolocation-db.com/json/");
  const ipAddress = await ipAddressResult.data.IPv4;
  Cookies.set("ip", ipAddress);
  const responseData = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/login_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: mbl,
      data: {
        device: "1244115844",
        ip: ipAddress,
        login_key: responseUserValidation.data.loginKey,
        password: otp,
      },
    },
  });

  return responseData;
}

/*----------------------------
       MY PROFILE
============================*/

export function* onFetchMyProfile() {
  yield takeLatest(GET_PROFILE_REQUEST, fetchProfile);
}
function* fetchProfile({ payload }) {
  try {
    if (payload) {
      const { reg_id, mbl } = payload;
      console.log(payload);

      const { data } = yield axios.get(
        `https://aaipay.in:10002/api/apps/v1/show_profile.jsp?reg_id=${reg_id}&mbl=${mbl}`,
        {
          "content-type": "application/json",
        }
      );
      // yield delay(300);
      yield put(populateProfile(data));
    }
  } catch (err) {
    yield put(populateProfileFailed(err.message));
  }
}

// /*----------------------------------
//            LOGIN VALIDATE
// ==================================*/

function* validateLoginOtp(payload) {
  try {
    yield put(setAlertMessage(false, "", ""));
    const result = yield call(validateLoginUser, payload.payload);
    yield delay(400);
    yield put({
      type: LOGIN_VALIDATE_SUCCESS,
      payload: result,
    });
    const regId = Cookies.get("regId");
    const mobile = Cookies.get("mobile");
    if (result.status !== "FAILED") {
      yield put(getMyProfile(regId, mobile));
    }
    if (
      result.status === "FAILED" ||
      result.status === null ||
      typeof result.status === "undefined"
    ) {
      // console.log(window.location.origin);
      // if (window.location.href !== `${window.location.origin}/mobile`) {
      //   // Redirect logic

      //   window.location.replace("/mobile");
      // }
      console.log("failed");
    } else {
      yield put(getMyProfile(regId, mobile));
    }
  } catch (error) {
    yield delay(400);
    yield put({ type: LOGIN_VALIDATE_FAILED, payload: error });
  }
}
export function* validateLoginSaga() {
  yield takeLatest(LOGIN_VALIDATE_REQUEST, validateLoginOtp);
}

async function validateLoginUser(payload) {
  const { mobile, ip, loginKey, password } = payload;

  const { data } = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/login_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: mobile,
      data: {
        device: "1244115844",
        ip: ip,
        login_key: loginKey,
        password: password,
      },
    },
  });
  return data;
}

// /*----------------------------------
//            USER VALIDATE
// ==================================*/

export function* validateUser({ payload }) {
  try {
    yield put(setAlertMessage(false, "", ""));
    const result = yield call(validateUserReq, payload);
    yield put({
      type: USER_VALIDATE_SUCCESS,
      payload: result,
    });
  } catch (error) {
    yield put({ type: USER_VALIDATE_FAILED, payload: error });

    console.log(error);
  }
}
export function* validateUserSaga() {
  yield takeLatest(USER_VALIDATE_REQUEST, validateUser);
}

async function validateUserReq(payload) {
  const { mobile } = payload;

  const { data } = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: mobile || Cookies.get("mobile"),
      device: "1244115844",
    },
  });
  return data;
}

/*----------------------------------
       UPDATE profile
==================================*/
export function* updateProfileSaga() {
  yield takeEvery(UPDATE_PROFILE_REQUEST, updateProfileEntryToDb);
}
function* updateProfileEntryToDb({ payload }) {
  try {
    // console.log();
    const result = yield call(updateProfile, payload);
    yield delay(700);
    yield put({ type: UPDATE_PROFILE_SUCCESS });
    yield put(setAlertMessage(true, "success", result.msg));
  } catch (error) {
    // yield put(setSnackbar(true, "error", "Something Went Wrong"));
  }
}
async function updateProfile(payload) {
  const regId = Cookies.get("regId");
  const { Mobile, Email, Address, gender, Name, zip, city, state } = payload;

  const { data } = await axios.post(
    `https://aaipay.in:10002/api/apps/v1/update_profile.jsp?Pname=${Name}&Pgender=${gender}&reg_no=${regId}&PhomePhone=&Pcity=${city}&Pstate=${state}&Ppin=${zip}&Paddress=${Address}&reg_mbl=${Mobile}&mail=${Email}`,
    {
      "content-type": "application/json",
    }
  );

  return data;
}

/*----------------------------------
          NEW LOGIN USER          
==================================*/

/* https://aaipay.in:10002/api/apps/v1/otp_validation.jsp?mbl=8595730637&otp=233759&mac=e4:b5:3:6e:95:ef*/

function* setOtpNewUser({ payload }) {
  console.log(payload);
  const { history } = payload;
  try {
    yield put(setAlertMessage(false, "", ""));
    const result = yield call(setOtpNewUserTask, payload);
    yield delay(400);
    yield put({
      type: NEW_LOGIN_SUCCESS,
      payload: result,
    });
    if (result.data.status.toUpperCase() === "Success".toUpperCase()) {
      toast.success(result.data.msg || "Logged in Successfully", {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });

      yield delay(1000);
      const { regId, mobile } = result.data.data;
      Cookies.set("regId", regId);
      Cookies.set("mobile", mobile);

      yield put(getMyProfile(regId, mobile));

      yield put(closeDrawer({ modalProps: { open: false } }));
      if (history.pathname === "/register/[owId]") {
        history.push("/mobile");
      }
    } else {
      toast.error(result.data.message ?? result.data.data.msg, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
    }
    // yield put(push("/dashboard"));
  } catch (error) {
    yield delay(400);
    yield put({ type: NEW_LOGIN_FAILED, payload: error });
    // yield put(setSnackbar(true, "error", "Invalid Email or Password"));
  }
}
export function* setOtpNewUserSaga() {
  yield takeLatest(NEW_LOGIN_REQUEST, setOtpNewUser);
}

async function setOtpNewUserTask(payload) {
  const { mbl, otp, owId } = payload;
  Cookies.set("password", otp);
  const response = await axios.post(
    `https://aaipay.in:10002/api/apps/v1/otp_validation.jsp?mbl=${mbl}&otp=${otp}&mac=e4:b5:3:6e:95:ef&owId=${owId}`,
    {
      "content-type": "application/json",
    }
  );
  if (response.data.err === 305) {
    toast.error(response.data.msg, {
      position: "top-center",
      autoClose: 5000,
      hideProgressBar: false,
      closeOnClick: true,
      pauseOnHover: true,
      draggable: true,
      progress: undefined,
    });
    return false;
  }
  const responseUserValidation = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: mbl,
      device: "12345",
    },
  });

  Cookies.set("loginKey", responseUserValidation.data.loginKey);
  const ipAddressResult = await axios.get("https://geolocation-db.com/json/");
  const ipAddress = await ipAddressResult.data.IPv4;
  Cookies.set("ip", ipAddress);
  const responseData = await axios({
    method: "POST",
    url: "https://aaipay.in:10002/api/apps/v1/login_validate.jsp",
    headers: { "content-type": "application/json" },
    data: {
      mobile: response?.data?.data?.mobile || mbl,
      data: {
        device: "1244115844",
        ip: ipAddress,
        login_key: responseUserValidation.data.loginKey,
        password: otp,
      },
    },
  });

  return responseData;
}
