import { put, takeLatest, call, select } from "@redux-saga/core/effects";
import {
  billPaymentFailed,
  billPaymentSuccess,
  populatedBillers,
  populatedBillersFailed,
  populatedEducationBillers,
  populatedEducationBillersFailed,
  populatedInputFields,
  populatedInputFieldsFailed,
  populateFetchedBill,
  populateFetchedBillFailed,
} from "@/redux/actions/bbps.actions";
import {
  LOADING_BUTTON_RESET,
  LOAD_BILLERS_REQUEST,
  LOAD_BILL_FETCH_REQUEST,
  LOAD_EDUC_BILLERS_REQUEST,
  LOAD_INPUT_FIELDS_REQUEST,
  BILL_PAY_REQUEST,
} from "@/redux/constants/bbps.constants";
import axios from "axios";
import Cookies from "js-cookie";
import { closeDrawer, openDrawer } from "../actions/drawer.actions";
import LoginComponent from "@/screens/LoginComponent";
import DrawerExample from "@/components/Layout/Drawer/ModalExample";
import ModalExample from "@/components/Layout/Modal/ModalExample";
import { setAlertMessage } from "../actions/alert.action";
import { closeModal, openModal } from "../actions/modal.actions";
import BillFetchComponent from "@/screens/BillFetchComponent/BillFetchComponent";
import QuickPayComponent from "@/screens/QuickPayComponent";
import { toast } from "react-toastify";
import { validateLoginUser } from "@/components/RequireAuthentication/RequireAuthentication";
import api from "../config/api.main";
import { getWalletBalance } from "../actions/passbook.action";
import { capitalize } from "utils/customFunctions";
import { couponCode } from "@/components/CouponCode";
import BillPaidComponent from "@/screens/BillPaidComponent";

export function* getAllBillers() {
  yield takeLatest(LOAD_BILLERS_REQUEST, fetchBillers);
}
function* fetchBillers({ payload }) {
  try {
    const {
      data: { data },
    } = yield call(api, `/BillPay/getBillers.jsp?serviceTypeId=${payload}`);

    yield put(populatedBillers(data));
  } catch (error) {
    yield put(
      populatedBillersFailed(typeof error !== "object" ? error : error.message)
    );
  }
}

/*----------------------------------
          BILLERS EDUCATION          
==================================*/

export function* getAllBillersEducation() {
  yield takeLatest(LOAD_EDUC_BILLERS_REQUEST, fetchBillersEducation);
}
function* fetchBillersEducation({ payload }) {
  try {
    console.log(payload);
    const {
      data: { data },
    } = yield call(
      api,
      `/BillPay/getBlrsByCity.jsp?billerCity=${payload.city}&serviceTypeId=${payload.serviceId}`
    );

    yield put(populatedEducationBillers(data));
  } catch (error) {
    yield put(
      populatedEducationBillersFailed(
        typeof error !== "object" ? error : error.message
      )
    );
  }
}

/*----------------------------------
          INPUT FIELDS          
==================================*/
export function* getAllInputFields() {
  yield takeLatest(LOAD_INPUT_FIELDS_REQUEST, fetchInputFields);
}
function* fetchInputFields({ payload }) {
  try {
    const { data } = yield call(
      api,
      `/BillPay/getBillerInputParams.jsp?billerId=${payload}`
    );

    yield put(populatedInputFields(data));
  } catch (error) {
    yield put(
      populatedInputFieldsFailed(
        typeof error !== "object" ? error : error.message
      )
    );
  }
}

/*----------------------------------
          BILL FETCH          
==================================*/
export function* getBillFetchSaga() {
  yield takeLatest(LOAD_BILL_FETCH_REQUEST, billFetch);
}
function* billFetch({ payload }) {
  /*   blrStateCode: "",
  blrStateName: "",
  blrCity: "", */
  const {
    billFetch,
    cust_mbl,
    billerInfo,
    blrStateName,
    blrStateCode,
    blrCity,
    preferredMethod,
    ...restPayload
  } = payload;
  try {
    const mobile = Cookies.get("mobile");
    const ip = Cookies.get("ip");
    const loginKey = Cookies.get("loginKey");
    const password = Cookies.get("password");

    const result = yield validateLoginUser({
      mobile,
      ip,
      loginKey,
      password,
    });

    if (result.status !== "FAILED") {
      const { data } = yield axios.get(
        `https://aaipay.in:10002/api/apps/v1/BillPay/billFetch.jsp`,
        {
          params: {
            ...restPayload,
            custmbl: Cookies.get("mobile"),
          },
        }
      );

      yield put(populateFetchedBill(data));
      yield Cookies.set("billFetchData", JSON.stringify(data));
      yield put(closeModal({ modalProps: { open: false } }));
      console.log(restPayload, "restPayload");
      if (data.responseStatus === true) {
        yield put(
          openModal({
            modalType: ModalExample,
            modalProps: {
              component:
                billFetch === true ? (
                  <BillFetchComponent
                    operator={restPayload.billerName}
                    billerInfo={billerInfo}
                  />
                ) : (
                  <QuickPayComponent />
                ),
              open: true,
              // setOpen: setOpen,
              widthDrawer: 800,
              closeDrawerAction: true,
            },
          })
        );
      } else {
        toast.error(data.errorMessage || "Bill cannot be fetched", {
          position: "top-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
        });
      }
    } else {
      yield put(closeDrawer({ modalProps: { open: false } }));
      yield put(
        openDrawer({
          modalType: DrawerExample,
          modalProps: {
            component: <LoginComponent />,
            open: true,
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
      yield put(setAlertMessage(false, "error", ""));
      // yield put(setAlertMessage(true, "error", "Please Login to Continue"));
      toast.error("Please Login to Continue", {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
      yield put({ type: LOADING_BUTTON_RESET });
    }
  } catch (error) {
    yield put(
      populateFetchedBillFailed(
        typeof error !== "object" ? error : error.message
      )
    );
  }
}

/*----------------------------------
          BILL PAID          
==================================*/

export function* payBillSaga() {
  yield takeLatest(BILL_PAY_REQUEST, billPay);
}
function* billPay({ payload }) {
  const {
    billerId,
    customerMobile,
    userId,
    billerResponse,
    addtionalInfo = "",
    requestId,
    pymtModeQuick,
    amt,
    billerAdhoc,
    marginAmount,
    allParams,
  } = payload;
  try {
    const regId = Cookies.get("regId");
    const reg_mobile = Cookies.get("mobile");
    const { data: couponData } = yield select(couponCode);

    const {
      marginType,
      totalAmount,
      billAmount,
      customerName,
      responseStatus,
      billDate,
      dueDate,
      additionalAmount,
      billPeriod,
      billNumber,
      ...rest
    } = JSON.parse(Cookies.get("billFetchData"));
    console.log(rest);
    const { data } = yield api.get(`BillPay/billPayment.jsp`, {
      params: {
        userId,
        billerAdhoc,
        billerId,
        pymtModeQuick,
        amt,
        custmbl: customerMobile,
        ...rest,
        // userId,
        // billerResponse,
        // addtionalInfo,
        // requestId,
        // pymtModeQuick,
        // amt,
        // billerAdhoc,
        // marginAmount,
      },
    });
    yield put(billPaymentSuccess(data));
    if (data.responseStatus === true) {
      yield api.get(
        `cashBack_credit.jsp?transID=${data.transID}&username=${regId}&reg_mobile=${reg_mobile}&cashbackID=${couponData?.cashBackID}`
      );

      yield put(getWalletBalance({ mbl: reg_mobile, reg_id: regId }));
      yield put(
        openModal({
          modalType: ModalExample,
          modalProps: {
            component: <BillPaidComponent />,
            open: true,
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
      // toast.success(`Bill Payment of ₹${amt * 0.01} is completed`, {
      //   position: "top-center",
      //   autoClose: 5000,
      //   hideProgressBar: false,
      //   closeOnClick: true,
      //   pauseOnHover: true,
      //   draggable: true,
      //   progress: undefined,
      // });
      // setLoadingRecharge(false);
      // setChangeWarning(false);
      Cookies.remove("plan");
      Cookies.remove("cpn");
      if (window.location.href !== `${window.location.origin}/mobile`) {
        // Redirect logic
        setTimeout(() => {
          window.location.href = "/mobile";
          Cookies.remove("plan");
          Cookies.remove("cpn");
        }, 3000);
      }
    } else {
      // dispatch(setAlertMessage(true, "error", `${data.res_msg}`));
      toast.error(`${capitalize(data.errorMessage)}`, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
      // setChangeWarning(false);
      // setLoadingRecharge(false);
    }
  } catch (error) {
    yield put(
      billPaymentFailed(typeof error !== "object" ? error : error.message)
    );
  }
}
