import { put, takeLatest, call } from "@redux-saga/core/effects";

import axios from "axios";
import Cookies from "js-cookie";
import { closeDrawer, openDrawer } from "../actions/drawer.actions";
import LoginComponent from "@/screens/LoginComponent";
import DrawerExample from "@/components/Layout/Drawer/ModalExample";
import ModalExample from "@/components/Layout/Modal/ModalExample";
import { setAlertMessage } from "../actions/alert.action";
import { closeModal, openModal } from "../actions/modal.actions";
import ComplaintStatus from "@/screens/ComplaintStatus";
import QuickPayComponent from "@/screens/QuickPayComponent";
import {
  populateComplaint,
  populateComplaintFailed,
  populateComplaintStatus,
  populateComplaintStatusFailed,
  populateComplaintTransactionHistory,
  populateComplaintTransactionHistoryFailed,
  populateQuickPay,
} from "../actions/complaints.action";
import {
  GET_COMPLAINT_STATUS_REQUEST,
  GET_COMPLAINT_TRANSACTION_HISTORY_REQUEST,
  SEND_COMPLAINT_REQUEST,
} from "../constants/complaints.constants";
import SuccessComplaint from "@/screens/SuccessComplaint";
import TransactionComplaint from "@/screens/TransactionComplaint";
// import { BASE_URL } from '@/redux/config/BASE_URL';

/*----------------------------------
      COMPLAINT REGISTER        
==================================*/
export function* sendComplaintSaga() {
  yield takeLatest(SEND_COMPLAINT_REQUEST, sendComplaint);
}
function* sendComplaint({ payload }) {
  const { complaintType, mobileNo, complaintDetails, ...restPayload } = payload;
  try {
    const mobile = Cookies.get("mobile");
    // const result = yield validateUser({ mobile });
    const { data: isUserValid } = yield axios({
      method: "POST",
      url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
      headers: { "content-type": "application/json" },
      data: {
        mobile: mobile,
        device: "1244115844",
      },
    });
    if (isUserValid.err === "01") {
      if (complaintType === "Transaction") {
        const { complaintDispo, txId } = restPayload;
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/complaintRegistration.jsp",
          headers: { "content-type": "application/json" },
          params: {
            complaintType,
            complaintDispo,
            txId,
            mobileNo,
            complaintDetails,
          },
        });
        yield put(populateComplaint(data));
        yield put(closeModal({ modalProps: { open: false } }));

        yield put(
          openModal({
            modalType: ModalExample,
            modalProps: {
              component: <SuccessComplaint />,
              open: true,
              noFullScreen: true,
              maxWidth: "sm",
              // setOpen: setOpen,
              widthDrawer: 800,
              closeDrawerAction: true,
            },
          })
        );
      } else {
        const { serveReason } = restPayload;
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/complaintRegistration.jsp",
          headers: { "content-type": "application/json" },
          params: { complaintType, serveReason, mobileNo, complaintDetails },
        });
        yield put(populateComplaint(data));
      }
    } else {
      yield put(closeDrawer({ modalProps: { open: false } }));
      yield put(
        openDrawer({
          modalType: DrawerExample,
          modalProps: {
            component: <LoginComponent />,
            open: true,
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
      yield put(setAlertMessage(false, "error", ""));
      yield put(setAlertMessage(true, "error", "Please Login to Continue"));
    }
  } catch (error) {
    yield put(
      populateComplaintFailed(typeof error !== "object" ? error : error.message)
    );
  }
}

/*----------------------------------
      COMPLAINT STATUS        
==================================*/
export function* getComplaintStatusSaga() {
  yield takeLatest(GET_COMPLAINT_STATUS_REQUEST, getComplaintStatus);
}
function* getComplaintStatus({ payload }) {
  const {
    searchBy,

    ...restPayload
  } = payload;
  try {
    const mobile = Cookies.get("mobile");
    // const result = yield validateUser({ mobile });
    const { data: isUserValid } = yield axios({
      method: "POST",
      url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
      headers: { "content-type": "application/json" },
      data: {
        mobile: mobile,
        device: "1244115844",
      },
    });
    if (isUserValid.err === "01") {
      if (searchBy === "byComplaintId") {
        /* https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp?complaintId=IY1496326110849&complaintType=Transaction&searchBy=byComplaintId */
        const { complaintType, complaintId } = restPayload;
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp",
          headers: { "content-type": "application/json" },
          params: {
            searchBy,
            complaintType,
            complaintId,
          },
        });

        if (data.data.length === 0) {
          yield put(populateComplaintStatus({}));
        }
        if (data.data.length > 0)
          yield put(populateComplaintStatus(data?.data[0]));
        yield put(closeModal({ modalProps: { open: false } }));

        yield put(
          openModal({
            modalType: ModalExample,
            modalProps: {
              component: <ComplaintStatus />,
              open: true,
              noFullScreen: true,
              maxWidth: "sm",
              // setOpen: setOpen,
              widthDrawer: 800,
              closeDrawerAction: true,
            },
          })
        );
      } else {
        const { fromDate, toDate } = restPayload;
        const yearFrom = fromDate.getFullYear();
        const monthFrom = `${fromDate.getMonth() + 1}`;
        const monthFromWithZero = monthFrom.padStart(2, 0);
        const dateFrom = `${fromDate.getDate()}`;
        const dateFromWithoutZero = dateFrom.padStart(2, 0);
        const fullDateFrom = `${yearFrom}-${monthFromWithZero}-${dateFromWithoutZero}`;
        const yearTo = toDate.getFullYear();
        const monthTo = `${toDate.getMonth() + 1}`;
        const monthToWithZero = monthTo.padStart(2, 0);
        const dateTo = `${toDate.getDate()}`;
        const dateToWithoutZero = dateTo.padStart(2, 0);
        const fullDateTo = `${yearTo}-${monthToWithZero}-${dateToWithoutZero}`;
        /* https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp?fromDate=2021-11-19&toDate=2021-11-20&searchBy=byDateRange */
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp",
          headers: { "content-type": "application/json" },
          params: { searchBy, fromDate: fullDateFrom, toDate: fullDateTo },
        });
        console.log(data.data);
        yield put(populateComplaintStatus(data));
        yield put(closeModal({ modalProps: { open: false } }));

        yield put(
          openModal({
            modalType: ModalExample,
            modalProps: {
              component: <ComplaintStatus />,
              open: true,
              noFullScreen: true,
              maxWidth: "sm",
              // setOpen: setOpen,
              widthDrawer: 800,
              closeDrawerAction: true,
            },
          })
        );
      }
    } else {
      yield put(closeDrawer({ modalProps: { open: false } }));
      yield put(
        openDrawer({
          modalType: DrawerExample,
          modalProps: {
            component: <LoginComponent />,
            open: true,
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
      yield put(setAlertMessage(false, "error", ""));
      yield put(setAlertMessage(true, "error", "Please Login to Continue"));
    }
  } catch (error) {
    yield put(
      populateComplaintStatusFailed(
        typeof error !== "object" ? error : error.message
      )
    );
  }
}

/*----------------------------------
      COMPLAINT TRANSACTION SEARCH        
==================================*/
export function* getComplaintTransactionHistorySaga() {
  yield takeLatest(
    GET_COMPLAINT_TRANSACTION_HISTORY_REQUEST,
    getComplaintTransactionHistory
  );
}
function* getComplaintTransactionHistory({ payload }) {
  const { searchBy, ...restPayload } = payload;
  try {
    const mobile = Cookies.get("mobile");
    // const result = yield validateUser({ mobile });
    const { data: isUserValid } = yield axios({
      method: "POST",
      url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
      headers: { "content-type": "application/json" },
      data: {
        mobile: mobile,
        device: "1244115844",
      },
    });
    if (isUserValid.err === "01") {
      if (searchBy === "searchById") {
        /* https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp?complaintId=IY1496326110849&complaintType=Transaction&searchBy=byComplaintId */
        const { txnId } = restPayload;
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/transactionHistory.jsp",
          headers: { "content-type": "application/json" },
          params: {
            searchBy,
            txnId,
          },
        });

        yield put(populateComplaintTransactionHistory(data.data));
      }
      if (searchBy === "searchByMobileNo") {
        /* https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp?complaintId=IY1496326110849&complaintType=Transaction&searchBy=byComplaintId */
        const { mobNo } = restPayload;
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/transactionHistory.jsp",
          headers: { "content-type": "application/json" },
          params: {
            searchBy,
            mobNo,
          },
        });
      }
      if (searchBy === "searchByDateRange") {
        const { fromDate, toDate } = restPayload;
        const yearFrom = fromDate.getFullYear();
        const monthFrom = `${fromDate.getMonth() + 1}`;
        const monthFromWithZero = monthFrom.padStart(2, 0);
        const dateFrom = `${fromDate.getDate()}`;
        const dateFromWithoutZero = dateFrom.padStart(2, 0);
        const fullDateFrom = `${yearFrom}-${monthFromWithZero}-${dateFromWithoutZero}`;
        const yearTo = toDate.getFullYear();
        const monthTo = `${toDate.getMonth() + 1}`;
        const monthToWithZero = monthTo.padStart(2, 0);
        const dateTo = `${toDate.getDate()}`;
        const dateToWithoutZero = dateTo.padStart(2, 0);
        const fullDateTo = `${yearTo}-${monthToWithZero}-${dateToWithoutZero}`;
        /* https://aaipay.in:10002/api/apps/v1/BillPay/complaintHistory.jsp?fromDate=2021-11-19&toDate=2021-11-20&searchBy=byDateRange */
        const { data } = yield axios({
          method: "GET",
          url: "https://aaipay.in:10002/api/apps/v1/BillPay/transactionHistory.jsp",
          headers: { "content-type": "application/json" },
          params: { searchBy, fromDate: fullDateFrom, toDate: fullDateTo },
        });
        console.log(data.data);
        yield put(populateComplaintTransactionHistory(data.data));
      }
      yield put(closeModal({ modalProps: { open: false } }));

      yield put(
        openModal({
          modalType: ModalExample,
          modalProps: {
            component: <TransactionComplaint />,
            open: true,
            noFullScreen: true,
            maxWidth: "md",
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
    } else {
      yield put(closeDrawer({ modalProps: { open: false } }));
      yield put(
        openDrawer({
          modalType: DrawerExample,
          modalProps: {
            component: <LoginComponent />,
            open: true,
            // setOpen: setOpen,
            widthDrawer: 800,
            closeDrawerAction: true,
          },
        })
      );
      yield put(setAlertMessage(false, "error", ""));
      yield put(setAlertMessage(true, "error", "Please Login to Continue"));
    }
  } catch (error) {
    yield put(
      populateComplaintTransactionHistoryFailed(
        typeof error !== "object" ? error : error.message
      )
    );
  }
}
