import {
  call,
  delay,
  put,
  takeEvery,
  takeLatest,
} from "@redux-saga/core/effects";
import axios from "axios";
import { setAlertMessage } from "../actions/alert.action";
import Cookies from "js-cookie";

import {
  GET_PASSBOOK_REQUEST,
  GET_WALLET_REQUEST,
} from "../constants/passbook.constants";
import {
  populatePassBook,
  populatePassBookFailed,
  populateWalletBalance,
  populateWalletBalanceFailed,
} from "../actions/passbook.action";
import { userValidate } from "../actions/auth.actions";
import { validateUser, validateUserSaga } from "./auth.saga";
import api from "../config/api.main";
const mobile = Cookies.get("mobile");
/*----------------------------
     PASSBOOK
============================*/

export function* onFetchMyPassbook() {
  yield takeLatest(GET_PASSBOOK_REQUEST, fetchPassbook);
}
function* fetchPassbook({ payload }) {
  try {
    const mobile = Cookies.get("mobile");
    // const result = yield validateUser({ mobile });
    const { data } = yield api({
      method: "POST",
      url: "user_validate.jsp",
      headers: { "content-type": "application/json" },
      data: {
        mobile: mobile,
        device: "1244115844",
      },
    });

    if (data.err === "01") {
      if (payload) {
        const { reg_id, mbl } = payload;

        const { data } = yield api.get(
          `passbook.jsp?reg_id=${reg_id}&mbl=${mobile}`
        );
        yield delay(300);
        yield put(populatePassBook(data));
      } else {
        Cookies.remove("loginKey");
        Cookies.remove("ip");
        Cookies.remove("mobile");
        Cookies.remove("regId");
        Cookies.remove("password");
      }
    }
  } catch (err) {
    yield put(populatePassBookFailed(err.message));
  }
}

/*----------------------------
     PASSBOOK
============================*/

export function* onFetchWallet() {
  yield takeEvery(GET_WALLET_REQUEST, fetchWalletBalance);
}
function* fetchWalletBalance({ payload }) {
  try {
    const mobile = Cookies.get("mobile");
    // const result = yield validateUser({ mobile });
    const { data } = yield axios({
      method: "POST",
      url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
      headers: { "content-type": "application/json" },
      data: {
        mobile: mobile,
        device: "1244115844",
      },
    });

    if (data.err === "01") {
      if (payload) {
        const { reg_id, mbl } = payload;
        const { data } = yield axios.get(
          `https://aaipay.in:10002/api/apps/v1/wallet_checkBal.jsp?reg_id=${reg_id}&mbl=${mbl}`,
          {
            "content-type": "application/json",
          }
        );
        yield put(populateWalletBalance(data));
      } else {
        Cookies.remove("loginKey");
        Cookies.remove("ip");
        Cookies.remove("mobile");
        Cookies.remove("regId");
        Cookies.remove("password");
      }
    }
  } catch (err) {
    yield put(populateWalletBalanceFailed(err.message));
  }
}
