import ModalExample from "@/components/Layout/Modal/ModalExample";
import { modalData } from "@/components/Layout/Modal/ModalRedux";
import UPIPaymentComponent, {
  upiPaymentData,
} from "@/components/UPIPaymentComponent";
import Cookies from "js-cookie";
import { toast } from "react-toastify";
import { END, eventChannel } from "redux-saga";
import { call, delay, put, select, take, takeLatest } from "redux-saga/effects";
import Swal from "sweetalert2";
import { capitalize } from "utils/customFunctions";
import { closeModal, openModal } from "../actions/modal.actions";
import {
  checkStatusOfPaymentFailed,
  checkStatusOfPaymentSuccess,
  sendUpiPaymentFailed,
  sendUpiPaymentSuccess,
} from "../actions/upi.payment.action";
import api from "../config/api.main";
import {
  CHECK_STATUS_PAYMENT_REQUEST,
  SEND_UPI_PAYMENT_REQUEST,
} from "../constants/upi.constants";

export function* sendUpiPaymentSaga() {
  yield takeLatest(SEND_UPI_PAYMENT_REQUEST, sendUPI);
}
function* sendUPI({ payload }) {
  const { payerVa, amount, note = "upi payment" } = payload;
  try {
    const user_id = Cookies.get("regId");
    // const { data: couponData } = yield select(couponCode);
    const { data } = yield api.get(`UPI/collectPayment.jsp`, {
      params: { payerVa, amount, note, user_id },
    });
    if (data.success === "true") {
      yield put(sendUpiPaymentSuccess(data));
      toast.success(data.message, {
        position: "top-center",
        autoClose: 2000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
      yield put(
        openModal({
          modalType: ModalExample,
          modalProps: {
            component: <UPIPaymentComponent amount={amount} />,
            open: true,
            closeDrawerAction: false,
            fullScreenAt: "sm",
          },
        })
      );
    } else if (data.success === "false") {
      yield put(sendUpiPaymentFailed(data.message));
      toast.error(`${capitalize(data.message)}`, {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
    }
  } catch (error) {
    yield put(
      sendUpiPaymentFailed(typeof error !== "object" ? error : error.message)
    );
    toast.error(`Something Went Wrong !!`, {
      position: "top-center",
      autoClose: 5000,
      hideProgressBar: false,
      closeOnClick: true,
      pauseOnHover: true,
      draggable: true,
      progress: undefined,
    });
  }
}
function countdown(secs) {
  return eventChannel((emitter) => {
    const interval = setInterval(() => {
      secs -= 10;
      if (secs > 0) {
        emitter(secs);
      } else {
        // this causes the channel to close
        emitter(END);
      }
    }, 10000);
    // The subscriber must return an unsubscribe function
    return () => {
      clearInterval(interval);
    };
  });
}
// export function* checkStatusOfPaymentSaga() {
//   yield takeLatest(CHECK_STATUS_PAYMENT_REQUEST, checkPaymentStatus);
// }
// function* checkPaymentStatus({ payload }) {
//   const { merchantTranId, transactionType, amount } = payload;

//   try {
//     const { upi } = yield select(upiPaymentData);
//     const timer = 30 * 1000;
//     const intervalTimer = 5 * 1000;
//     const doStuff = async () => {
//       console.log("i am printing", payload);
//       const { data } = await api.get(`UPI/callbackStatusCheck.jsp`, {
//         params: {
//           merchantTranId:
//             transactionType === "Q" ? merchantTranId : upi.merchantTranId,
//           transactionType,
//         },
//       });
//       if (data.status === "FAIL") {
//         clearInterval(interval);
//         // yield put(closeModal({ modalProps: { open: false } }));
//         store.dispatch(closeModal({ modalProps: { open: false } }));
//       }
//       return data;
//     };
//     const data = yield call(doStuff);
//     let interval = setInterval(doStuff, intervalTimer);
//     setTimeout(() => {
//       console.log("expired");
//       clearInterval(interval);
//     }, timer);
//     console.log(data, "data");
//     if (data.status === "FAIL") {
//       yield clearInterval(interval);
//       yield put(closeModal({ modalProps: { open: false } }));
//     }
//     // const { data } = yield api.get(`UPI/callbackStatusCheck.jsp`, {
//     //   params: {
//     //     merchantTranId:
//     //       transactionType === "Q" ? merchantTranId : upi.merchantTranId,
//     //     transactionType,
//     //   },
//     // });
//     if (data.status !== "FAIL" && data.status !== "PENDING") {
//       yield put(checkStatusOfPaymentSuccess(data.status));
//       toast.success(`Payment of ${amount} is completed`, {
//         position: "top-center",
//         autoClose: 2000,
//         hideProgressBar: false,
//         closeOnClick: true,
//         pauseOnHover: true,
//         draggable: true,
//         progress: undefined,
//       });
//     } else if (data.status === "FAIL") {
//       yield put(checkStatusOfPaymentFailed(data.status));
//       toast.error(
//         `Unfortunately we have an issue with your payment, try again later`,
//         {
//           position: "top-center",
//           autoClose: 5000,
//           hideProgressBar: false,
//           closeOnClick: true,
//           pauseOnHover: true,
//           draggable: true,
//           progress: undefined,
//         }
//       );
//       yield put(closeModal({ modalProps: { open: false } }));
//     }
//   } catch (error) {
//     yield put(
//       checkStatusOfPaymentFailed(
//         typeof error !== "object" ? error : error.message
//       )
//     );
//     toast.error(`Something Went Wrong !!`, {
//       position: "top-center",
//       autoClose: 5000,
//       hideProgressBar: false,
//       closeOnClick: true,
//       pauseOnHover: true,
//       draggable: true,
//       progress: undefined,
//     });
//   }
// }

export function* checkStatusOfPaymentSaga() {
  yield takeLatest(CHECK_STATUS_PAYMENT_REQUEST, checkPaymentStatus);
}

function* checkPaymentStatus({ payload }) {
  const { merchantTranId, transactionType, amount } = payload;
  const chan = yield call(countdown, 300);
  const upiPayment = yield select(upiPaymentData);
  try {
    while (true) {
      // take(END) will cause the saga to terminate by jumping to the finally block
      let seconds = yield take(chan);
      console.log(`countdown: ${seconds}`);
      const { data } = yield api.get(`UPI/callbackStatusCheck.jsp`, {
        params: {
          merchantTranId:
            transactionType === "Q"
              ? merchantTranId
              : upiPayment.upi.merchantTranId,
          transactionType,
        },
      });
      console.log(data.status);
      const modalData1 = yield select(modalData);
      if (data.status === "SUCCESS") {
        yield delay(1000);
        yield put(checkStatusOfPaymentSuccess(data.status));
        yield put(closeModal({ modalProps: { open: false } }));
        toast.success(`Payment of ${amount} is completed`, {
          position: "top-center",
          autoClose: 2000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
        });
        chan.close();
      } else if (data.status === "FAIL") {
        yield put(checkStatusOfPaymentFailed(data.status));
        yield delay(1000);
        yield put(closeModal({ modalProps: { open: false } }));
        toast.error(
          `Unfortunately we have an issue with your payment, try again later`,
          {
            position: "top-center",
            autoClose: 5000,
            hideProgressBar: false,
            closeOnClick: true,
            pauseOnHover: true,
            draggable: true,
            progress: undefined,
          }
        );
        chan.close();
      }

      // modalData
      else if (
        modalData1.modalProps.payment === true &&
        modalData1.modalProps.close === true
      ) {
        chan.close();
      }
    }
  } finally {
    const upiPayment2 = yield select(upiPaymentData);
    const modalData1 = yield select(modalData);
    yield delay(1000);
    yield put(closeModal({ modalProps: { open: false } }));

    console.log(modalData1);
    if (modalData1.modalProps.close !== true) {
      if (
        upiPayment2.status !== "FAIL" ||
        upiPayment2.status !== "PENDING" ||
        upiPayment2.status !== "SUCCESS"
      ) {
        toast.error(
          `Unfortunately we have an issue with your payment, try again later`,
          {
            position: "top-center",
            autoClose: 5000,
            hideProgressBar: false,
            closeOnClick: true,
            pauseOnHover: true,
            draggable: true,
            progress: undefined,
          }
        );
      }
    }

    console.log("countdown terminated");
  }
}
