// import { applyMiddleware, createStore } from "redux";
// import createSagaMiddleware from "redux-saga";
// import { createWrapper } from "next-redux-wrapper";

// import rootReducer from "@/redux/reducers/rootReducer";
// import rootSaga from "@/redux/saga/rootSaga";

// const bindMiddleware = (middleware) => {
//   if (process.env.NODE_ENV !== "production") {
//     const { composeWithDevTools } = require("redux-devtools-extension");
//     return composeWithDevTools(applyMiddleware(...middleware));
//   }
//   return applyMiddleware(...middleware);
// };

// export const makeStore = (context) => {
//   const sagaMiddleware = createSagaMiddleware();
//   const store = createStore(rootReducer, bindMiddleware([sagaMiddleware]));
//   store.sagaTask = sagaMiddleware.run(rootSaga);
//   return store;
// };

// export const wrapper = createWrapper(makeStore, { debug: true });

import { createStore, applyMiddleware } from "redux";
import { HYDRATE, createWrapper } from "next-redux-wrapper";
import Router from "next/router";
// import thunkMiddleware from "redux-thunk";
import createSagaMiddleware from "redux-saga";
import rootSaga from "@/redux/saga/rootSaga";
import reducers from "./reducers/rootReducer";

const bindMiddlware = (middlware) => {
  if (process.env.NODE_ENV !== "production") {
    const { composeWithDevTools } = require("redux-devtools-extension");
    return composeWithDevTools(applyMiddleware(...middlware));
  }

  return applyMiddleware(...middlware);
};

const reducer = (state, action) => {
  if (action.type === HYDRATE) {
    const nextState = {
      ...state,
      ...action.payload,
    };
    // if (typeof window !== "undefined" && state?.router) {
    //   // preserve router value on client side navigation
    //   nextState.router = state.router;
    // }
    return nextState;
  } else {
    return reducers(state, action);
  }
};

export const initStore = (context) => {
  const sagaMiddleware = createSagaMiddleware();

  const store = createStore(reducer, bindMiddlware([sagaMiddleware]));
  store.sagaTask = sagaMiddleware.run(rootSaga);
  return store;
};
export const store = initStore();

export const wrapper = createWrapper(initStore);
