/* eslint-disable jsx-a11y/anchor-is-valid */

import CardComponentNoMedia from "@/components/CardComponentNoMedia/index";
import { getPassBook, getWalletBalance } from "@/redux/actions/passbook.action";

import Image from "next/image";
import { Grid, Typography } from "@material-ui/core";
import Cookies from "js-cookie";
import { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useStyles } from "./utils";

import GeneralBreadcrumbs from "@/components/GeneralBreadcrumbs";

import ArrowForwardIcon from "@material-ui/icons/ArrowForward";
import aboutCards from "@/config/aboutCards";
// import MyProfileForm from "./_Form";
const TypographyPromise = ({ text }) => {
  const classes = useStyles();
  return (
    <Typography variant="body1" className={classes.para2} component="p">
      <ArrowForwardIcon style={{ marginRight: 10, marginLeft: 0 }} />
      {text}
    </Typography>
  );
};
const AboutUsComponent = () => {
  const classes = useStyles();
  const dispatch = useDispatch();
  const { isAuthenticated, loading: loadProf } = useSelector(
    (state) => state.myProfile
  );
  const { loading: loadPass } = useSelector((state) => state.passbook);
  const reg_id = Cookies.get("regId");
  const mobile = Cookies.get("mobile");

  useEffect(() => {
    dispatch(getPassBook({ reg_id, mobile }));
  }, [dispatch, reg_id, mobile]);

  useEffect(() => {
    isAuthenticated &&
      dispatch(
        getWalletBalance({
          reg_id,
          mbl: mobile,
        })
      );
  }, [dispatch, reg_id, mobile, isAuthenticated]);

  return (
    <>
      <div className={classes.root}>
        <GeneralBreadcrumbs />

        <Typography
          variant="h6"
          style={{
            fontSize: 28,
            textTransform: "uppercase",
            marginBottom: 30,
          }}
        >
          About AaiPay
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={12} md={6}>
            <Typography variant="body1" className={classes.para} component="p">
              The AaiPay wallet can be used across a host of payments services,
              including bill recharges, utility bill payments, cab bookings,
              ticket bookings, payments for groceries, as well as payments to
              online digital and offline retail stores. AaiPay bridges the
              digital divide between consumers and companies via swift recharges
              and bill payments at no extra cost for its online transactions. Be
              it prepaid, postpaid, DTH, data card, electricity, life insurance,
              landlines, gas, water, broadband, cable, municipality or Metro
              payments and traffic challans, AaiPay is best for one and all. The
              app also offers instant money transfer to family and friends with
              ease.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              AaiPay is well known for its product innovation and cutting-edge
              technology. Earlier this year, it rolled out the first-of-its-kind
              instant credit product called {`'Boost'`} that ensures loan
              disbursal in a matter of 90 seconds. AaiPay is the first in the
              industry to give loans in a mobile wallet. It will be adding new
              products in its lending portfolio in the near future. With an
              extensive range of offerings in lending, AaiPay is on track to
              become one of {`India's`} largest lenders, in the times to come.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              We are on a mission to get millions of merchants both in organised
              and unorganised sector to be a part of the digital payments
              ecosystem. Our Chat-n-Pay service is all about social payments. It
              is an engaging and secure way for you to seamlessly Chat-n-Pay to
              friends, family, and merchants in less than 5 seconds. It also
              enables merchants, small or large to accept digital payments in
              less than 1 minute after registering on the Aaipay App.
            </Typography>
          </Grid>
          <Grid item xs={12} md={6}>
            <div className={classes.imageContainer}>
              <Image
                src="/assets/images/about-page.svg"
                alt="About aaipay"
                width={400}
                height={400}
              />
            </div>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 18,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              We Promise
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <TypographyPromise text="An easy and instant recharging process" />
            <TypographyPromise text="Hassle-free online experience" />
            <TypographyPromise text="Safe and secure payment process" />
            <TypographyPromise text="Best discounts available in the market" />
            <TypographyPromise
              text="Simple voucher redemption with no hidden costs or complex terms
              and conditions"
            />
            <TypographyPromise
              text="And a totally satisfied you, {`who'll`} want to come back to us
              again and again"
            />
            <TypographyPromise text=" After all, you know {`it's`} a smart thing to do!" />
          </Grid>

          <Grid container spacing={2}>
            {aboutCards.map((about) => {
              return (
                <Grid item xs={12} sm={6} md={3} key={about.id}>
                  <CardComponentNoMedia
                    title={about.title}
                    icon={about.icon}
                    description={about.description}
                    btnText={about.btnText}
                  />
                </Grid>
              );
            })}
          </Grid>
        </Grid>
      </div>
    </>
  );
};

export default AboutUsComponent;
