import { useEffect, useState } from "react";
import { Formik, Form, Field, useFormikContext, ErrorMessage } from "formik";
import { initialValues, validate } from "./utils";
import Controls from "@/components/Controls/Controls";
import {
  FormControl,
  FormControlLabel,
  FormLabel,
  Grid,
  MenuItem,
  Radio,
  RadioGroup,
  TextField,
  Typography,
} from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import {
  getAllBillers,
  getAllEducationBillers,
  getAllInputFields,
  getFetchedBill,
} from "@/redux/actions/bbps.actions";
import Image from "next/image";
import Skeleton from "@material-ui/lab/Skeleton";
import { checkNumeric } from "utils/customFunctions";
import { useRouter } from "next/router";

import { RESET_BILLERS } from "@/redux/constants/bbps.constants";
import {
  getAllStates,
  getCityByStateCode,
} from "@/redux/actions/state.city.actions";
const LoadOperators = ({ serviceId }) => {
  const dispatch = useDispatch();
  const { states } = useSelector((state) => state.states);
  const { values } = useFormikContext();

  useEffect(() => {
    if (values.billerId) {
      dispatch(getAllInputFields(values.billerId));
    }
  }, [values.billerId, dispatch]);

  useEffect(() => {
    if (values?.blrStateCode) {
      dispatch(getCityByStateCode(values?.blrStateCode));
    }
  }, [values?.blrStateCode, dispatch]);

  useEffect(() => {
    if (values?.blrCity) {
      dispatch(getAllEducationBillers(values?.blrCity, serviceId));
    }
  }, [values?.blrCity, serviceId, dispatch]);

  useEffect(() => {
    if (serviceId) {
      if (serviceId === "771124" || serviceId === 771124) {
        dispatch({ type: RESET_BILLERS });
        dispatch(getAllStates());
      } else {
        dispatch(getAllBillers(serviceId));
      }
    }
  }, [dispatch, serviceId]);

  // useEffect(() => {
  //   if (id && name) {
  //     dispatch(getAllBillers(id));
  //   }
  // }, [id, dispatch, name]);
  return null;
};

const BBPSRechargeForm = ({ serviceId, serviceTypeName }) => {
  const dispatch = useDispatch();
  const { states, loading: loadState } = useSelector((state) => state.states);
  const { cities, loading: loadCity } = useSelector((state) => state.cities);
  const router = useRouter();
  // const {} = router.query;
  const pathname = router.pathname.replace("/", "");
  const { loading, billers } = useSelector((state) => state.billers);
  const { loadingButton } = useSelector((state) => state.billFetch);
  const {
    error: errField,
    fields,
    billerInfo,
  } = useSelector((state) => state.fields);

  const validateFields = (value, field) => {
    const regex = new RegExp(field.validationRegex);
    let errors;

    if (field.paramName) {
      if (field.optional === "0") {
        if (!value) {
          errors = ` ${field.paramName} is Required`;
        } else if (!regex.test(value)) {
          errors = `Invalid ${field.paramName}`;
        }
        return errors;
      }
    }

    return errors;
  };
  // const validateMobile = (value, field) => {
  //   let errors;
  //   if (field === "customer_mobile_no") {
  //     if (!value) {
  //       errors = "";
  //     }
  //     return errors;
  //   }
  //   return errors;
  // };
  const validateAmount = (value, field) => {
    let errors;
    if (field === "amount") {
      if (!value || value === "") {
        errors = "Recharge amount is required.";
      } else if (!checkNumeric(value)) {
        errors = "Only Numeric values are allowed.";
      }
      return errors;
    }
    return errors;
  };
  const renderDynamicFields = (
    values,
    setFieldValue,
    handleBlur,
    errors,
    touched,
    handleChange
  ) => {
    if (serviceId !== "771124") {
      if (fields.some((field) => field.optional === "1")) {
        return (
          <Grid item xs={12}>
            <TextField
              fullWidth
              className=""
              variant="standard"
              name="preferredMethod"
              id="Select"
              select
              label="Select Preferred Method"
              value={values.preferredMethod}
              onChange={handleChange}
              error={touched.preferredMethod && Boolean(errors.preferredMethod)}
              helperText={touched.preferredMethod && errors.preferredMethod}
            >
              {fields.map((option) => (
                <MenuItem key={option.paramName} value={option.paramName}>
                  {option.paramName}
                </MenuItem>
              ))}
            </TextField>
            {fields
              .filter((fieldOuter) => {
                return fieldOuter.paramName === values.preferredMethod;
              })
              .map((field) => {
                return (
                  <Field
                    key={field.paramName}
                    validate={(val) => validateFields(val, field)}
                    component={Controls.Input}
                    fullWidth
                    id={field.paramName}
                    name={field.paramName}
                    label={field.paramName}
                    value={values[field.paramName] || ""}
                    onChange={(e) =>
                      setFieldValue(field.paramName, e.target.value)
                    }
                    error={
                      touched[field.paramName] &&
                      Boolean(errors[field.paramName])
                    }
                    onBlur={handleBlur}
                    helperText={
                      touched[field.paramName] && errors[field.paramName]
                    }
                    variant="standard"
                    margin="normal"
                    required={field.optional === "0" ? true : false}
                    minLength={field.minLength}
                    maxLength={field.maxLength}
                    type={
                      field.dataType === "ALPHANUMERIC"
                        ? "text"
                        : field.dataType === "NUMERIC"
                        ? "number"
                        : "text"
                    }
                  />
                );
              })}
          </Grid>
        );
      } else {
        return fields.map((field, index) => (
          <Grid item xs={12} key={index}>
            <Field
              validate={(val) => validateFields(val, field)}
              component={Controls.Input}
              fullWidth
              id={field.paramName}
              name={field.paramName}
              label={field.paramName}
              value={values[field.paramName] || ""}
              onChange={(e) => setFieldValue(field.paramName, e.target.value)}
              error={
                touched[field.paramName] && Boolean(errors[field.paramName])
              }
              onBlur={handleBlur}
              helperText={touched[field.paramName] && errors[field.paramName]}
              variant="standard"
              margin="normal"
              required={field.optional === "0" ? true : false}
              minLength={field.minLength}
              maxLength={field.maxLength}
              type={
                field.dataType === "ALPHANUMERIC"
                  ? "text"
                  : field.dataType === "NUMERIC"
                  ? "number"
                  : "text"
              }
            />
          </Grid>
        ));
      }
    } else {
      return fields.map((field, index) => (
        <Grid item xs={12} key={index}>
          <Field
            validate={(val) => validateFields(val, field)}
            component={Controls.Input}
            fullWidth
            id={field.paramName}
            name={field.paramName}
            label={field.paramName}
            value={values[field.paramName] || ""}
            onChange={(e) => setFieldValue(field.paramName, e.target.value)}
            error={touched[field.paramName] && Boolean(errors[field.paramName])}
            onBlur={handleBlur}
            helperText={touched[field.paramName] && errors[field.paramName]}
            variant="standard"
            margin="normal"
            required={field.optional === "0" ? true : false}
            minLength={field.minLength}
            maxLength={field.maxLength}
            type={
              field.dataType === "ALPHANUMERIC"
                ? "text"
                : field.dataType === "NUMERIC"
                ? "number"
                : "text"
            }
          />
        </Grid>
      ));
    }
  };
  return (
    <div>
      <Formik
        validateOnChange={false}
        initialValues={initialValues}
        enableReinitialize
        // validator={validate}
        onSubmit={(values, actions) => {
          const { biller_options, state_options, city_options, ...rest } =
            values;
          const submitted_values = { ...rest };
          if (billerInfo.billFetchRequired === "MANDATORY") {
            console.log(submitted_values);
            dispatch(
              getFetchedBill({
                ...submitted_values,
                billFetch: true,
                billerInfo,
              })
            );
          } else {
            dispatch(getFetchedBill({ ...submitted_values, billFetch: false }));
          }
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          touched,
          errors,
          resetForm,
          handleBlur,
          handleChange,
        }) => {
          return (
            <>
              <Grid container>
                {loading ? (
                  <Grid item xs={12} className="skeleton__wrapper">
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                  </Grid>
                ) : (
                  <>
                    <Grid
                      item
                      xs={8}
                      md={8}
                      style={{ display: "flex", justifyContent: "flex-start" }}
                    >
                      <Typography
                        component="div"
                        variant="subtitle2"
                        style={{ marginBottom: 10 }}
                      >{`${serviceTypeName} Bill Payment`}</Typography>
                    </Grid>
                    {pathname !== "dth" && (
                      <Grid
                        item
                        xs={4}
                        md={4}
                        style={{
                          display: "flex",
                          justifyContent: "flex-end",
                          alignItems: "center",
                        }}
                      >
                        <Image
                          src="/assets/images/Bharat-BillPay-Final-Logo.jpg"
                          alt="Bharat BillPay"
                          width="65"
                          height="22"
                        />
                      </Grid>
                    )}

                    <Form
                      onSubmit={handleSubmit}
                      style={{ display: "contents" }}
                    >
                      <Grid container spacing={2}>
                        {!loading && serviceId !== "771124" && (
                          <>
                            <Grid item xs={12}>
                              <Field
                                component={Controls.MuiAutoComplete}
                                id="billerName"
                                name="billerName"
                                label="Operator"
                                getOptionLabel={(option) =>
                                  option.billerName !== undefined
                                    ? option.billerName
                                    : ""
                                }
                                getOptionSelected={(option, values) =>
                                  option.billerName === values.billerName
                                }
                                className="scrollbar"
                                value={values.biller_options || null}
                                onChange={(e, value) => {
                                  if (value !== null) {
                                    resetForm();
                                    setFieldValue("biller_options", value);
                                    setFieldValue("billerId", value?.billerId);
                                    setFieldValue(
                                      "billerName",
                                      value?.billerName
                                    );
                                  }
                                }}
                                options={billers}
                                fullWidth={true}
                              />
                            </Grid>
                          </>
                        )}
                        {!loadState && serviceId === "771124" && (
                          <>
                            <Grid item xs={12}>
                              <Field
                                component={Controls.MuiAutoComplete}
                                id="blrStateName"
                                name="blrStateName"
                                label="State"
                                getOptionLabel={(option) =>
                                  option.blrStateName !== undefined
                                    ? option.blrStateName
                                    : ""
                                }
                                getOptionSelected={(option, values) =>
                                  option.blrStateName === values.blrStateName
                                }
                                className="scrollbar"
                                value={values.state_options || null}
                                onChange={(e, value) => {
                                  if (value !== null) {
                                    resetForm();
                                    setFieldValue("state_options", value);
                                    setFieldValue(
                                      "blrStateName",
                                      value?.blrStateName
                                    );
                                    setFieldValue(
                                      "blrStateCode",
                                      value?.blrStateCode
                                    );
                                  }
                                }}
                                options={states}
                                fullWidth={true}
                              />
                            </Grid>
                          </>
                        )}
                        {values.blrStateName !== "" &&
                          !loadCity &&
                          serviceId === "771124" && (
                            <>
                              <Grid item xs={12}>
                                <Field
                                  component={Controls.MuiAutoComplete}
                                  id="blrCity"
                                  name="blrCity"
                                  label="City"
                                  getOptionLabel={(option) =>
                                    option.blrCity !== undefined &&
                                    option.blrCity !== ""
                                      ? option.blrCity
                                      : ""
                                  }
                                  getOptionSelected={(option, values) =>
                                    option.blrCity === values.blrCity
                                  }
                                  className="scrollbar"
                                  value={values.city_options || null}
                                  onChange={(e, value) => {
                                    if (value !== null) {
                                      // resetForm();
                                      setFieldValue("city_options", value);
                                      setFieldValue("blrCity", value?.blrCity);
                                    }
                                  }}
                                  options={cities}
                                  fullWidth={true}
                                />
                              </Grid>
                            </>
                          )}
                        {!loading && serviceId === "771124" && values?.blrCity && (
                          <>
                            <Grid item xs={12}>
                              <Field
                                component={Controls.MuiAutoComplete}
                                id="billerName"
                                name="billerName"
                                label="Select Your Institute"
                                getOptionLabel={(option) =>
                                  option.billerName !== undefined
                                    ? option.billerName
                                    : ""
                                }
                                getOptionSelected={(option, values) =>
                                  option.billerName === values.billerName
                                }
                                className="scrollbar"
                                value={values.biller_options || null}
                                onChange={(e, value) => {
                                  if (value !== null) {
                                    // resetForm();
                                    setFieldValue("biller_options", value);
                                    setFieldValue("billerId", value?.billerId);
                                    setFieldValue(
                                      "billerName",
                                      value?.billerName
                                    );
                                  }
                                }}
                                options={billers}
                                fullWidth={true}
                              />
                            </Grid>
                          </>
                        )}
                        {errField && (
                          <Grid
                            item
                            xs={12}
                            style={{
                              paddingTop: 0,
                              paddingBottom: 0,
                              color: "red",
                              marginTop: -8,
                              fontSize: 13,
                            }}
                          >
                            Something Went wrong
                          </Grid>
                        )}
                        {fields.length > 0 && (
                          <>
                            {renderDynamicFields(
                              values,
                              setFieldValue,
                              handleBlur,
                              errors,
                              touched,
                              handleChange
                            )}
                          </>
                        )}
                        {billerInfo.billFetchRequired === "NOT_SUPPORTED" &&
                        !billerInfo.billFetchRequired === "MANDATORY" ? (
                          <Grid item xs={12} md={12}>
                            <Field
                              component={Controls.Input}
                              fullWidth
                              // required={true}
                              validate={(val) => validateAmount(val, "amount")}
                              type="number"
                              maxLength="5"
                              id="amount"
                              name="amount"
                              label="Amount"
                              value={values.amount ?? ""}
                              onChange={(e) =>
                                setFieldValue("amount", e.target.value)
                              }
                              error={touched.amount && Boolean(errors.amount)}
                              helperText={touched.amount && errors.amount}
                              variant="standard"
                              margin="normal"
                            />
                          </Grid>
                        ) : null}

                        <Controls.Button
                          color="primary"
                          variant="contained"
                          fullWidthButton={true}
                          loadingButton={loadingButton}
                          loadingIndicator={true}
                          type="submit"
                          disabled={values.billerName ? false : true}
                          text={
                            billerInfo.billFetchRequired === "MANDATORY"
                              ? "Fetch Bill"
                              : "Proceed to Pay"
                          }
                          style={{ fontSize: 16 }}
                        />
                      </Grid>
                    </Form>
                  </>
                )}
              </Grid>

              <LoadOperators
                serviceId={serviceId}
                serviceTypeName={serviceTypeName}
                errField={errField}
              />
            </>
          );
        }}
      </Formik>
    </div>
  );
};

export default BBPSRechargeForm;
