import { useWindowSize } from "@/hooks/useWindowSize";
import {
  Grid,
  makeStyles,
  Table,
  TableBody,
  TableCell,
  TableRow,
  Typography,
} from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import _ from "lodash";
import Image from "next/image";
import Controls from "../../components/Controls/Controls";
import { closeModal, openModal } from "@/redux/actions/modal.actions";
import ModalExample from "../../components/Layout/Modal/ModalExample";
import BillPaidComponent from "../BillPaidComponent";
import TableRowComponent from "../../components/TableRowComponent";
import { useRouter } from "next/router";
import Cookies from "js-cookie";
import { capitalize, str_obj } from "utils/customFunctions";
import { useEffect, useState } from "react";
import Moment from "react-moment";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 16}px` : "100%",

    // height: "calc(100vh - 10px)",

    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    // overflowY: "scroll",
  },
  table: {
    padding: theme.spacing(2),
    margin: theme.spacing(2, 0, 0, 0),
  },
}));

const BillFetchComponent = ({ operator, billerInfo }) => {
  const dispatch = useDispatch();
  const router = useRouter();
  const { bill_details, loading } = useSelector((state) => state.billFetch);
  const {
    userInfo: { Name, Email },
  } = useSelector((state) => state.myProfile);
  const { fields } = useSelector((state) => state.fields);
  const [fieldBackup, setFieldBackup] = useState(fields);
  const [billDetailsBackup, setBillDetailsBackup] = useState(bill_details);
  const {
    customerName,
    cust_mbl,
    billDate,
    dueDate,
    billPeriod,
    totalAmount,
    billAmount,
    billNumber,
  } = bill_details;
  const windowWidth = useWindowSize();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
  });

  const operator_type = capitalize(router.pathname.replace("/", ""));
  const handleContinue = () => {
    Cookies.set(
      "plan",
      JSON.stringify({
        billerInfo,
        bbps: true,
        fields,
        bill_details,
        operator_type,
      })
    );

    router.push("/payment-details");
  };

  return (
    <div className={classes.root}>
      <Grid container>
        <Grid
          item
          xs={8}
          md={8}
          style={{ display: "flex", justifyContent: "flex-start" }}
        >
          <Typography variant="h6">BILL INFORMATION</Typography>
        </Grid>
        <Grid
          item
          xs={4}
          md={4}
          style={{
            display: "flex",
            justifyContent: "flex-end",
            alignItems: "center",
          }}
        >
          <Image
            src="/assets/images/Bharat-BillPay-Final-Logo.jpg"
            alt="Bharat BillPay"
            width="65"
            height="24"
          />
        </Grid>
      </Grid>

      {!_.isEmpty(bill_details) ? (
        <>
          <Table className={classes.table} size="small">
            <TableBody>
              <TableRowComponent heading="Operator" detail={operator} />
              {fieldBackup?.map((field, index) => {
                return billDetailsBackup[`${field.paramName}`] ? (
                  <TableRowComponent
                    heading={field.paramName}
                    detail={billDetailsBackup[`${field.paramName}`]}
                    key={index}
                  />
                ) : null;
              })}
              <TableRowComponent
                heading="Customer Name"
                detail={customerName}
              />

              {/* <TableRowComponent heading="Payment Mode" detail="Cash" /> */}
              {billNumber && (
                <TableRowComponent heading="Bill Number" detail={billNumber} />
              )}
              {billDate && (
                <TableRowComponent
                  heading="Bill Date"
                  detail={<Moment format="DD MMM YYYY">{billDate}</Moment>}
                />
              )}
              {dueDate && (
                <TableRowComponent
                  heading="Due Date"
                  detail={<Moment format="DD MMM YYYY">{dueDate}</Moment>}
                />
              )}

              <TableRowComponent
                heading="Bill Amount"
                detail={`₹ ${parseFloat(billAmount / 100).toFixed(2)}`}
              />

              <TableRowComponent
                heading="Total Amount"
                detail={`₹ ${parseFloat(totalAmount / 100).toFixed(2)}`}
              />
            </TableBody>
          </Table>
          <span
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              width: "100%",
              marginTop: 24,
            }}
          >
            <Controls.Button
              type="button"
              text="Cancel"
              onClick={() =>
                dispatch(closeModal({ modalProps: { open: false } }))
              }
            />
            <Controls.Button
              text="Continue"
              type="button"
              onClick={handleContinue}
            />
          </span>
        </>
      ) : null}
    </div>
  );
};

export default BillFetchComponent;
