import { useWindowSize } from "@/hooks/useWindowSize";
import {
  colors,
  Grid,
  makeStyles,
  Table,
  TableBody,
  TableCell,
  TableRow,
  Typography,
} from "@material-ui/core";
import Script from "next/script";
import { useDispatch, useSelector } from "react-redux";
import _ from "lodash";
import Image from "next/image";
import Controls from "@/components/Controls/Controls";
import Lottie from "react-lottie-player";
import { closeModal, openModal } from "@/redux/actions/modal.actions";
import ModalExample from "@/components/Layout/Modal/ModalExample";
import TableRowComponent from "@/components/TableRowComponent";
import { lotteJson } from "@/config/lotteJson";
import { useRouter } from "next/router";
import Moment from "react-moment";
import { capitalize } from "utils/customFunctions";
import { GetApp as GetAppIcon, Redo as RedoIcon } from "@material-ui/icons";
import axios from "axios";
import api from "@/redux/config/api.main";
import { toast } from "react-toastify";
import fileDownload from "js-file-download";

const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 16}px` : "100%",

    // height: "calc(100vh - 10px)",

    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    // overflowY: "scroll",
  },
  table: {
    padding: theme.spacing(2),
    margin: theme.spacing(2, 0, 0, 0),
  },
  buttonGrid: {
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    width: "100%",
    marginTop: 24,
    flexDirection: (props) =>
      props && props.windowWidth > 768 ? "row" : "column",
  },
  dFlexCenter: {
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
  },
  dFlexStart: { display: "flex", justifyContent: "flex-start" },
  dFlexEnd: {
    display: "flex",
    justifyContent: "flex-end",
    alignItems: "center",
  },
}));
// const downloadSlip = async (txnRefId) => {
//   try {
//     const response = await api({
//       url: `BillPay/receipt.jsp?txnRefId=CC012017BAAA07654297`,
//       method: "GET",
//       responseType: "blob",
//     });
//     const url = window.URL.createObjectURL(new Blob([response.data]));
//     const link = document.createElement("a");
//     link.href = url;
//     link.setAttribute("download", "receipt.pdf");
//     document.body.appendChild(link);
//     console.log(response);
//     link.click();
//     document.body.removeChild(link);
//   } catch (error) {
//     toast.error(`File cannot be downloaded, Something went wrong !!`, {
//       position: "top-center",
//       autoClose: 5000,
//       hideProgressBar: false,
//       closeOnClick: true,
//       pauseOnHover: true,
//       draggable: true,
//       progress: undefined,
//     });
//   }
// };
const downloadSlip = async (txnRefId) => {
  try {
    api({
      url: `BillPay/receipt.jsp?txnRefId=${txnRefId}`,
      method: "GET",
      responseType: "blob", // Important
    }).then((response) => {
      fileDownload(response.data, "receipt.pdf");
    });
  } catch (error) {
    toast.error(`File cannot be downloaded, Something went wrong !!`, {
      position: "top-center",
      autoClose: 5000,
      hideProgressBar: false,
      closeOnClick: true,
      pauseOnHover: true,
      draggable: true,
      progress: undefined,
    });
  }
};
const BillPaidComponent = () => {
  const dispatch = useDispatch();
  const { bill_paid_details } = useSelector((state) => state.billPay);

  // const {
  //   responseCode,
  //   responseReason,
  //   txnRefId,
  //   approvalRefNumber,
  //   txnRespType,
  //   inputParams,
  //   CustConvFee,
  //   RespAmount,
  //   RespBillDate,
  //   RespBillNumber,
  //   RespBillPeriod,
  //   RespCustomerName,
  //   RespDueDate,
  // } = bill_paid_details;
  const {
    transactionStatus,
    dueDate,
    approvalRefNumber,
    transactionRefId,
    billDate,
    responseStatus,
    billNumber,
    customerName,
    billPeriod,
    billAmount,
    convCharge,
  } = bill_paid_details;
  const { width: windowWidth } = useWindowSize();

  const classes = useStyles({
    windowWidth: windowWidth,
  });
  const router = useRouter();

  return (
    <>
      <Script src="https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js" />
      <div className={classes.root}>
        <Grid container>
          <Grid item xs={8} md={8} className={classes.dFlexStart}>
            <Typography variant="h6">
              <Image
                src="/assets/images/logos/logo.png"
                alt="Aaipay"
                width="174"
                height="45"
              />
            </Typography>
          </Grid>
          <Grid item xs={4} md={4} className={classes.dFlexEnd}>
            <Image
              src="/assets/images/Be Assured.png"
              alt="Bharat BillPay"
              width="60"
              height="60"
            />
          </Grid>
          <Grid item xs={12} className={classes.dFlexCenter}>
            <Lottie
              loop={false}
              background="transparent"
              animationData={lotteJson}
              play
              speed={0.8}
              style={{ width: 100, height: 100 }}
            />
          </Grid>
          <Grid item xs={12} className={classes.dFlexCenter}>
            <Typography
              variant="subtitle2"
              style={{
                color: colors.green[500],
                fontSize: "1.2rem",
                textAlign: "center",
              }}
            >
              {`Congratulations your bill of ₹ ${
                billAmount * 0.01
              } has been paid successfully`}
            </Typography>
          </Grid>
        </Grid>

        {!_.isEmpty(bill_paid_details) ? (
          <>
            <Grid container spacing={2}>
              <Grid item xs={12} md={12}>
                <Table className={classes.table} size="small">
                  <TableBody>
                    <TableRowComponent
                      heading="Transaction Status"
                      detail={transactionStatus}
                    />
                    <TableRowComponent
                      heading="Transaction Date"
                      detail={<Moment format="DD MMM YYYY">{billDate}</Moment>}
                    />
                    <TableRowComponent
                      heading="Transaction Reference Id"
                      detail={transactionRefId}
                    />

                    <TableRowComponent
                      heading="Approval Ref Number"
                      detail={approvalRefNumber}
                    />
                    <TableRowComponent
                      heading="Bill Number"
                      detail={billNumber}
                    />
                    <TableRowComponent
                      heading="Bill Period"
                      detail={billPeriod}
                    />
                    <TableRowComponent
                      heading="Due Date"
                      detail={<Moment format="DD MMM YYYY">{dueDate}</Moment>}
                    />
                    <TableRowComponent
                      heading="Customer Name"
                      detail={capitalize(customerName)}
                    />

                    <TableRowComponent
                      heading="Customer Conv. Fee Fee"
                      detail={`₹ ${convCharge * 0.01}`}
                    />

                    <TableRowComponent
                      heading="Total Paid Amount"
                      detail={`₹ ${billAmount * 0.01}`}
                    />
                  </TableBody>
                </Table>
              </Grid>
            </Grid>

            <span className={classes.buttonGrid}>
              <Controls.Button
                text="Do another"
                type="button"
                startIcon={<RedoIcon />}
                onClick={() => {
                  dispatch(closeModal({ modalProps: { open: false } }));
                  router.push("/mobile");
                }}
              />
              <Controls.Button
                type="button"
                text="Download Receipt"
                style={{ backgroundColor: colors.green[500] }}
                startIcon={<GetAppIcon />}
                onClick={() => downloadSlip(transactionRefId)}
              />
              {/* <a href="https://aaipay.in:10002/api/apps/v1/BillPay/receipt.jsp?txnRefId=CC012017BAAA07654297">
                Download Receipt
              </a> */}
            </span>
          </>
        ) : null}
      </div>
    </>
  );
};

export default BillPaidComponent;
