import { useWindowSize } from "@/hooks/useWindowSize";
import {
  colors,
  CssBaseline,
  Grid,
  makeStyles,
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableRow,
  Typography,
} from "@material-ui/core";
import Script from "next/script";
import { useDispatch, useSelector } from "react-redux";
import _ from "lodash";
import Image from "next/image";
import Controls from "@/components/Controls/Controls";
import Lottie from "react-lottie-player";
import { closeModal, openModal } from "@/redux/actions/modal.actions";
import ModalExample from "@/components/Layout/Modal/ModalExample";
import TableRowComponent from "@/components/TableRowComponent";
import { lotteJson } from "@/config/lotteJson";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 96}px` : "100%",

    // height: "calc(100vh - 10px)",

    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    // overflowY: "scroll",
  },
  table: {
    padding: theme.spacing(2),
    margin: theme.spacing(2, 0, 0, 0),
  },
}));

const ComplaintStatus = () => {
  const { complaint_status, loading } = useSelector(
    (state) => state.complaintStatus
  );

  const windowWidth = useWindowSize();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
  });

  return (
    <>
      <Script src="https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js" />
      <div className={classes.root}>
        <Grid container>
          {/* <Grid
            item
            xs={8}
            md={8}
            style={{ display: "flex", justifyContent: "flex-start" }}
          >
            <Typography variant="h6">
              <Image
                src="/assets/images/logos/logo.png"
                alt="Aaipay"
                width="174"
                height="45"
              />
            </Typography>
          </Grid> */}
          {/* <Grid
            item
            xs={4}
            md={4}
            style={{
              display: "flex",
              justifyContent: "flex-end",
              alignItems: "center",
            }}
          >
            <Image
              src="/assets/images/Be Assured.png"
              alt="Bharat BillPay"
              width="45"
              height="45"
            />
          </Grid> */}
          {/* <Grid
            item
            xs={12}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Lottie
              loop={false}
              background="transparent"
              animationData={lotteJson}
              play
              speed={0.8}
              style={{ width: 60, height: 60 }}
            />
          </Grid> */}
          <Grid
            item
            xs={12}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Typography variant="subtitle2" style={{ fontSize: 18 }}>
              {/* {complaint.responseCode === "000"
                ? "Congratulations! Complaint Successfully Registered"
                : "Something went wrong"} */}
              COMPLAINT STATUS
            </Typography>
          </Grid>
        </Grid>

        {complaint_status instanceof Array ? (
          <>
            <Grid container spacing={2}>
              <Grid item xs={12}>
                <Table className={classes.table} size="small">
                  <TableHead>
                    <TableRow>
                      <TableCell>Complaint ID</TableCell>
                      <TableCell>Complaint Assigned</TableCell>
                      <TableCell>Complaint Status</TableCell>
                    </TableRow>
                  </TableHead>
                  <TableBody>
                    {complaint_status.map((cs, i) => {
                      return (
                        <TableRow key={i}>
                          <TableCell>{cs.complaintId}</TableCell>
                          <TableCell>
                            {cs.complaintAssigned || "CC AVENUE"}
                          </TableCell>
                          <TableCell>{cs.complaintStatus}</TableCell>
                        </TableRow>
                      );
                    })}
                    {complaint_status.length === 0 && (
                      <TableRow>
                        <TableCell colSpan={3} style={{ textAlign: "center" }}>
                          No Record found with this Complaint ID
                        </TableCell>
                      </TableRow>
                    )}
                  </TableBody>
                </Table>
              </Grid>
            </Grid>
          </>
        ) : (
          <>
            {_.isEmpty(complaint_status) ? (
              <Grid container spacing={2}>
                <Grid item xs={12}>
                  <Table className={classes.table} size="small">
                    <TableBody>
                      <TableRow>
                        <TableCell colSpan={3} style={{ textAlign: "center" }}>
                          No Record found with this Complaint ID
                        </TableCell>
                      </TableRow>
                    </TableBody>
                  </Table>
                </Grid>
              </Grid>
            ) : (
              <Grid container spacing={2}>
                <Grid item xs={12}>
                  <Table className={classes.table} size="small">
                    <TableBody>
                      <TableRowComponent
                        heading="Complaint ID"
                        detail={complaint_status.complaintId}
                      />
                      <TableRowComponent
                        heading="Complaint Assigned"
                        detail={
                          complaint_status.complaintAssigned || "CC AVENUE"
                        }
                      />
                      <TableRowComponent
                        heading="Complaint Status"
                        detail={complaint_status.complaintStatus}
                      />
                    </TableBody>
                  </Table>
                </Grid>
              </Grid>
            )}
          </>
        )}
      </div>
    </>
  );
};

export default ComplaintStatus;
