// import PropTypes from 'prop-types';
import { Formik, Form, Field, useFormikContext } from "formik";
import { initialValues, validate, complaintDispoOptions } from "./utils";
import Controls from "@/components/Controls/Controls";
import { Grid } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";

import { useRouter } from "next/router";
import AlertMessage from "@/components/AlertMessage";
import { sendComplaint } from "@/redux/actions/complaints.action";
const LoadOperators = () => {
  const dispatch = useDispatch();
  const router = useRouter();

  const { values, setFieldValue } = useFormikContext();

  return null;
};

const ComplaintRegForm = ({ loadingButton }) => {
  const { alertOpen } = useSelector((state) => state.alert);
  const dispatch = useDispatch();

  return (
    <div>
      <Formik
        initialValues={initialValues}
        validate={validate}
        onSubmit={(values) => {
          const { complaintDispoOptions, ...submission_values } = values;
          dispatch(sendComplaint(submission_values));
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          handleChange,
          touched,
          errors,
          setErrors,
          resetForm,
        }) => {
          return (
            <div>
              {alertOpen === true ? <AlertMessage /> : null}
              <Form onSubmit={handleSubmit}>
                <Grid container spacing={2}>
                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.RadioGroup}
                      row={true}
                      label="Complaint Type"
                      id="complaintType"
                      name="complaintType"
                      value={values.complaintType || "Transaction"}
                      onChange={(event) => {
                        resetForm();
                        setFieldValue(
                          "complaintType",
                          event.currentTarget.value
                        );
                      }}
                      items={[
                        { id: "Transaction", title: "Transaction" },
                        { id: "Service", title: "Service" },
                      ]}
                    />
                  </Grid>
                  {values.complaintType !== "Transaction" && (
                    <Grid item xs={12} md={6}>
                      <Field
                        component={Controls.Input}
                        fullWidth
                        id="serveReason"
                        name="serveReason"
                        label="Service Reason"
                        value={values.serveReason}
                        onChange={handleChange}
                        error={
                          touched.serveReason && Boolean(errors.serveReason)
                        }
                        helperText={touched.serveReason && errors.serveReason}
                        variant="standard"
                        margin="normal"
                        placeholder={"Please Enter your Service Reason"}
                      />
                    </Grid>
                  )}

                  <Grid item xs={12} md={6}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="mobileNo"
                      name="mobileNo"
                      label="Primary Mobile Number"
                      value={values.mobileNo}
                      onChange={handleChange}
                      error={touched.mobileNo && Boolean(errors.mobileNo)}
                      helperText={touched.mobileNo && errors.mobileNo}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your Primary Mobile Number"}
                    />
                  </Grid>
                  {values.complaintType === "Transaction" && (
                    <>
                      <Grid item xs={12} md={6}>
                        <Field
                          component={Controls.Input}
                          fullWidth
                          id="txId"
                          name="txId"
                          label="Transaction Ref ID"
                          value={values.txId}
                          onChange={handleChange}
                          error={touched.txId && Boolean(errors.txId)}
                          helperText={touched.txId && errors.txId}
                          variant="standard"
                          margin="normal"
                          placeholder={
                            "Please Enter your Primary Mobile Number"
                          }
                        />
                      </Grid>
                      <Grid item xs={12} md={12}>
                        <Field
                          margin="normal"
                          component={Controls.MuiAutoComplete}
                          id="complaintDispo"
                          name="complaintDispo"
                          label="Complaint Disposition"
                          getOptionLabel={(option) =>
                            option.title !== undefined ? option.title : ""
                          }
                          getOptionSelected={(option, values) =>
                            option.title === values.title
                          }
                          error={
                            touched.complaintDispo &&
                            Boolean(errors.complaintDispo)
                          }
                          helperText={
                            touched.complaintDispo && errors.complaintDispo
                          }
                          value={values.complaintDispoOptions || null}
                          onChange={(e, value) => {
                            if (value !== null) {
                              setFieldValue("complaintDispoOptions", value);
                              setFieldValue("complaintDispo", value?.id);
                            }
                          }}
                          options={complaintDispoOptions}
                          style={{ position: "relative", top: -3 }}
                          fullWidth={true}
                        />
                      </Grid>
                    </>
                  )}

                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.Input}
                      multiline={true}
                      label="Complaint Details"
                      id="complaintDetails"
                      name="complaintDetails"
                      value={values.complaintDetails}
                      onChange={handleChange}
                      fullWidth
                      placeholder={"Please Enter Complaint Details"}
                      margin="normal"
                      error={
                        touched.complaintDetails &&
                        Boolean(errors.complaintDetails)
                      }
                      helperText={
                        touched.complaintDetails && errors.complaintDetails
                      }
                    />
                  </Grid>

                  <div
                    style={{
                      width: "100%",
                      display: "flex",
                      justifyContent: "flex-end",
                    }}
                  >
                    <Controls.Button
                      color="primary"
                      variant="contained"
                      type="submit"
                      text="Submit"
                      loadingIndicator={true}
                      loadingButton={loadingButton}
                      // style={{
                      //   fontSize: 16,
                      // }}
                    />
                  </div>
                </Grid>
              </Form>

              <LoadOperators />
            </div>
          );
        }}
      </Formik>
    </div>
  );
};

export default ComplaintRegForm;
