import { useEffect, useState } from "react";
// import PropTypes from 'prop-types';
import _ from "lodash";
import { Formik, Form, Field, useFormikContext } from "formik";
import {
  initialValues,
  validate,
  useStyles,
  complaintTypeOptions,
} from "./utils";
import Controls from "@/components/Controls/Controls";
import { Grid } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";

import { getMyProfile } from "@/redux/actions/auth.actions";
import { useRouter } from "next/router";
import AlertMessage from "@/components/AlertMessage";
import { getWalletBalance } from "@/redux/actions/passbook.action";
import Cookies from "js-cookie";
import { getComplaintStatus } from "@/redux/actions/complaints.action";
const LoadOperators = ({ userInfoWithRegId }) => {
  const dispatch = useDispatch();
  const router = useRouter();
  const { values, setFieldValue } = useFormikContext();
  useEffect(() => {
    if (typeof userInfoWithRegId.regId !== "undefined") {
      dispatch(
        getMyProfile(userInfoWithRegId?.regId, userInfoWithRegId?.mobile)
      );
    }
  }, [userInfoWithRegId.regId, userInfoWithRegId.mobile, dispatch]);

  return null;
};

const ComplaintsTrackForm = () => {
  const { userInfo, loading, loadingButton } = useSelector(
    (state) => state.myProfile
  );
  const { userInfo: userInfoWithRegId } = useSelector((state) => state.setOtp);
  const { alertOpen } = useSelector((state) => state.alert);
  const dispatch = useDispatch();
  const { isAuthenticated } = useSelector((state) => state.myProfile);
  const reg_id = Cookies.get("regId");
  const mbl = Cookies.get("mobile");
  useEffect(() => {
    isAuthenticated &&
      dispatch(
        getWalletBalance({
          reg_id,
          mbl,
        })
      );
  }, [dispatch, reg_id, mbl, isAuthenticated]);

  return (
    <div>
      <Formik
        initialValues={initialValues}
        validate={validate}
        onSubmit={(values) => {
          dispatch(getComplaintStatus(values));
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          handleChange,
          touched,
          errors,
          setErrors,
          resetForm,
        }) => {
          return (
            <div>
              {alertOpen === true ? <AlertMessage /> : null}
              <Form onSubmit={handleSubmit}>
                <Grid container spacing={2}>
                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.RadioGroup}
                      row={true}
                      label="Track By"
                      id="searchBy"
                      name="searchBy"
                      value={values.searchBy || "byComplaintId"}
                      onChange={(event) => {
                        resetForm();
                        setFieldValue("searchBy", event.currentTarget.value);
                      }}
                      items={[
                        { id: "byComplaintId", title: "Complaint ID" },
                        { id: "byDateRange", title: "Date Range" },
                      ]}
                    />
                  </Grid>
                  {values.searchBy === "byComplaintId" && (
                    <>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.MuiAutoComplete}
                          id="complaintType"
                          name="complaintType"
                          label="Complaint Type"
                          getOptionLabel={(option) =>
                            option.title !== undefined ? option.title : ""
                          }
                          getOptionSelected={(option, values) =>
                            option.id === values.id
                          }
                          error={
                            touched.complaintType &&
                            Boolean(errors.complaintDispo)
                          }
                          helperText={
                            touched.complaintType && errors.complaintType
                          }
                          value={values.complaintTypeOptions || null}
                          onChange={(e, value) => {
                            if (value !== null) {
                              setFieldValue("complaintTypeOptions", value);
                              setFieldValue("complaintType", value?.id);
                            }
                          }}
                          disableClearable={true}
                          options={complaintTypeOptions}
                          style={{ position: "relative", top: -3 }}
                          fullWidth={true}
                        />
                      </Grid>
                      <Grid item xs={12} md={6}>
                        <Field
                          component={Controls.Input}
                          fullWidth
                          id="complaintId"
                          name="complaintId"
                          label="Complaint ID"
                          value={values.complaintId}
                          onChange={handleChange}
                          error={
                            touched.complaintId && Boolean(errors.complaintId)
                          }
                          helperText={touched.complaintId && errors.complaintId}
                          variant="standard"
                          margin="normal"
                          placeholder={"Please Enter assigned Complaint ID"}
                        />
                      </Grid>
                    </>
                  )}
                  {values.searchBy === "byDateRange" && (
                    <>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.DatePicker}
                          id="fromDate"
                          name="fromDate"
                          label="From"
                          error={touched.fromDate && Boolean(errors.fromDate)}
                          helperText={touched.fromDate && errors.fromDate}
                          value={values?.fromDate || Date.now()}
                          onChange={(e) =>
                            setFieldValue("fromDate", e.target.value)
                          }
                          style={{ marginTop: 18 }}
                          fullWidth={true}
                        />
                      </Grid>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.DatePicker}
                          id="toDate"
                          name="toDate"
                          label="To"
                          error={touched.toDate && Boolean(errors.toDate)}
                          helperText={touched.toDate && errors.toDate}
                          value={values?.toDate}
                          onChange={(e) =>
                            setFieldValue("toDate", e.target.value)
                          }
                          style={{ marginTop: 18 }}
                          fullWidth={true}
                        />
                      </Grid>
                    </>
                  )}

                  <div
                    style={{
                      width: "100%",
                      display: "flex",
                      justifyContent: "flex-end",
                    }}
                  >
                    <Controls.Button
                      color="primary"
                      variant="contained"
                      type="submit"
                      text="Submit"
                      loadingIndicator={true}
                      loadingButton={loadingButton}
                      // style={{
                      //   fontSize: 16,
                      // }}
                    />
                  </div>
                </Grid>
              </Form>

              <LoadOperators
                userInfo={userInfo}
                loading={loading}
                userInfoWithRegId={userInfoWithRegId}
              />
            </div>
          );
        }}
      </Formik>
    </div>
  );
};

export default ComplaintsTrackForm;
