import { Formik, Form, Field, useFormikContext } from "formik";
import { initialValues, validate, useStyles } from "./utils";
import Controls from "@/components/Controls/Controls";
import { Grid } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";

import AlertMessage from "@/components/AlertMessage";

import Cookies from "js-cookie";

import { getComplaintTransactionHistory } from "@/redux/actions/complaints.action";
const LoadOperators = () => {
  const { values, setFieldValue } = useFormikContext();

  return null;
};

const ComplainTransactionForm = ({ loadingButton }) => {
  const { alertOpen } = useSelector((state) => state.alert);
  const dispatch = useDispatch();
  const classes = useStyles();
  return (
    <div>
      <Formik
        initialValues={initialValues}
        validate={validate}
        onSubmit={(values) => {
          dispatch(getComplaintTransactionHistory(values));
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          handleChange,
          touched,
          errors,
          setErrors,
          resetForm,
        }) => {
          return (
            <div>
              {alertOpen === true ? <AlertMessage /> : null}
              <Form onSubmit={handleSubmit}>
                <Grid container spacing={2}>
                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.RadioGroup}
                      row={true}
                      label="Search By"
                      id="searchBy"
                      name="searchBy"
                      value={values.searchBy || "searchById"}
                      onChange={(event) => {
                        resetForm();
                        setFieldValue("searchBy", event.currentTarget.value);
                        if (event.currentTarget.value === "searchByDateRange") {
                          setFieldValue("mobNo", Cookies.get("mobile"));
                        }
                      }}
                      items={[
                        { id: "searchById", title: "Transaction ID" },
                        {
                          id: "searchByDateRange",
                          title: "Mobile and Date Range",
                        },
                        // { id: "searchByDateRange", title: "Date Range" },
                      ]}
                    />
                  </Grid>
                  {values.searchBy === "searchById" && (
                    <>
                      <Grid item xs={12}>
                        <Field
                          component={Controls.Input}
                          fullWidth
                          id="txnId"
                          name="txnId"
                          label="Transaction ID"
                          value={values.txnId}
                          onChange={handleChange}
                          error={touched.txnId && Boolean(errors.txnId)}
                          helperText={touched.txnId && errors.txnId}
                          variant="standard"
                          margin="normal"
                          placeholder={"Please Enter assigned Transaction ID"}
                        />
                      </Grid>
                    </>
                  )}
                  {values.searchBy === "searchByMobileNo" && (
                    <>
                      <Grid item xs={12}>
                        <Field
                          component={Controls.Input}
                          fullWidth
                          id="mobNo"
                          name="mobNo"
                          label="Mobile"
                          value={values.mobNo}
                          onChange={handleChange}
                          error={touched.mobNo && Boolean(errors.mobNo)}
                          helperText={touched.mobNo && errors.mobNo}
                          variant="standard"
                          margin="normal"
                          placeholder={"Please Enter Mobile Number"}
                          disabled
                        />
                      </Grid>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.DatePicker}
                          id="fromDate"
                          name="fromDate"
                          label="From"
                          error={touched.fromDate && Boolean(errors.fromDate)}
                          helperText={touched.fromDate && errors.fromDate}
                          value={values?.fromDate || Date.now()}
                          onChange={(e) =>
                            setFieldValue("fromDate", e.target.value)
                          }
                          style={{ marginTop: 18 }}
                          fullWidth={true}
                        />
                      </Grid>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.DatePicker}
                          id="toDate"
                          name="toDate"
                          label="To"
                          error={touched.toDate && Boolean(errors.toDate)}
                          helperText={touched.toDate && errors.toDate}
                          value={values?.toDate}
                          onChange={(e) =>
                            setFieldValue("toDate", e.target.value)
                          }
                          style={{ marginTop: 18 }}
                          fullWidth={true}
                        />
                      </Grid>
                    </>
                  )}
                  {values.searchBy === "searchByDateRange" && (
                    <>
                      <Grid item xs={12}>
                        <Field
                          component={Controls.Input}
                          fullWidth
                          id="mobNo"
                          name="mobNo"
                          label="Mobile"
                          value={values.mobNo}
                          onChange={handleChange}
                          error={touched.mobNo && Boolean(errors.mobNo)}
                          helperText={touched.mobNo && errors.mobNo}
                          variant="standard"
                          margin="normal"
                          placeholder={"Please Enter Mobile Number"}
                          disabled
                        />
                      </Grid>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.DatePicker}
                          id="fromDate"
                          name="fromDate"
                          label="From"
                          error={touched.fromDate && Boolean(errors.fromDate)}
                          helperText={touched.fromDate && errors.fromDate}
                          value={values?.fromDate || Date.now()}
                          onChange={(e) =>
                            setFieldValue("fromDate", e.target.value)
                          }
                          style={{ marginTop: 18 }}
                          fullWidth={true}
                        />
                      </Grid>
                      <Grid item xs={12} md={6}>
                        <Field
                          margin="normal"
                          component={Controls.DatePicker}
                          id="toDate"
                          name="toDate"
                          label="To"
                          error={touched.toDate && Boolean(errors.toDate)}
                          helperText={touched.toDate && errors.toDate}
                          value={values?.toDate}
                          onChange={(e) =>
                            setFieldValue("toDate", e.target.value)
                          }
                          style={{ marginTop: 18 }}
                          fullWidth={true}
                        />
                      </Grid>
                    </>
                  )}

                  <div
                    style={{
                      width: "100%",
                      display: "flex",
                      justifyContent: "flex-end",
                    }}
                  >
                    <Controls.Button
                      color="primary"
                      variant="contained"
                      type="submit"
                      text="Submit"
                      loadingIndicator={true}
                      loadingButton={loadingButton}
                    />
                  </div>
                </Grid>
              </Form>

              <LoadOperators />
            </div>
          );
        }}
      </Formik>
    </div>
  );
};

export default ComplainTransactionForm;
