import { useWindowSize } from "@/hooks/useWindowSize";
import { makeStyles, Grid, Typography, Divider } from "@material-ui/core";
import { useEffect, useState } from "react";
import Image from "next/image";
import Controls from "@/components/Controls/Controls";
import { useDispatch, useSelector } from "react-redux";
import { sendOtp, setOtp } from "@/redux/actions/auth.actions";
import * as yup from "yup";
import AlertMessage from "@/components/AlertMessage";
import { setAlertMessage } from "@/redux/actions/alert.action";
import { useFormik, useFormikContext } from "formik";
import { Link } from "@/components/Link";
import { useRouter } from "next/router";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth}px` : "600px",

    height: "calc(100vh - 75px)",
    overflowY: "auto",
    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
  },
  image: {
    display: "flex",
    justifyContent: "center",
    // paddingTop: theme.spacing(0),
    // paddingBottom: theme.spacing(5),
    flexDirection: "column",
    alignItems: "center",
  },
  heading: {
    fontWeight: 500,
    // textTransform: "uppercase",
    fontSize: 24,
    marginTop: theme.spacing(1),
  },
  divider: {
    width: "90%",
    marginTop: theme.spacing(3),
    marginBottom: theme.spacing(3),
  },
  actionButton: {
    width: "30px",
    height: "30px",
  },
  alert: {
    marginBottom: theme.spacing(2),
    border: `1px solid ${theme.palette.success.main}`,
  },
  resendOtp: {
    border: "none",
    color: "#3da3e3",
    fontSize: 13,
    textDecoration: "underline",
    textDecorationStyle: "dashed",
    fontWeight: 600,
    background: "transparent",

    "&:hover": {
      cursor: "pointer",
    },
  },
  resendOtpContainer: {
    display: "flex",
    width: "100%",
    alignItems: "flex-end",
    justifyContent: "flex-end",
    padding: theme.spacing(2),
  },
}));
const phoneRegExp =
  /^((\\+[1-9]{1,4}[ \\-]*)|(\\([0-9]{2,3}\\)[ \\-]*)|([0-9]{2,4})[ \\-]*)*?[0-9]{3,4}?[ \\-]*[0-9]{3,4}?$/;
const validationSchema = yup.object({
  mbl: yup
    .string()
    .required("Enter your mobile number")
    .matches(phoneRegExp, "Phone number is not valid")
    .min(10, "Mobile should be of minimum 10 characters length")
    .max(10, "Mobile should be of maximum 10 characters length"),
});
const LoginComponent = (props) => {
  const windowWidth = useWindowSize();
  const router = useRouter();
  const dispatch = useDispatch();
  const { status } = useSelector((state) => state.otp);
  const { status: userStatus } = useSelector((state) => state.registerUser);
  const { alertOpen } = useSelector((state) => state.alert);
  const { loadingButton } = useSelector((state) => state.otp);
  const { loadingButton: optSentLoadingButton } = useSelector(
    (state) => state.setOtp
  );

  const [otpSent, setOtpSent] = useState(false);

  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
  });
  const formik = useFormik({
    initialValues: {
      mbl: props.mbl ? props.mbl : "",
      otp: "",
    },

    validationSchema: validationSchema,
    onSubmit:
      otpSent === false
        ? (values) => {
            dispatch(sendOtp(values.mbl));
          }
        : (values) => {
            dispatch(setOtp(values.mbl, values.otp, router));
            console.log(values);
          },
  });
  useEffect(() => {
    if (
      status?.toUpperCase() === "Success".toUpperCase() ||
      userStatus?.toUpperCase() === "Success".toUpperCase()
    ) {
      // alert("hi");

      console.log(props.mbl);
      setOtpSent(true);
    } else {
      setOtpSent(false);
    }
  }, [status, setOtpSent, props.mbl, userStatus]);

  useEffect(() => {
    return () => {
      dispatch(setAlertMessage(false, "", ""));
    };
  }, [dispatch]);

  return (
    <div className={classes.root}>
      <div className={classes.image}>
        <Typography variant="h4" component="div">
          <Image
            src="/assets/images/logos/logo.png"
            alt="logo"
            width="174"
            height="45"
          />
        </Typography>

        {/* <Typography variant="h5" component="div" className={classes.heading}>
          Sign Up
        </Typography> */}

        <Divider className={classes.divider} />
      </div>
      {alertOpen === true ? <AlertMessage /> : null}
      <form onSubmit={formik.handleSubmit}>
        <Grid container spacing={2}>
          <Grid item xs={12}>
            <Controls.Input
              fullWidth={true}
              label="Mobile"
              name="mbl"
              variant="standard"
              placeholder="Please Enter your mobile number"
              // value={mbl}
              maxLength={10}
              // onChange={(e) => setMobile(e.target.value)}
              value={formik.values.mbl}
              onChange={formik.handleChange}
              error={formik.touched.mbl && Boolean(formik.errors.mbl)}
              helperText={formik.touched.mbl && formik.errors.mbl}
            />
          </Grid>

          {otpSent && (
            <Grid item xs={12}>
              <Controls.Input
                fullWidth={true}
                label="OTP"
                name="otp"
                variant="standard"
                placeholder="Please Enter OTP"
                // value={otp || ""}
                // onChange={(e) => setOtp(e.target.value)}
                value={formik.values.otp}
                onChange={formik.handleChange}
                error={formik.touched.otp && Boolean(formik.errors.otp)}
                helperText={formik.touched.otp && formik.errors.otp}
              />
            </Grid>
          )}
          {otpSent ? (
            <div className={classes.resendOtpContainer}>
              <button
                className={classes.resendOtp}
                onClick={(e) => {
                  e.preventDefault();
                  dispatch(sendOtp(formik.values.mbl));
                }}
              >
                Resend OTP
              </button>
            </div>
          ) : null}
          {otpSent ? (
            <>
              <Controls.Button
                fullWidth={true}
                text="LOGIN"
                type="submit"
                loadingButton={optSentLoadingButton}
                loadingIndicator={true}
                fullWidthButton={true}
                disabled={
                  formik.values.otp === "" || formik.values.otp === "null"
                    ? true
                    : false
                }
              />
            </>
          ) : (
            <Controls.Button
              fullWidth={true}
              text="GET OTP"
              type="submit"
              loadingButton={loadingButton}
              loadingIndicator={true}
              fullWidthButton={true}
            />
          )}
        </Grid>
      </form>
    </div>
  );
};

export default LoginComponent;
