import React, { useState, useEffect, useMemo } from "react";
import StickyHeadTable from "@/components/Table";
import NoRecords from "@/components/NoRecords";
import Controls from "@/components/Controls/Controls";
import {
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
} from "@material-ui/core";
import MuiAppBar from "@/components/Container/Appbar";
import Disclaimer from "@/components/Disclaimer";
import { columns } from "./utils";
import Spinner from "@/components/Spinner";
const PreviewPlans = ({ plans, filterData, setAmountValue, slider }) => {
  // const filterValue = filterData?.length > 0 ? filterData[0] : [];
  const filterValue = useMemo(
    () => (filterData?.length > 0 ? filterData[0] : []),
    [filterData]
  );

  const [records, setRecords] = useState([]);
  const pagination = plans?.length || 0;
  const { TblContainer } = StickyHeadTable(records, pagination);
  const [filter, setFilter] = useState(filterValue);
  const handleFilter = (e) => {
    e.preventDefault();
    e.persist();
    let filtered = e.target.innerText;
    if (filtered === "ROMAING") {
      filtered = "Romaing";
    }
    setFilter(filtered);
    plans[filtered] ? setRecords(plans[filtered]) : setRecords([]);
  };
  useEffect(() => {
    plans && filterValue ? setRecords(plans[filterValue]) : setRecords([]);
  }, [setRecords, filterValue, plans]);
  return (
    <div>
      <MuiAppBar menuItems={filterData} handleFilter={handleFilter} />
      <TblContainer records={records} pagination={pagination}>
        <TableContainer style={{ maxHeight: 320 }} className="scrollbar">
          {slider === true ? (
            <style>{`
        .box.box-form.preview {
          padding: 0 !important;
      }
        `}</style>
          ) : (
            <style>{`
      .box.box-form.preview {
        padding: 40 !important;
    }
      `}</style>
          )}
          <Table stickyHeader aria-label="sticky table">
            <TableHead>
              <TableRow>
                {columns.map((column) => (
                  <TableCell
                    key={column.id}
                    align={column.align}
                    style={{ minWidth: column.minWidth, fontSize: 12 }}
                  >
                    {column.label}
                  </TableCell>
                ))}
              </TableRow>
            </TableHead>
            <TableBody>
              {records.length > 0 ? (
                records.map((item, index) => {
                  return (
                    <TableRow hover role="checkbox" tabIndex={-1} key={index}>
                      {columns.map((column) => {
                        const value = item[column.id];
                        return (
                          <TableCell
                            key={column?.id}
                            align={column.align}
                            style={{ textTransform: column.textTransform }}
                          >
                            {column.textTransformFirstChar === true ? (
                              value.charAt(0).toUpperCase() +
                              value.slice(1, value.length)
                            ) : column.button === true ? (
                              <Controls.Button
                                text={`₹ ${value}`}
                                variant="outlined"
                                onClick={() => {
                                  setAmountValue(value);
                                }}
                                style={{
                                  minWidth: 90,
                                  fontSize: 13.5,
                                  paddingTop: 5,
                                  paddingBottom: 5,
                                  paddingLeft: 10,
                                  paddingRight: 10,
                                }}
                              />
                            ) : (
                              value
                            )}
                          </TableCell>
                        );
                      })}
                    </TableRow>
                  );
                })
              ) : (
                <TableRow>
                  <TableCell colSpan={columns.length + 1}>
                    <NoRecords>No Plans at this Moment</NoRecords>
                  </TableCell>
                </TableRow>
              )}
            </TableBody>
          </Table>
        </TableContainer>
      </TblContainer>
      <Disclaimer>
        <strong>Disclaimer: </strong>While we support most recharges, we request
        you to verify with your operator once before proceeding.
      </Disclaimer>
    </div>
  );
};
export default PreviewPlans;
