import { useEffect, useState } from "react";
// import PropTypes from 'prop-types';
import Spinner from "@/components/Spinner";
import _ from "lodash";
import { Formik, Form, Field, useFormikContext } from "formik";
import { initialValues, useStyles } from "./utils";
import Controls from "@/components/Controls/Controls";
import { Grid, Typography } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import {
  getAllOperators,
  getAllPlans,
} from "@/redux/actions/mobile.recharge.actions";
import { checkNumeric } from "utils/customFunctions";
import { Skeleton } from "@material-ui/lab";
import LoginComponent from "@/screens/LoginComponent";
import { useRouter } from "next/router";
import Cookies from "js-cookie";
import axios from "axios";
import { closeDrawer, openDrawer } from "@/redux/actions/drawer.actions";
import DrawerExample from "@/components/Layout/Drawer/ModalExample";
import { toast } from "react-toastify";
import { validateLoginUser } from "@/components/RequireAuthentication/RequireAuthentication";

const LoadOperators = ({ operator, circle, amount }) => {
  const dispatch = useDispatch();

  const { values, setFieldValue } = useFormikContext();
  useEffect(() => {
    if (values.mbl.length === 10 && checkNumeric(values.mbl)) {
      dispatch(getAllPlans(values.mbl));
    }
  }, [values.mbl, dispatch]);

  useEffect(() => {
    if (values.mbl.length === 10 && checkNumeric(values.mbl)) {
      setFieldValue("Operator", operator);
      setFieldValue("Circle", circle);
    }
  }, [values.mbl, operator, setFieldValue, circle]);

  useEffect(() => {
    setFieldValue("recharge_amount", amount);
  }, [setFieldValue, amount]);
  useEffect(() => {
    if (values.recharge_type) {
      dispatch(getAllOperators(values.recharge_type));
    }
  }, [values.recharge_type, dispatch]);
  return null;
};

const MobileRechargeForm = ({ amount }) => {
  const dispatch = useDispatch();
  const classes = useStyles();
  const router = useRouter();
  const { operators, loading: loadOper } = useSelector(
    (state) => state.operators
  );
  const { plans, circle, operator, oprCode, loading } = useSelector(
    (state) => state.plans
  );
  const [disabledProceed, setDisabledProceed] = useState(false);
  return (
    <div>
      <Formik
        initialValues={initialValues}
        // validate={validate}
        onSubmit={async (values, actions) => {
          // const { operator_name, ...restValues } = values;
          // const { recharge_type, mbl, Operator, Circle, recharge_amount } =
          //   restValues;
          // const { data: isUserValid } = await axios({
          //   method: "POST",
          //   url: "https://aaipay.in:10002/api/apps/v1/user_validate.jsp",
          //   headers: { "content-type": "application/json" },
          //   data: {
          //     mobile: mbl,
          //     device: "1244115844",
          //   },
          // });
          // console.log(isUserValid);
          // if (isUserValid.err === "01") {
          //   Cookies.set(
          //     "plan",
          //     JSON.stringify({
          //       recharge_type,
          //       mbl,
          //       Operator,
          //       Circle,
          //       recharge_amount,
          //       oprCode,
          //     })
          //   );
          //   router.push("/payment-details");
          //   setDisabledProceed(true);
          // } else {
          //   dispatch(closeDrawer({ modalProps: { open: false } }));
          //   toast.error("Please Login to Continue", {
          //     position: "top-center",
          //     autoClose: 5000,
          //     hideProgressBar: false,
          //     closeOnClick: true,
          //     pauseOnHover: true,
          //     draggable: true,
          //     progress: undefined,
          //   });
          //   dispatch(
          //     openDrawer({
          //       modalType: DrawerExample,
          //       modalProps: {
          //         component: <LoginComponent />,
          //         open: true,
          //         // setOpen: setOpen,
          //         widthDrawer: 800,
          //         closeDrawerAction: true,
          //       },
          //     })
          //   );

          //   // yield put(setAlertMessage(true, "error", "Please Login to Continue"));

          //   setDisabledProceed(false);
          //   // dispatch({ type: LOADING_BUTTON_RESET });
          // }

          try {
            const { operator_name, ...restValues } = values;
            const { recharge_type, mbl, Operator, Circle, recharge_amount } =
              restValues;
            const ip = Cookies.get("ip");
            const loginKey = Cookies.get("loginKey");
            const password = Cookies.get("password");
            const mobile = Cookies.get("mobile");
            const { data } = await validateLoginUser({
              ip,
              loginKey,
              password,
              mobile,
            });
            if (data?.err === "101") {
              Cookies.set(
                "plan",
                JSON.stringify({
                  recharge_type,
                  mbl,
                  Operator,
                  Circle,
                  recharge_amount,
                  oprCode,
                })
              );
              router.push("/payment-details");
              setDisabledProceed(true);
            } else {
              dispatch(closeDrawer({ modalProps: { open: false } }));
              toast.error("Please Login to Continue", {
                position: "top-center",
                autoClose: 5000,
                hideProgressBar: false,
                closeOnClick: true,
                pauseOnHover: true,
                draggable: true,
                progress: undefined,
              });
              dispatch(
                openDrawer({
                  modalType: DrawerExample,
                  modalProps: {
                    component: <LoginComponent />,
                    open: true,
                    // setOpen: setOpen,
                    widthDrawer: 800,
                    closeDrawerAction: true,
                  },
                })
              );

              setDisabledProceed(false);
            }
          } catch (error) {
            console.error(error);
          }
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          handleChange,
          touched,
          errors,
          setErrors,
        }) => {
          const rechargeTypeCapitalize = `${values.recharge_type
            .charAt(0)
            .toUpperCase()}${values.recharge_type
            .slice(1, values.recharge_type.length)
            .toLowerCase()}`;

          const handleServiceChange = (e) => {
            setFieldValue("recharge_type", e.target.value);
            dispatch(getAllOperators(values.recharge_type));
            setFieldValue("Operator", "");
            setFieldValue("mbl", "");
            setFieldValue("recharge_amount", "");
            setFieldValue("oprCode", "");
            setErrors("");
          };
          const flatOperatorOptions = {
            options: operators.map((option) => option.operator),
          };
          return (
            <>
              <Grid container>
                {loadOper ? (
                  <Grid item xs={12} className="skeleton__wrapper">
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                    <Skeleton animation="wave" className="skeleton" />
                  </Grid>
                ) : (
                  <>
                    <Grid
                      item
                      xs={12}
                      style={{ display: "flex", justifyContent: "flex-start" }}
                    >
                      <Typography
                        component="div"
                        variant="subtitle2"
                        style={{
                          marginBottom: 10,
                        }}
                        className="bill_head"
                      >
                        {operator && values.mbl.length === 10
                          ? values.recharge_type.toLowerCase() ===
                            "PREPAID".toLowerCase()
                            ? `${
                                values.Operator.toLowerCase() ||
                                operator.toLowerCase()
                              } ${rechargeTypeCapitalize} Mobile Recharge`
                            : `${
                                values.Operator.toLowerCase() ||
                                operator.toLowerCase()
                              } ${rechargeTypeCapitalize} Mobile Bill Payment`
                          : `Mobile Recharge or Bill Payment`}
                      </Typography>
                    </Grid>
                    <Form onSubmit={handleSubmit}>
                      <Grid container spacing={3}>
                        <Grid item xs={12} md={12}>
                          <Field
                            component={Controls.RadioGroup}
                            row={true}
                            id="recharge_type"
                            name="recharge_type"
                            value={values.recharge_type}
                            onChange={handleServiceChange}
                            items={[
                              { id: "PREPAID", title: "Prepaid" },
                              { id: "POSTPAID", title: "Postpaid" },
                            ]}
                          />
                        </Grid>
                        <Grid item xs={12} md={12}>
                          <Field
                            component={Controls.Input}
                            fullWidth
                            id="mbl"
                            name="mbl"
                            label="Mobile Number"
                            value={values.mbl}
                            onChange={handleChange}
                            error={touched.mbl && Boolean(errors.mbl)}
                            helperText={touched.mbl && errors.mbl}
                            variant="standard"
                            margin="normal"
                          />
                        </Grid>
                        {values.mbl.length === 10 &&
                        checkNumeric(values.mbl) ? (
                          !loading ? (
                            <>
                              <Grid item xs={12} md={12}>
                                <Field
                                  {...flatOperatorOptions}
                                  component={Controls.AutoCompleteSingle}
                                  id="Operator"
                                  name="Operator"
                                  label="Operator"
                                  getOptionSelected={(option, values) =>
                                    option.toLowerCase() ===
                                    values.toLowerCase()
                                  }
                                  value={values?.Operator || null}
                                  onChange={(e, value) => {
                                    value !== null &&
                                      setFieldValue("Operator", value);
                                  }}
                                />
                              </Grid>
                              <Grid item xs={12} md={12}>
                                <Field
                                  component={Controls.AutoCompleteSingle}
                                  id="Circle"
                                  name="Circle"
                                  label="Circle"
                                  value={values.Circle || null}
                                  onChange={(e, value) => {
                                    value !== null &&
                                      setFieldValue("Circle", value);
                                  }}
                                  getOptionSelected={(option, values) =>
                                    option.toLowerCase() ===
                                    values.toLowerCase()
                                  }
                                  options={["DELHI", "PUNJAB"]}
                                />
                              </Grid>
                            </>
                          ) : (
                            <Spinner />
                          )
                        ) : null}

                        <Grid item xs={12} md={12}>
                          <Field
                            component={Controls.Input}
                            fullWidth
                            id="recharge_amount"
                            name="recharge_amount"
                            label="Amount"
                            value={values.recharge_amount}
                            onChange={handleChange}
                            error={
                              touched.recharge_amount &&
                              Boolean(errors.recharge_amount)
                            }
                            helperText={
                              touched.recharge_amount && errors.recharge_amount
                            }
                            variant="standard"
                            margin="normal"
                          />
                        </Grid>

                        <Controls.Button
                          color="primary"
                          variant="contained"
                          fullWidth
                          type="submit"
                          loadingIndicator={true}
                          loadingButton={disabledProceed}
                          fullWidthButton={true}
                          text="Proceed"
                          className={classes.loadingButton}
                          style={{ fontSize: 16 }}
                          disabled={
                            values.mbl.length !== 10 ||
                            !checkNumeric(values.mbl) ||
                            values.recharge_amount === "" ||
                            !checkNumeric(values.recharge_amount)
                              ? true
                              : false
                          }
                        />
                      </Grid>
                    </Form>
                  </>
                )}
              </Grid>

              <LoadOperators
                plans={plans}
                operator={operator}
                circle={circle}
                amount={amount}
              />
            </>
          );
        }}
      </Formik>
    </div>
  );
};

export default MobileRechargeForm;
