import { useEffect } from "react";
// import PropTypes from 'prop-types';

import _ from "lodash";
import { Formik, Form, Field, useFormikContext } from "formik";
import { initialValues, validate } from "./utils";
import Controls from "@/components/Controls/Controls";
import { Grid } from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";

import { updateProfile } from "@/redux/actions/auth.actions";

import AlertMessage from "@/components/AlertMessage";

const LoadOperators = ({ userInfo, loading }) => {
  const { values, setFieldValue } = useFormikContext();
  // useEffect(() => {
  //   if (typeof userInfoWithRegId.regId !== "undefined") {
  //     dispatch(
  //       getMyProfile(userInfoWithRegId?.regId, userInfoWithRegId?.mobile)
  //     );
  //   }
  // }, [userInfoWithRegId.regId, userInfoWithRegId.mobile, dispatch]);

  // useEffect(() => {
  //   console.log(userInfo.Name);
  //   if (userInfo.Name === "undefined") {
  //     router.push("/mobile");
  //   }
  // }, [userInfo.Name, router]);
  useEffect(() => {
    if (!_.isEmpty(userInfo) && !loading) {
      setFieldValue("Mobile", userInfo.Mobile);
      setFieldValue("Email", userInfo.Email);
      setFieldValue("Name", userInfo.Name);
      setFieldValue("gender", userInfo.gender);
      setFieldValue("Address", userInfo.Address);
      setFieldValue("city", userInfo.city);
      setFieldValue("state", userInfo.state);
      setFieldValue("zip", userInfo.zip);
      setFieldValue("reg_date", String(new Date(userInfo.reg_date)));
    }
  }, [userInfo, loading, setFieldValue]);
  return null;
};

const MyProfileForm = ({ userInfo }) => {
  const { loading, loadingButton } = useSelector((state) => state.myProfile);
  const { userInfo: userInfoWithRegId } = useSelector((state) => state.setOtp);
  const { alertOpen } = useSelector((state) => state.alert);
  const dispatch = useDispatch();
  return (
    <div>
      <Formik
        initialValues={initialValues}
        validator={validate}
        onSubmit={(values, actions) => {
          // setTimeout(() => {
          //   alert(JSON.stringify(values, null, 2));
          //   actions.setSubmitting(false);
          // }, 1000);
          console.log(values);
          dispatch(updateProfile(values));
        }}
      >
        {({
          setFieldValue,
          values,
          handleSubmit,
          handleChange,
          touched,
          errors,
          setErrors,
        }) => {
          return (
            <>
              {alertOpen === true ? <AlertMessage /> : null}
              <Form onSubmit={handleSubmit}>
                <Grid container spacing={5}>
                  <Grid item xs={12} md={4}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="Mobile"
                      name="Mobile"
                      label="Primary Mobile Number"
                      value={values.Mobile}
                      onChange={handleChange}
                      error={touched.Mobile && Boolean(errors.Mobile)}
                      helperText={touched.Mobile && errors.Mobile}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your Primary Mobile Number"}
                      disabled
                    />
                  </Grid>
                  <Grid item xs={12} md={4}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="Email"
                      name="Email"
                      label="Email"
                      value={values.Email}
                      onChange={handleChange}
                      error={touched.Email && Boolean(errors.Email)}
                      helperText={touched.Email && errors.Email}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your Email Address"}
                    />
                  </Grid>
                  <Grid item xs={12} md={4}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="Name"
                      name="Name"
                      label="Name"
                      value={values.Name}
                      onChange={handleChange}
                      error={touched.Name && Boolean(errors.Name)}
                      helperText={touched.Name && errors.Name}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your Full Name"}
                    />
                  </Grid>
                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.RadioGroup}
                      row={true}
                      label="Gender"
                      id="gender"
                      name="gender"
                      value={values.gender || "male"}
                      onChange={(event) => {
                        setFieldValue("gender", event.currentTarget.value);
                      }}
                      items={[
                        { id: "male", title: "Male" },
                        { id: "female", title: "Female" },
                        { id: "others", title: "Others" },
                      ]}
                    />
                  </Grid>
                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.Input}
                      multiline={true}
                      label="Address"
                      id="Address"
                      name="Address"
                      value={values.Address}
                      onChange={handleChange}
                      fullWidth
                      placeholder={"Please Enter your Address"}
                      margin="normal"
                    />
                  </Grid>
                  <Grid item xs={12} md={4}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="city"
                      name="city"
                      label="City"
                      value={values.city}
                      onChange={handleChange}
                      error={touched.city && Boolean(errors.city)}
                      helperText={touched.city && errors.city}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your City"}
                    />
                  </Grid>
                  <Grid item xs={12} md={4}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="state"
                      name="state"
                      label="State"
                      value={values.state}
                      onChange={handleChange}
                      error={touched.state && Boolean(errors.state)}
                      helperText={touched.state && errors.state}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your State"}
                    />
                  </Grid>
                  <Grid item xs={12} md={4}>
                    <Field
                      component={Controls.Input}
                      fullWidth
                      id="zip"
                      name="zip"
                      label="Zip Code"
                      value={values.zip}
                      onChange={handleChange}
                      error={touched.zip && Boolean(errors.zip)}
                      helperText={touched.zip && errors.zip}
                      variant="standard"
                      margin="normal"
                      placeholder={"Please Enter your Zip Code"}
                    />
                  </Grid>
                  <Grid item xs={12} md={12}>
                    <Field
                      component={Controls.Input}
                      multiline={true}
                      label="Member Since"
                      id="reg_date"
                      name="reg_date"
                      value={values.reg_date}
                      onChange={handleChange}
                      fullWidth
                      //   placeholder={"Please Enter your reg_date"}
                      margin="normal"
                      disabled
                    />
                  </Grid>
                  <div
                    style={{
                      width: "100%",
                      display: "flex",
                      justifyContent: "flex-end",
                    }}
                  >
                    <Controls.Button
                      color="primary"
                      variant="contained"
                      type="submit"
                      text="Update Profile"
                      loadingIndicator={true}
                      loadingButton={loadingButton}
                      // style={{
                      //   fontSize: 16,
                      // }}
                    />
                  </div>
                </Grid>
              </Form>

              <LoadOperators
                userInfo={userInfo}
                loading={loading}
                userInfoWithRegId={userInfoWithRegId}
              />
            </>
          );
        }}
      </Formik>
    </div>
  );
};

export default MyProfileForm;
