// import Overlay from "@/components/Overlay";
// import PageHeader from "@/components/PageHeader";
import PageHeader from "@/components/PageHeader";
import Spinner from "@/components/Spinner";
import { getPassBook, getWalletBalance } from "@/redux/actions/passbook.action";
import _ from "lodash";
import {
  Avatar,
  Grid,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Typography,
} from "@material-ui/core";
import Cookies from "js-cookie";
import { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useStyles } from "./utils";
import Moment from "react-moment";
import Overlay from "@/components/Overlay";
import AddMoneyToWallet from "@/components/AddMoneyToWallet";
import GeneralBreadcrumbs from "@/components/GeneralBreadcrumbs";
import AlertMessage from "@/components/AlertMessage";
import { capitalize } from "utils/customFunctions";

// import MyProfileForm from "./_Form";

const PassBookComponent = () => {
  const classes = useStyles();
  const dispatch = useDispatch();
  const { isAuthenticated } = useSelector((state) => state.myProfile);

  const {
    passbook,
    loading: loadPass,
    wallet_balance,
  } = useSelector((state) => state.passbook);
  const reg_id = Cookies.get("regId");
  const mobile = Cookies.get("mobile");
  useEffect(() => {
    dispatch(getPassBook({ reg_id, mobile }));
  }, [dispatch, reg_id, mobile]);

  useEffect(() => {
    isAuthenticated &&
      dispatch(
        getWalletBalance({
          reg_id,
          mbl: mobile,
        })
      );
  }, [dispatch, reg_id, mobile, isAuthenticated]);
  return (
    <>
      <div className={classes.root}>
        <GeneralBreadcrumbs />
        <PageHeader
          title="Passbook"
          subTitle="Manage Your Transaction History from Here"
        />
        <AddMoneyToWallet walletBalance={wallet_balance} />
        <TableContainer className="scrollbar">
          <Table style={{ minWidth: 600, overflowX: "auto" }}>
            <TableHead>
              <TableRow>
                <TableCell
                  style={{
                    textTransform: "uppercase",
                    minWidth: 350,
                  }}
                >
                  Transactions
                </TableCell>
                <TableCell style={{ textTransform: "uppercase" }}>
                  Amount
                </TableCell>
                <TableCell style={{ textTransform: "uppercase" }}>
                  Status
                </TableCell>
                <TableCell
                  style={{ textTransform: "uppercase", minWidth: 200 }}
                >
                  Remarks
                </TableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              {loadPass && (
                <TableRow>
                  <TableCell colSpan={6}>
                    <center>
                      {" "}
                      <Spinner />
                    </center>
                  </TableCell>
                </TableRow>
              )}
              {!loadPass && _.isEmpty(passbook) && (
                <TableRow>
                  <TableCell colSpan={6}>
                    <center>You have not made any transactions yet</center>
                  </TableCell>
                </TableRow>
              )}

              {!loadPass &&
                !_.isEmpty(passbook) &&
                passbook.map((transaction) => {
                  const {
                    amount,
                    operator,
                    operation,
                    remark,
                    Transection_status,
                    date,
                    acount,
                    bank_ref_ID,
                    tid,
                    status,
                  } = transaction;
                  return (
                    <TableRow key={tid}>
                      <TableCell style={{ width: "600px" }}>
                        <Grid container spacing={2}>
                          <Grid item sm={4} xs={4} md={2}>
                            <Avatar
                              alt="Remy Sharp"
                              // src="/static/images/avatar/1.jpg"
                              src={
                                Transection_status.toUpperCase() === "CREDIT"
                                  ? `/assets/images/rupee_up.png`
                                  : `/assets/images/rupee_down.png`
                              }
                            />
                          </Grid>
                          <Grid item xs={8} sm={8} md={10}>
                            <Typography variant="body2">
                              {operator === "PG"
                                ? "Money Added to Wallet"
                                : operator}
                            </Typography>
                            <Typography
                              variant="h6"
                              style={{
                                fontSize: "1.1rem",
                                marginBottom: "0.2rem",
                              }}
                            >
                              {operation === "wallet" && "Add Money"}
                              {operation === "Service_booking" &&
                                `Order Booking for ID ${acount}`}
                              {operation === "recharge" &&
                                `Recharge/Bill Payment for ${acount}`}
                            </Typography>
                            <Typography
                              variant="body2"
                              style={{
                                marginBottom: "0.8rem",
                              }}
                            >
                              <Moment date={date} format="DD-MM-YYYY hh:mm A" />
                            </Typography>
                            <Typography variant="body2">
                              Transaction ID {tid}
                            </Typography>
                          </Grid>
                        </Grid>
                      </TableCell>
                      <TableCell>
                        <Typography variant="subtitle1">
                          {Transection_status.toUpperCase() === "CREDIT"
                            ? `+${amount}`
                            : `-${amount}`}
                        </Typography>
                      </TableCell>
                      <TableCell>
                        <Typography variant="subtitle1">
                          {status.toUpperCase()}
                        </Typography>
                      </TableCell>
                      <TableCell>
                        <Typography variant="subtitle1">
                          {capitalize(remark)}
                        </Typography>
                      </TableCell>
                    </TableRow>
                  );
                })}
            </TableBody>
          </Table>
        </TableContainer>
      </div>
    </>
  );
};

export default PassBookComponent;
