/* eslint-disable jsx-a11y/anchor-is-valid */

import CardComponentNoMedia from "@/components/CardComponentNoMedia/index";

import { getPassBook, getWalletBalance } from "@/redux/actions/passbook.action";

import Image from "next/image";
import { Grid, Paper, Typography } from "@material-ui/core";
import Cookies from "js-cookie";
import { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useStyles } from "./utils";

import GeneralBreadcrumbs from "@/components/GeneralBreadcrumbs";

import ArrowForwardIcon from "@material-ui/icons/ArrowForward";
import aboutCards from "@/config/aboutCards";
import { useWindowSize } from "@/hooks/useWindowSize";
// import MyProfileForm from "./_Form";

const PrivacyPolicyComponent = () => {
  const classes = useStyles();
  const dispatch = useDispatch();
  const { isAuthenticated, loadProf } = useSelector((state) => state.myProfile);
  const reg_id = Cookies.get("regId");
  const mobile = Cookies.get("mobile");
  useEffect(() => {
    dispatch(getPassBook({ reg_id, mobile }));
  }, [dispatch, reg_id, mobile]);

  useEffect(() => {
    isAuthenticated &&
      dispatch(
        getWalletBalance({
          reg_id,
          mbl: mobile,
        })
      );
  }, [dispatch, reg_id, mobile, isAuthenticated]);
  const { width: windowWidth } = useWindowSize();
  return (
    <>
      <div className={classes.root}>
        <GeneralBreadcrumbs />

        <Typography
          variant="h6"
          style={{ fontSize: 28, textTransform: "uppercase", marginBottom: 30 }}
        >
          PRIVACY POLICY
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              This Privacy Policy explains the approach of AaiPay towards user/
              customer information provided on AaiPay. This Privacy Policy is an
              open to all public document.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              1. Collection
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              1.1 AaiPay will only collect Personal Information where the
              information is necessary for AaiPay for carrying out any of the
              functions which are a part and parcel of the activities of AaiPay.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              1.2 AaiPay collects Personal Data to carry out the functions of
              the site such as provide online recharge, provide information on
              promotions new products and services related to Prepaid and Post
              Paid Recharge and Gadgets related to the mobile industry primarily
              in India. AaiPay also gathers/collects information for account
              management, billing services, business planning and marketing.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              1.3 AaiPay will be transparent and notify individuals on the
              reason for collecting any personal information and whether if the
              information may be used in the future for any purposes stating an
              overview of the purpose. The individual may then decide to
              participate or not or to participate selectively. Individuals may
              contact AaiPay (Address given at the Contact Us Page) for their
              personal data be removed ( upon proving their identity first) from
              the database for any personal reasons which will be promptly acted
              upon. The type of organisations to whom AaiPay usually Disclose
              the Personal Information include Related Bodies Corporates and
              contractors and at any point if required by Government of India
              and Related Bodies. AaiPay will not collect Sensitive Information
              from individuals except with consent and only where it is
              necessary . AaiPay will not collect Personal Data of any
              Individual in any underhanded manner.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              2. Use
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              2.1 AaiPay might use the data mainly contact information for
              Direct Marketing for the site. i) individuals can easily
              unsubscribe to Direct Marketing Program of AaiPay. ii) if the
              individual Opts Out of all Direct Marketing Program, the wish will
              be respected by AaiPay and all its Related subsidiaries.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              2.2 AaiPay will not use Sensitive Information for Direct
              Marketing.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              2.3 AaiPay may use Personal Information for reasons related to law
              enforcement or internal investigations into unlawful activitiesor
              if ordered by the Government of India and/or any other law
              enforcing agency.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              2.4 AaiPay will not use Data where there is a doubt that the
              information is accurate, complete and up to date.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              3. Disclosure
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              3.1 AaiPay may Disclose Personal Information to related or
              unrelated third parties if consent has been obtained from the
              individual.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              3.2 AaiPay may Disclose Personal Data to Related Bodies Corporate.
              Where that Related Body Corporate is bound by the original Primary
              Purpose for which the information was collected.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              3.3 AaiPay may Disclose Personal Information to unrelated third
              parties to enable outsourcing of functions (such as billing,
              account management) which is expected.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              3.4 AaiPay may Disclose Personal Information to law enforcement
              agencies, Government of India agencies, courts or external
              advisers where permitted or required by law.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              3.5 AaiPay may Disclose Personal data for personal or public
              safety.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              3.6 AaiPay does not sell or share its customer lists on a
              commercial basis with third parties but if it did, it would only
              do so only with prior consent of the individual.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              4. Information quality
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              4.1 AaiPay will review from time to time the data collected and
              ensure the accurateness of the data by asking individuals to
              participate in updating the same.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              4.2 AaiPay may ask its users to re- enter data in case there is
              any system failure causing any information loss.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              4.3 AaiPay reserves the right to destroy the data after a
              particular period of time once it becomes redundant in use or for
              any other reason to safeguard the interests of AaiPay.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              5. Information security
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              5.1 AaiPay directs its employees to perform duties so as to assist
              in every way possible to carry out the privacy policy in the
              truest possible manner.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              5.2 AaiPay will ensure that the records containing Personal
              Information accessible by staff who have a genuine{" "}
              {"need to know"} as well as {"right to know"}.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              5.3 AaiPay will not falsely protect any employee/ person who is
              found to have tampered or have used the personal data in an
              underhanded and/or harmful manner.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              6. Access and correction
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              6.1 AaiPay will allow its records containing Personal Information
              to be accessed by the individual concerned in accordance with the
              Privacy Act.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              6.2 AaiPay will correct its records containing Personal
              Information as soon as practically possible, at the request of the
              individual concerned .
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              6.3 Individuals wishing to correct/ update/ remove their personal
              information due to valid reasons may do so by approaching AaiPay
              Customer Service.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              6.4 Individuals may also update their information where
              individuals hold an account at AaiPay.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              7. Anonymous transactions
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              7.1 AaiPay will not make it mandatory for visitors to its web
              sites to provide Personal Information unless such Personal
              Information is required to answer an inquiry or provide a service.
              Individuals may however choose to participate in providing
              personal information (for example, as part of a competition or
              questionnaire).
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              7.2 AaiPay will allow its customers to transact with it
              anonymously wherever possible.
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              8. Glossary
            </Typography>
          </Grid>
          <Grid item xs={12} md={12}>
            <Typography variant="body1" className={classes.para} component="p">
              Collection Information means the information outlined in 1.3
              notified to individuals prior to, or as soon as practical after,
              the collection of their Personal Information.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              Direct Marketing means the marketing of goods or services through
              means of communication including written, verbal or electronic
              means. The goods or services which are marketed may be those of
              AaiPay or a Related Body Corporate or those of an independent
              third party organisation.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              Disclosure generally means the release of information outside
              AaiPay, including under a contract to carry out an{" "}
              {"outsourced function"}.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              AaiPay means all companies in the AaiPay group, including
              Linkincity.com, Techroxy.com and Aquilis Design.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              Personal Information means information or an opinion (including
              information or an opinion forming part of a database), whether
              true or not and whether recorded in a material form or not, about
              an individual whose identity is apparent, or can reasonably be
              ascertained from the information or opinion.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              Sensitive Information means:
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              (a) information or an opinion about an {"individual's"}:
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (i) racial or ethnic origin; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (ii) political opinions; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (iii) membership of a political association; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (iv) religious beliefs or affiliations; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (v) philosophical beliefs; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (vi) membership of a professional or trade association; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (vii) membership of a trade union; or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (ix) criminal record;that is also personal information or
            </Typography>
            <Typography variant="body1" className={classes.para3} component="p">
              (x) Health Information about an individual.
            </Typography>
            <Typography variant="body1" className={classes.para} component="p">
              Use means the handling of Personal Information within AaiPay.
            </Typography>
          </Grid>
          <Grid></Grid>
          <Grid item xs={12}>
            <Typography
              variant="h6"
              style={{
                fontSize: 20,
                textTransform: "uppercase",
                marginBottom: 0,
              }}
            >
              Contacting AaiPay
            </Typography>
          </Grid>
          <Grid item xs={12}>
            <div
              style={{
                display: "flex",
                flexDirection: windowWidth > 768 ? "row" : "column",
              }}
            >
              <Typography
                variant="subtitle2"
                style={{
                  fontSize: "1.1rem",
                  minWidth: windowWidth > 768 ? 150 : 0,
                }}
              >
                Address
              </Typography>
              <Typography variant="body2" style={{ fontSize: "0.9rem" }}>
                222, 2nd Floor, Corporate Parke Pune, Maharshra-7938448
              </Typography>
            </div>
            <div
              style={{
                display: "flex",
                flexDirection: windowWidth > 768 ? "row" : "column",
              }}
            >
              <Typography
                variant="subtitle2"
                style={{
                  fontSize: "1.1rem",
                  minWidth: windowWidth > 768 ? 150 : 0,
                }}
              >
                Hotline
              </Typography>
              <Typography variant="body2" style={{ fontSize: "0.9rem" }}>
                <a className={classes.link} href={"tel: +918888222200"}>
                  +918888222200
                </a>
              </Typography>
            </div>
            <div
              style={{
                display: "flex",
                flexDirection: windowWidth > 768 ? "row" : "column",
              }}
            >
              <Typography
                variant="subtitle2"
                style={{
                  fontSize: "1.1rem",
                  minWidth: windowWidth > 768 ? 150 : 0,
                }}
              >
                Email Us
              </Typography>
              <Typography variant="body2" style={{ fontSize: "0.9rem" }}>
                <a className={classes.link} href={"mailto:contactus@aaipay.in"}>
                  contactus@aaipay.in
                </a>
              </Typography>
            </div>
          </Grid>
        </Grid>
      </div>
    </>
  );
};

export default PrivacyPolicyComponent;
