import { useWindowSize } from "@/hooks/useWindowSize";
import {
  Grid,
  makeStyles,
  Table,
  TableBody,
  TableCell,
  TableRow,
  Typography,
} from "@material-ui/core";
import { useDispatch, useSelector } from "react-redux";
import _ from "lodash";
import Image from "next/image";
import Controls from "@/components/Controls/Controls";
import { closeModal, openModal } from "@/redux/actions/modal.actions";
import ModalExample from "@/components/Layout/Modal/ModalExample";
import BillPaidComponent from "@/screens/BillPaidComponent";
import TableRowComponent from "@/components/TableRowComponent";
import { useRouter } from "next/router";
import QuickPayPaidComponent from "@/screens/QuickPayPaidComponent";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 16}px` : "100%",

    // height: "calc(100vh - 10px)",

    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    // overflowY: "scroll",
  },
  table: {
    padding: theme.spacing(2),
    margin: theme.spacing(2, 0, 0, 0),
  },
}));

const QuickPayComponent = () => {
  const dispatch = useDispatch();
  const { bill_details, loading } = useSelector((state) => state.billFetch);
  const {
    userInfo: { Name, Email },
  } = useSelector((state) => state.myProfile);

  const {
    customerName,
    cust_mbl,
    billDate,
    dueDate,
    billPeriod,
    totalAmount,
    billAmount,
    billNumber,
  } = bill_details;
  const windowWidth = useWindowSize();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
  });
  const { billerInfo } = useSelector((state) => state.fields);
  const handlePay = (e) => {
    e.preventDefault();
    dispatch(closeModal({ modalProps: { open: false } }));

    dispatch(
      openModal({
        modalType: ModalExample,
        modalProps: {
          component:
            billerInfo.billFetchRequired === "MANDATORY" ? (
              <BillPaidComponent />
            ) : (
              <QuickPayPaidComponent />
            ),
          open: true,
          // setOpen: setOpen,
          widthDrawer: 800,
          closeDrawerAction: true,
        },
      })
    );
  };
  const router = useRouter();

  const serviceName = router?.route?.replace("/", "")?.toUpperCase();
  return (
    <div className={classes.root}>
      <Grid container>
        <Grid
          item
          xs={8}
          md={8}
          style={{ display: "flex", justifyContent: "flex-start" }}
        >
          <Typography variant="h6">{`QUICK PAY FOR ${serviceName}`}</Typography>
        </Grid>
        <Grid
          item
          xs={4}
          md={4}
          style={{
            display: "flex",
            justifyContent: "flex-end",
            alignItems: "center",
          }}
        >
          <Image
            src="/assets/images/Bharat-BillPay-Final-Logo.jpg"
            alt="Bharat BillPay"
            width="65"
            height="24"
          />
        </Grid>
      </Grid>

      {!_.isEmpty(bill_details) ? (
        <>
          <Table className={classes.table} size="small">
            <TableBody>
              <TableRowComponent heading="Customer Number" detail={cust_mbl} />
              <TableRowComponent heading="Payment Mode" detail="Cash" />

              <TableRowComponent
                heading="Bill Amount"
                detail={`₹${billAmount}`}
              />
              <TableRowComponent heading="Convenience Fees" detail="NA" />
              <TableRowComponent
                heading="Total Amount"
                detail={`₹${totalAmount}`}
              />
            </TableBody>
          </Table>
          <span
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              width: "100%",
              marginTop: 24,
            }}
          >
            <Controls.Button
              type="button"
              text="Cancel"
              onClick={() =>
                dispatch(closeModal({ modalProps: { open: false } }))
              }
            />
            <Controls.Button text="Pay Now" type="button" onClick={handlePay} />
          </span>
        </>
      ) : null}
    </div>
  );
};

export default QuickPayComponent;
