import { useWindowSize } from "@/hooks/useWindowSize";
import {
  colors,
  Grid,
  makeStyles,
  Table,
  TableBody,
  TableCell,
  TableRow,
  Typography,
} from "@material-ui/core";
import Script from "next/script";
import { useDispatch, useSelector } from "react-redux";
import _ from "lodash";
import Image from "next/image";
import Controls from "@/components/Controls/Controls";
import Lottie from "react-lottie-player";
import { closeModal, openModal } from "@/redux/actions/modal.actions";
import ModalExample from "@/components/Layout/Modal/ModalExample";
import TableRowComponent from "@/components/TableRowComponent";
import { lotteJson } from "@/config/lotteJson";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 16}px` : "100%",

    // height: "calc(100vh - 10px)",

    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    // overflowY: "scroll",
  },
  table: {
    padding: theme.spacing(2),
    margin: theme.spacing(2, 0, 0, 0),
  },
}));

const QuickPayPaidComponent = () => {
  const dispatch = useDispatch();
  const { bill_details, loading } = useSelector((state) => state.billFetch);
  const {
    userInfo: { Name, Email },
  } = useSelector((state) => state.myProfile);

  const {
    customerName,
    cust_mbl,
    billDate,
    dueDate,
    billPeriod,
    totalAmount,
    billAmount,
    billNumber,
  } = bill_details;
  const windowWidth = useWindowSize();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
  });
  // const handlePay = (e) => {
  //   e.preventDefault();
  //   dispatch(closeModal({ modalProps: { open: false } }));
  //   dispatch(
  //     openModal({
  //       modalType: ModalExample,
  //       modalProps: {
  //         component: <BillPayedComponent />,
  //         open: true,
  //         // setOpen: setOpen,
  //         widthDrawer: 800,
  //         closeDrawerAction: true,
  //       },
  //     })
  //   );
  // };
  return (
    <>
      <Script src="https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js" />
      <div className={classes.root}>
        <Grid container>
          <Grid
            item
            xs={8}
            md={8}
            style={{ display: "flex", justifyContent: "flex-start" }}
          >
            <Typography variant="h6">
              <Image
                src="/assets/images/logos/logo.png"
                alt="Aaipay"
                width="174"
                height="45"
              />
            </Typography>
          </Grid>
          <Grid
            item
            xs={4}
            md={4}
            style={{
              display: "flex",
              justifyContent: "flex-end",
              alignItems: "center",
            }}
          >
            <Image
              src="/assets/images/Be Assured.png"
              alt="Bharat BillPay"
              width="60"
              height="60"
            />
          </Grid>
          <Grid
            item
            xs={12}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Lottie
              loop={false}
              background="transparent"
              animationData={lotteJson}
              play
              speed={0.8}
              style={{ width: 100, height: 100 }}
            />
          </Grid>
          <Grid
            item
            xs={12}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Typography
              variant="subtitle2"
              style={{ color: colors.green[500], fontSize: 18 }}
            >
              Congratulations! Your Bill Paid Successfully
            </Typography>
          </Grid>
        </Grid>

        {!_.isEmpty(bill_details) ? (
          <>
            <Grid container spacing={2}>
              <Grid item xs={12} md={6}>
                <Table className={classes.table} size="small">
                  <TableBody>
                    <TableRowComponent
                      heading="Transaction Status"
                      detail="Successful"
                    />
                    <TableRowComponent
                      heading="Txn Date and Time "
                      detail="2015-06-14 12:50:02"
                    />
                    <TableRowComponent heading="Payment Mode" detail="Cash" />
                    <TableRowComponent heading="Init Channel" detail="INT" />
                    <TableRowComponent
                      heading="Biller"
                      detail="OTME00005XXZ43-OTME"
                    />
                    <TableRowComponent
                      heading="Account No."
                      detail="8851273946"
                    />
                    <TableRowComponent
                      heading="Phone No."
                      detail="9898990084"
                    />
                  </TableBody>
                </Table>
              </Grid>
              <Grid item xs={12} md={6}>
                <Table className={classes.table} size="small">
                  <TableBody>
                    <TableRowComponent
                      heading="Transaction ID"
                      detail="00011193BAAC000020773"
                    />
                    <TableRowComponent
                      heading="Approval Number"
                      detail="12456780"
                    />
                    <TableRowComponent heading="Customer" detail="Ashish" />

                    <TableRowComponent
                      heading="Biller ID"
                      detail="0TME00005XXZ43"
                    />

                    <TableRowComponent
                      heading="Bill Amount"
                      detail={`₹${billAmount}`}
                    />
                    <TableRowComponent heading="Convenience Fees" detail="NA" />
                    <TableRowComponent
                      heading="Total Amount"
                      detail={`₹${totalAmount}`}
                    />
                  </TableBody>
                </Table>
              </Grid>
            </Grid>

            <span
              style={{
                display: "flex",
                justifyContent: "center",
                alignItems: "center",
                width: "100%",
                marginTop: 24,
              }}
            >
              <Controls.Button
                type="button"
                text="Download Slip"
                onClick={() =>
                  dispatch(closeModal({ modalProps: { open: false } }))
                }
                // onClick={() =>
                //   dispatch(closeModal({ modalProps: { open: false } }))
                // }
              />
              {/* <Controls.Button text="Pay Now" type="button" onClick={handlePay} /> */}
              <Controls.Button
                text="Do another"
                type="button"
                style={{ backgroundColor: colors.green[500] }}
              />
            </span>
          </>
        ) : null}
      </div>
    </>
  );
};

export default QuickPayPaidComponent;
