import { useWindowSize } from "@/hooks/useWindowSize";
import { makeStyles, Grid, Typography, Divider } from "@material-ui/core";
import Controls from "@/components/Controls/Controls";
import Image from "next/image";
import { useDispatch, useSelector } from "react-redux";
import { useFormik } from "formik";
import * as yup from "yup";
import { loginNewUser, registerUser } from "@/redux/actions/auth.actions";
import AlertMessage from "@/components/AlertMessage";
import { useRouter } from "next/router";
// import { registerUser } from "@/redux/actions/auth.actions";

const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768
        ? props.customPage === true
          ? `100%`
          : `${props.windowWidth}px`
        : "600px",

    height: (props) =>
      props && props.customPage === true
        ? "calc(100vh - 125px)"
        : "calc(100vh - 75px)",
    overflowY: "auto",
    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
  },
  image: {
    display: "flex",
    justifyContent: "center",
    // paddingTop: theme.spacing(0),
    // paddingBottom: theme.spacing(5),
    flexDirection: "column",
    alignItems: "center",
  },
  heading: {
    fontWeight: 500,
    // textTransform: "uppercase",
    fontSize: 24,
    marginTop: theme.spacing(1),
  },
  divider: {
    width: "90%",
    marginTop: theme.spacing(3),
    marginBottom: theme.spacing(3),
  },
  actionButton: {
    width: "30px",
    height: "30px",
  },
}));
const phoneRegExp =
  /^((\\+[1-9]{1,4}[ \\-]*)|(\\([0-9]{2,3}\\)[ \\-]*)|([0-9]{2,4})[ \\-]*)*?[0-9]{3,4}?[ \\-]*[0-9]{3,4}?$/;
const validationSchema = yup.object({
  email: yup
    .string("Enter your email")
    .email("Enter a valid email")
    .required("Email is required"),
  fullName: yup.string().required("Enter your Name"),
  mbl: yup
    .string()
    .required("Enter your mobile number")
    .matches(phoneRegExp, "Phone number is not valid")
    .min(10, "Mobile number must be at least 10 characters long")
    .max(10, "Mobile number must be at least 10 characters long"),
});
const SignUpComponent = (props) => {
  const windowWidth = useWindowSize();
  const { loadingButton, err } = useSelector((state) => state.registerUser);
  const { loadingButton: loadingNewUser } = useSelector(
    (state) => state.setOtp
  );
  const dispatch = useDispatch();
  const router = useRouter();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
    customPage: props.customPage,
  });
  const formik = useFormik({
    initialValues: {
      mbl: props.mbl ? props.mbl : "",
      fullName: "",
      email: "",
      otp: "",
    },
    validationSchema: validationSchema,
    onSubmit: (values) => {
      const { email, mbl, fullName, otp } = values;
      if (err === 1) {
        console.log("sign in");
        dispatch(loginNewUser(mbl, otp, props.owId, router));
      } else {
        dispatch(registerUser(mbl, fullName, email, props.owId));
      }
    },
  });

  return (
    <div className={classes.root}>
      <div className={classes.image}>
        <Typography variant="h4" component="div">
          <Image
            src="/assets/images/logos/logo.png"
            alt="logo"
            width="174"
            height="45"
          />
        </Typography>

        {/* <Typography variant="h5" component="div" className={classes.heading}>
          Sign Up
        </Typography> */}
        <Divider className={classes.divider} />
      </div>

      <form onSubmit={formik.handleSubmit}>
        <Grid container spacing={2}>
          <Grid item xs={12}>
            <Controls.Input
              fullWidth={true}
              label="Mobile"
              name="mbl"
              placeholder="Please Enter your mobile number"
              maxLength={10}
              value={formik.values.mbl ?? props?.mbl ?? ""}
              onChange={formik.handleChange}
              error={formik.touched.mbl && Boolean(formik.errors.mbl)}
              helperText={formik.touched.mbl && formik.errors.mbl}
            />
          </Grid>
          <Grid item xs={12}>
            <Controls.Input
              fullWidth={true}
              label="Full Name"
              name="fullName"
              placeholder="Please Enter your Full Name"
              value={formik.values.fullName}
              onChange={formik.handleChange}
              error={formik.touched.fullName && Boolean(formik.errors.fullName)}
              helperText={formik.touched.fullName && formik.errors.fullName}
            />
          </Grid>
          <Grid item xs={12}>
            <Controls.Input
              fullWidth={true}
              label="Email"
              name="email"
              placeholder="Please Enter your email address"
              value={formik.values.email}
              onChange={formik.handleChange}
              error={formik.touched.email && Boolean(formik.errors.email)}
              helperText={formik.touched.email && formik.errors.email}
            />
          </Grid>
          {err === 1 && (
            <Grid item xs={12}>
              <Controls.Input
                fullWidth={true}
                label="OTP"
                name="otp"
                value={formik.values.otp}
                onChange={formik.handleChange}
                error={formik.touched.otp && Boolean(formik.errors.otp)}
                helperText={formik.touched.otp && formik.errors.otp}
              />
            </Grid>
          )}

          <Controls.Button
            fullWidthButton={true}
            text={err === 1 ? "Login" : "Sign Up"}
            type="submit"
            loadingButton={err === 1 ? loadingNewUser : loadingButton}
            loadingIndicator={true}
          />
        </Grid>
      </form>
    </div>
  );
};

export default SignUpComponent;
