import { useWindowSize } from "@/hooks/useWindowSize";
import {
  colors,
  Grid,
  makeStyles,
  Table,
  TableBody,
  Typography,
} from "@material-ui/core";
import Script from "next/script";
import { useSelector } from "react-redux";
import _ from "lodash";

import Lottie from "react-lottie-player";

import TableRowComponent from "@/components/TableRowComponent";
import { lotteJson } from "@/config/lotteJson";
const useStyles = makeStyles((theme) => ({
  root: {
    width: (props) =>
      props && props.windowWidth < 768 ? `${props.windowWidth - 96}px` : "100%",

    // height: "calc(100vh - 10px)",

    paddingTop: theme.spacing(5),
    paddingBottom: theme.spacing(5),
    paddingLeft: theme.spacing(5),
    paddingRight: theme.spacing(5),
    // overflowY: "scroll",
  },
  table: {
    padding: theme.spacing(2),
    margin: theme.spacing(2, 0, 0, 0),
  },
}));

const SuccessComplaint = () => {
  const { complaint, loading } = useSelector((state) => state.complaints);

  const windowWidth = useWindowSize();
  const { width } = windowWidth;
  const classes = useStyles({
    windowWidth: width,
  });

  return (
    <>
      <Script src="https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js" />
      <div className={classes.root}>
        <Grid container>
          <Grid
            item
            xs={12}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Lottie
              loop={false}
              background="transparent"
              animationData={lotteJson}
              play
              speed={0.8}
              style={{ width: 60, height: 60 }}
            />
          </Grid>
          <Grid
            item
            xs={12}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Typography
              variant="subtitle2"
              style={{
                color:
                  complaint.responseCode === "000"
                    ? colors.green[500]
                    : colors.red[500],
                fontSize: 18,
              }}
            >
              {complaint.responseCode === "000"
                ? "Congratulations! Complaint Successfully Registered"
                : "Something went wrong"}
            </Typography>
          </Grid>
        </Grid>

        {!_.isEmpty(complaint) ? (
          <>
            <Grid container spacing={2}>
              <Grid item xs={12}>
                <Table className={classes.table} size="small">
                  <TableBody>
                    <TableRowComponent
                      heading="Complaint ID"
                      detail={complaint.complaintId}
                    />
                    <TableRowComponent
                      heading="Complaint Assigned"
                      detail={complaint.complaintAssigned}
                    />
                  </TableBody>
                </Table>
              </Grid>
            </Grid>
          </>
        ) : null}
      </div>
    </>
  );
};

export default SuccessComplaint;
